*============================================================================;
*  Title:
*         Format Library for Inpatient Quality Indicators Program;
*
*  Description:
*          FORMAT LIB FOR AHRQ INPATIENT QUALITY INDICATORS;
*
*          >>>  VERSION 4.1, December 2009 <<<
*
*          Note:  Codes valid from 10/1/1994 to 9/30/2009
*
*============================================================================;
FILENAME CONTROL 'C:\PATHNAME\CONTROL_IQI.SAS';  *<===USER MUST modify;

%INCLUDE CONTROL;


PROC FORMAT DDNAME=library;

 /* -------------------------------------------------------------- */
 /* --- FORMATS FOR STRATIFIERS ---------------------------------- */
 /* -------------------------------------------------------------- */

 /* --- FORMAT FOR SEX CATEGORY ---------------------------------- */
VALUE SEXCAT
 1 = 'Male'
 2 = 'Female'
  ;

 /* --- FORMAT FOR AGE CATEGORY ---------------------------------- */
VALUE AGECAT
 0 = '00 to 17'
 1 = '18 to 39'
 2 = '40 to 64'
 3 = '65 to 74'
 4 = '75+'
  ;

 /* --- FORMAT FOR RACE CATEGORY --------------------------------- */
VALUE RACECAT
 1 = 'White'
 2 = 'Black'
 3 = 'Hispanic'
 4 = 'Asian and NH/PI'
 5 = 'Amer Indian/AN'
 6 = 'Other'
  ;

 /* --- FORMAT FOR PAYER CATEGORY ---------------------------------- */
VALUE PAYCAT
 1 = 'Medicare'
 2 = 'Medicaid'
 3 = 'Private'
 4 = 'Self Pay'
 5 = 'No Charge'
 6 = 'Other'
  ;

 * -------------------------------------------------------------- ;
 * --- IQI DEFINING FORMATS ------------------------------------- ;
 * -------------------------------------------------------------- ;

 * -------------------------------------------------------------- ;
 * --- FORMATS - PROVIDER LEVEL MORTALITY INDICATORS ------------ ;
 * -------------------------------------------------------------- ;

 /* ----------------------------------------- */
 /* Palliative Care                           */
 /* ----------------------------------------- */

VALUE $PALLIAD
'V667 ' = '1' /* ENCOUNTR PALLIATIVE CARE */
OTHER = '0' ;

 /* ----------------------------------------- */
 /* Mortality after Craniotomy                */
 /*   Mortality (post-op) Indicator / IQI #13 */
 /* ----------------------------------------- */

 /* Craniotomy DRGs  */
 /* CMS DRGs: */

VALUE $CRANIOTG
'001' = '1' /* CRANIOTOMY AGE >17 W CC */
'002' = '1' /* CRANIOTOMY AGE >17 W/O CC */
'528' = '1' /* INTRACRANIAL VASCULAR PROC W PDX HEMORRHAGE */
'529' = '1' /* VENTRICULAR SHUNT PROCEDURES W CC */
'530' = '1' /* VENTRICULAR SHUNT PROCEDURES W/O CC */
'543' = '1' /* CRANIOTOMY W MAJOR DEVICE IMPLANT OR ACUTE COMPLEX CNS PRINCIPAL DIAGNOSIS */
OTHER = '0' ;

 /* MS DRGs: */

VALUE $CRANIO2G
'020' = '1' /* Intracranial vascular procedures w PDX hemorrhage w MCC */
'021' = '1' /* Intracranial vascular procedures w PDX hemorrhage w CC */
'022' = '1' /* Intracranial vascular procedures w PDX hemorrhage w/o CC/MCC */
'023' = '1' /* Cranio w major dev impl/acute complex CNS PDX w MCC or chemo implant */
'024' = '1' /* Cranio w major dev impl/acute complex CNS PDX w/o MCC */
'025' = '1' /* Craniotomy & endovascular intracranial procedures w MCC */
'026' = '1' /* Craniotomy & endovascular intracranial procedures w CC */
'027' = '1' /* Craniotomy & endovascular intracranial procedures w/o CC/MCC */
'031' = '1' /* Ventricular shunt procedures w MCC */
'032' = '1' /* Ventricular shunt procedures w CC */
'033' = '1' /* Ventricular shunt procedures w/o CC/MCC */
OTHER = '0' ;

 /* EXCLUDE: HEAD TRAUMA */
 /* ICD-9-CM DIAGNOSIS CODES ( INCLUDES 4TH AND 5TH DIGITS): */

VALUE $HTRAUID
'80000' = '1' /* CLOSED SKULL VAULT FX */
'80001' = '1' /* CL SKULL VLT FX W/O COMA */
'80002' = '1' /* CL SKULL VLT FX-BRF COMA */
'80003' = '1' /* CL SKULL VLT FX-MOD COMA */
'80004' = '1' /* CL SKL VLT FX-PROLN COMA */
'80005' = '1' /* CL SKUL VLT FX-DEEP COMA */
'80006' = '1' /* CL SKULL VLT FX-COMA NOS */
'80009' = '1' /* CL SKL VLT FX-CONCUS NOS */
'80010' = '1' /* CL SKL VLT FX/CEREBR LAC */
'80011' = '1' /* CL SKULL VLT FX W/O COMA */
'80012' = '1' /* CL SKULL VLT FX-BRF COMA */
'80013' = '1' /* CL SKULL VLT FX-MOD COMA */
'80014' = '1' /* CL SKL VLT FX-PROLN COMA */
'80015' = '1' /* CL SKUL VLT FX-DEEP COMA */
'80016' = '1' /* CL SKULL VLT FX-COMA NOS */
'80019' = '1' /* CL SKL VLT FX-CONCUS NOS */
'80020' = '1' /* CL SKL VLT FX/MENING HEM */
'80021' = '1' /* CL SKULL VLT FX W/O COMA */
'80022' = '1' /* CL SKULL VLT FX-BRF COMA */
'80023' = '1' /* CL SKULL VLT FX-MOD COMA */
'80024' = '1' /* CL SKL VLT FX-PROLN COMA */
'80025' = '1' /* CL SKUL VLT FX-DEEP COMA */
'80026' = '1' /* CL SKULL VLT FX-COMA NOS */
'80029' = '1' /* CL SKL VLT FX-CONCUS NOS */
'80030' = '1' /* CL SKULL VLT FX/HEM NEC */
'80031' = '1' /* CL SKULL VLT FX W/O COMA */
'80032' = '1' /* CL SKULL VLT FX-BRF COMA */
'80033' = '1' /* CL SKULL VLT FX-MOD COMA */
'80034' = '1' /* CL SKL VLT FX-PROLN COMA */
'80035' = '1' /* CL SKUL VLT FX-DEEP COMA */
'80036' = '1' /* CL SKULL VLT FX-COMA NOS */
'80039' = '1' /* CL SKL VLT FX-CONCUS NOS */
'80040' = '1' /* CL SKL VLT FX/BR INJ NEC */
'80041' = '1' /* CL SKULL VLT FX W/O COMA */
'80042' = '1' /* CL SKULL VLT FX-BRF COMA */
'80043' = '1' /* CL SKULL VLT FX-MOD COMA */
'80044' = '1' /* CL SKL VLT FX-PROLN COMA */
'80045' = '1' /* CL SKUL VLT FX-DEEP COMA */
'80046' = '1' /* CL SKULL VLT FX-COMA NOS */
'80049' = '1' /* CL SKL VLT FX-CONCUS NOS */
'80050' = '1' /* OPN SKULL VAULT FRACTURE */
'80051' = '1' /* OPN SKUL VLT FX W/O COMA */
'80052' = '1' /* OPN SKUL VLT FX-BRF COMA */
'80053' = '1' /* OPN SKUL VLT FX-MOD COMA */
'80054' = '1' /* OPN SKL VLT FX-PROLN COM */
'80055' = '1' /* OPN SKL VLT FX-DEEP COMA */
'80056' = '1' /* OPN SKUL VLT FX-COMA NOS */
'80059' = '1' /* OP SKL VLT FX-CONCUS NOS */
'80060' = '1' /* OPN SKL VLT FX/CEREB LAC */
'80061' = '1' /* OPN SKUL VLT FX W/O COMA */
'80062' = '1' /* OPN SKUL VLT FX-BRF COMA */
'80063' = '1' /* OPN SKUL VLT FX-MOD COMA */
'80064' = '1' /* OPN SKL VLT FX-PROLN COM */
'80065' = '1' /* OPN SKL VLT FX-DEEP COMA */
'80066' = '1' /* OPN SKUL VLT FX-COMA NOS */
'80069' = '1' /* OP SKL VLT FX-CONCUS NOS */
'80070' = '1' /* OPN SKL VLT FX/MENIN HEM */
'80071' = '1' /* OPN SKUL VLT FX W/O COMA */
'80072' = '1' /* OPN SKUL VLT FX-BRF COMA */
'80073' = '1' /* OPN SKUL VLT FX-MOD COMA */
'80074' = '1' /* OPN SKL VLT FX-PROLN COM */
'80075' = '1' /* OPN SKL VLT FX-DEEP COMA */
'80076' = '1' /* OPN SKUL VLT FX-COMA NOS */
'80079' = '1' /* OP SKL VLT FX-CONCUS NOS */
'80080' = '1' /* OPN SKULL VLT FX/HEM NEC */
'80081' = '1' /* OPN SKUL VLT FX W/O COMA */
'80082' = '1' /* OPN SKUL VLT FX-BRF COMA */
'80083' = '1' /* OPN SKUL VLT FX-MOD COMA */
'80084' = '1' /* OPN SKL VLT FX-PROLN COM */
'80085' = '1' /* OPN SKL VLT FX-DEEP COMA */
'80086' = '1' /* OPN SKUL VLT FX-COMA NOS */
'80089' = '1' /* OP SKL VLT FX-CONCUS NOS */
'80090' = '1' /* OP SKL VLT FX/BR INJ NEC */
'80091' = '1' /* OPN SKUL VLT FX W/O COMA */
'80092' = '1' /* OPN SKUL VLT FX-BRF COMA */
'80093' = '1' /* OPN SKUL VLT FX-MOD COMA */
'80094' = '1' /* OPN SKL VLT FX-PROLN COM */
'80095' = '1' /* OP SKUL VLT FX-DEEP COMA */
'80096' = '1' /* OPN SKUL VLT FX-COMA NOS */
'80099' = '1' /* OP SKL VLT FX-CONCUS NOS */
'80100' = '1' /* CLOS SKULL BASE FRACTURE */
'80101' = '1' /* CL SKUL BASE FX W/O COMA */
'80102' = '1' /* CL SKUL BASE FX-BRF COMA */
'80103' = '1' /* CL SKUL BASE FX-MOD COMA */
'80104' = '1' /* CL SKL BASE FX-PROL COMA */
'80105' = '1' /* CL SKL BASE FX-DEEP COMA */
'80106' = '1' /* CL SKUL BASE FX-COMA NOS */
'80109' = '1' /* CL SKULL BASE FX-CONCUSS */
'80110' = '1' /* CL SKL BASE FX/CEREB LAC */
'80111' = '1' /* CL SKUL BASE FX W/O COMA */
'80112' = '1' /* CL SKUL BASE FX-BRF COMA */
'80113' = '1' /* CL SKUL BASE FX-MOD COMA */
'80114' = '1' /* CL SKL BASE FX-PROL COMA */
'80115' = '1' /* CL SKL BASE FX-DEEP COMA */
'80116' = '1' /* CL SKUL BASE FX-COMA NOS */
'80119' = '1' /* CL SKULL BASE FX-CONCUSS */
'80120' = '1' /* CL SKL BASE FX/MENIN HEM */
'80121' = '1' /* CL SKUL BASE FX W/O COMA */
'80122' = '1' /* CL SKUL BASE FX/BRF COMA */
'80123' = '1' /* CL SKUL BASE FX-MOD COMA */
'80124' = '1' /* CL SKL BASE FX-PROL COMA */
'80125' = '1' /* CL SKL BASE FX-DEEP COMA */
'80126' = '1' /* CL SKUL BASE FX-COMA NOS */
'80129' = '1' /* CL SKULL BASE FX-CONCUSS */
'80130' = '1' /* CL SKULL BASE FX/HEM NEC */
'80131' = '1' /* CL SKUL BASE FX W/O COMA */
'80132' = '1' /* CL SKUL BASE FX-BRF COMA */
'80133' = '1' /* CL SKUL BASE FX-MOD COMA */
'80134' = '1' /* CL SKL BASE FX-PROL COMA */
'80135' = '1' /* CL SKL BASE FX-DEEP COMA */
'80136' = '1' /* CL SKUL BASE FX-COMA NOS */
'80139' = '1' /* CL SKULL BASE FX-CONCUSS */
'80140' = '1' /* CL SK BASE FX/BR INJ NEC */
'80141' = '1' /* CL SKUL BASE FX W/O COMA */
'80142' = '1' /* CL SKUL BASE FX-BRF COMA */
'80143' = '1' /* CL SKUL BASE FX-MOD COMA */
'80144' = '1' /* CL SKL BASE FX-PROL COMA */
'80145' = '1' /* CL SKL BASE FX-DEEP COMA */
'80146' = '1' /* CL SKUL BASE FX-COMA NOS */
'80149' = '1' /* CL SKULL BASE FX-CONCUSS */
'80150' = '1' /* OPEN SKULL BASE FRACTURE */
'80151' = '1' /* OPN SKL BASE FX W/O COMA */
'80152' = '1' /* OPN SKL BASE FX-BRF COMA */
'80153' = '1' /* OPN SKL BASE FX-MOD COMA */
'80154' = '1' /* OP SKL BASE FX-PROL COMA */
'80155' = '1' /* OP SKL BASE FX-DEEP COMA */
'80156' = '1' /* OPN SKL BASE FX-COMA NOS */
'80159' = '1' /* OPN SKUL BASE FX-CONCUSS */
'80160' = '1' /* OP SKL BASE FX/CEREB LAC */
'80161' = '1' /* OPN SKL BASE FX W/O COMA */
'80162' = '1' /* OPN SKL BASE FX-BRF COMA */
'80163' = '1' /* OPN SKL BASE FX-MOD COMA */
'80164' = '1' /* OP SKL BASE FX-PROL COMA */
'80165' = '1' /* OP SKL BASE FX-DEEP COMA */
'80166' = '1' /* OPN SKL BASE FX-COMA NOS */
'80169' = '1' /* OPN SKUL BASE FX-CONCUSS */
'80170' = '1' /* OP SKL BASE FX/MENIN HEM */
'80171' = '1' /* OPN SKL BASE FX W/O COMA */
'80172' = '1' /* OPN SKL BASE FX-BRF COMA */
'80173' = '1' /* OPN SKL BASE FX-MOD COMA */
'80174' = '1' /* OP SKL BASE FX-PROL COMA */
'80175' = '1' /* OP SKL BASE FX-DEEP COMA */
'80176' = '1' /* OPN SKL BASE FX-COMA NOS */
'80179' = '1' /* OPN SKUL BASE FX-CONCUSS */
'80180' = '1' /* OPN SKUL BASE FX/HEM NEC */
'80181' = '1' /* OPN SKL BASE FX W/O COMA */
'80182' = '1' /* OPN SKL BASE FX-BRF COMA */
'80183' = '1' /* OPN SKL BASE FX-MOD COMA */
'80184' = '1' /* OP SKL BASE FX-PROL COMA */
'80185' = '1' /* OP SKL BASE FX-DEEP COMA */
'80186' = '1' /* OPN SKL BASE FX-COMA NOS */
'80189' = '1' /* OPN SKUL BASE FX-CONCUSS */
'80190' = '1' /* OP SK BASE FX/BR INJ NEC */
'80191' = '1' /* OP SKUL BASE FX W/O COMA */
'80192' = '1' /* OPN SKL BASE FX-BRF COMA */
'80193' = '1' /* OPN SKL BASE FX-MOD COMA */
'80194' = '1' /* OP SKL BASE FX-PROL COMA */
'80195' = '1' /* OP SKL BASE FX-DEEP COMA */
'80196' = '1' /* OPN SKL BASE FX-COMA NOS */
'80199' = '1' /* OPN SKUL BASE FX-CONCUSS */
'8020' = '1' /* NASAL BONE FX-CLOSED */
'8021' = '1' /* NASAL BONE FX-OPEN */
'80220' = '1' /* MANDIBLE FX NOS-CLOSED */
'80221' = '1' /* FX CONDYL PROC MANDIB-CL */
'80222' = '1' /* SUBCONDYLAR FX MANDIB-CL */
'80223' = '1' /* FX CORON PROC MANDIB-CL */
'80224' = '1' /* FX RAMUS NOS-CLOSED */
'80225' = '1' /* FX ANGLE OF JAW-CLOSED */
'80226' = '1' /* FX SYMPHY MANDIB BODY-CL */
'80227' = '1' /* FX ALVEOLAR BORD MAND-CL */
'80228' = '1' /* FX MANDIBLE BODY NEC-CL */
'80229' = '1' /* MULT FX MANDIBLE-CLOSED */
'80230' = '1' /* MANDIBLE FX NOS-OPEN */
'80231' = '1' /* FX CONDYL PROC MAND-OPEN */
'80232' = '1' /* SUBCONDYL FX MANDIB-OPEN */
'80233' = '1' /* FX CORON PROC MANDIB-OPN */
'80234' = '1' /* FX RAMUS NOS-OPEN */
'80235' = '1' /* FX ANGLE OF JAW-OPEN */
'80236' = '1' /* FX SYMPHY MANDIB BDY-OPN */
'80237' = '1' /* FX ALV BORD MAND BDY-OPN */
'80238' = '1' /* FX MANDIBLE BODY NEC-OPN */
'80239' = '1' /* MULT FX MANDIBLE-OPEN */
'8024' = '1' /* FX MALAR/MAXILLARY-CLOSE */
'8025' = '1' /* FX MALAR/MAXILLARY-OPEN */
'8026' = '1' /* FX ORBITAL FLOOR-CLOSED */
'8027' = '1' /* FX ORBITAL FLOOR-OPEN */
'8028' = '1' /* FX FACIAL BONE NEC-CLOSE */
'8029' = '1' /* FX FACIAL BONE NEC-OPEN */
'80300' = '1' /* CLOSE SKULL FRACTURE NEC */
'80301' = '1' /* CL SKULL FX NEC W/O COMA */
'80302' = '1' /* CL SKULL FX NEC-BRF COMA */
'80303' = '1' /* CL SKULL FX NEC-MOD COMA */
'80304' = '1' /* CL SKL FX NEC-PROLN COMA */
'80305' = '1' /* CL SKUL FX NEC-DEEP COMA */
'80306' = '1' /* CL SKULL FX NEC-COMA NOS */
'80309' = '1' /* CL SKULL FX NEC-CONCUSS */
'80310' = '1' /* CL SKL FX NEC/CEREBR LAC */
'80311' = '1' /* CL SKULL FX NEC W/O COMA */
'80312' = '1' /* CL SKULL FX NEC-BRF COMA */
'80313' = '1' /* CL SKULL FX NEC-MOD COMA */
'80314' = '1' /* CL SKL FX NEC-PROLN COMA */
'80315' = '1' /* CL SKUL FX NEC-DEEP COMA */
'80316' = '1' /* CL SKULL FX NEC-COMA NOS */
'80319' = '1' /* CL SKULL FX NEC-CONCUSS */
'80320' = '1' /* CL SKL FX NEC/MENING HEM */
'80321' = '1' /* CL SKULL FX NEC W/O COMA */
'80322' = '1' /* CL SKULL FX NEC-BRF COMA */
'80323' = '1' /* CL SKULL FX NEC-MOD COMA */
'80324' = '1' /* CL SKL FX NEC-PROLN COMA */
'80325' = '1' /* CL SKUL FX NEC-DEEP COMA */
'80326' = '1' /* CL SKULL FX NEC-COMA NOS */
'80329' = '1' /* CL SKULL FX NEC-CONCUSS */
'80330' = '1' /* CL SKULL FX NEC/HEM NEC */
'80331' = '1' /* CL SKULL FX NEC W/O COMA */
'80332' = '1' /* CL SKULL FX NEC-BRF COMA */
'80333' = '1' /* CL SKULL FX NEC-MOD COMA */
'80334' = '1' /* CL SKL FX NEC-PROLN COMA */
'80335' = '1' /* CL SKUL FX NEC-DEEP COMA */
'80336' = '1' /* CL SKULL FX NEC-COMA NOS */
'80339' = '1' /* CL SKULL FX NEC-CONCUSS */
'80340' = '1' /* CL SKL FX NEC/BR INJ NEC */
'80341' = '1' /* CL SKULL FX NEC W/O COMA */
'80342' = '1' /* CL SKULL FX NEC-BRF COMA */
'80343' = '1' /* CL SKULL FX NEC-MOD COMA */
'80344' = '1' /* CL SKL FX NEC-PROLN COMA */
'80345' = '1' /* CL SKUL FX NEC-DEEP COMA */
'80346' = '1' /* CL SKULL FX NEC-COMA NOS */
'80349' = '1' /* CL SKULL FX NEC-CONCUSS */
'80350' = '1' /* OPEN SKULL FRACTURE NEC */
'80351' = '1' /* OPN SKUL FX NEC W/O COMA */
'80352' = '1' /* OPN SKUL FX NEC-BRF COMA */
'80353' = '1' /* OPN SKUL FX NEC-MOD COMA */
'80354' = '1' /* OPN SKL FX NEC-PROL COMA */
'80355' = '1' /* OPN SKL FX NEC-DEEP COMA */
'80356' = '1' /* OPN SKUL FX NEC-COMA NOS */
'80359' = '1' /* OPN SKULL FX NEC-CONCUSS */
'80360' = '1' /* OPN SKL FX NEC/CEREB LAC */
'80361' = '1' /* OPN SKUL FX NEC W/O COMA */
'80362' = '1' /* OPN SKUL FX NEC-BRF COMA */
'80363' = '1' /* OPN SKUL FX NEC-MOD COMA */
'80364' = '1' /* OPN SKL FX NEC-PROLN COM */
'80365' = '1' /* OPN SKL FX NEC-DEEP COMA */
'80366' = '1' /* OPN SKUL FX NEC-COMA NOS */
'80369' = '1' /* OPN SKULL FX NEC-CONCUSS */
'80370' = '1' /* OPN SKL FX NEC/MENIN HEM */
'80371' = '1' /* OPN SKUL FX NEC W/O COMA */
'80372' = '1' /* OPN SKUL FX NEC-BRF COMA */
'80373' = '1' /* OPN SKUL FX NEC-MOD COMA */
'80374' = '1' /* OPN SKL FX NEC-PROL COMA */
'80375' = '1' /* OPN SKL FX NEC-DEEP COMA */
'80376' = '1' /* OPN SKUL FX NEC-COMA NOS */
'80379' = '1' /* OPN SKULL FX NEC-CONCUSS */
'80380' = '1' /* OPN SKULL FX NEC/HEM NEC */
'80381' = '1' /* OPN SKUL FX NEC W/O COMA */
'80382' = '1' /* OPN SKUL FX NEC-BRF COMA */
'80383' = '1' /* OPN SKUL FX NEC-MOD COMA */
'80384' = '1' /* OPN SKL FX NEC-PROL COMA */
'80385' = '1' /* OPN SKL FX NEC-DEEP COMA */
'80386' = '1' /* OPN SKUL FX NEC-COMA NOS */
'80389' = '1' /* OPN SKULL FX NEC-CONCUSS */
'80390' = '1' /* OP SKL FX NEC/BR INJ NEC */
'80391' = '1' /* OPN SKUL FX NEC W/O COMA */
'80392' = '1' /* OPN SKUL FX NEC-BRF COMA */
'80393' = '1' /* OPN SKUL FX NEC-MOD COMA */
'80394' = '1' /* OPN SKL FX NEC-PROL COMA */
'80395' = '1' /* OPN SKL FX NEC-DEEP COMA */
'80396' = '1' /* OPN SKUL FX NEC-COMA NOS */
'80399' = '1' /* OPN SKULL FX NEC-CONCUSS */
'80400' = '1' /* CL SKUL FX W OTH BONE FX */
'80401' = '1' /* CL SKL W OTH FX W/O COMA */
'80402' = '1' /* CL SKL W OTH FX-BRF COMA */
'80403' = '1' /* CL SKL W OTH FX-MOD COMA */
'80404' = '1' /* CL SKL/OTH FX-PROLN COMA */
'80405' = '1' /* CL SKUL/OTH FX-DEEP COMA */
'80406' = '1' /* CL SKL W OTH FX-COMA NOS */
'80409' = '1' /* CL SKUL W OTH FX-CONCUSS */
'80410' = '1' /* CL SK W OTH FX/CEREB LAC */
'80411' = '1' /* CL SKL W OTH FX W/O COMA */
'80412' = '1' /* CL SKL W OTH FX-BRF COMA */
'80413' = '1' /* CL SKL W OTH FX-MOD COMA */
'80414' = '1' /* CL SKL/OTH FX-PROLN COMA */
'80415' = '1' /* CL SKUL/OTH FX-DEEP COMA */
'80416' = '1' /* CL SKL W OTH FX-COMA NOS */
'80419' = '1' /* CL SKUL W OTH FX-CONCUSS */
'80420' = '1' /* CL SKL/OTH FX/MENING HEM */
'80421' = '1' /* CL SKL W OTH FX W/O COMA */
'80422' = '1' /* CL SKL W OTH FX-BRF COMA */
'80423' = '1' /* CL SKL W OTH FX-MOD COMA */
'80424' = '1' /* CL SKL/OTH FX-PROLN COMA */
'80425' = '1' /* CL SKUL/OTH FX-DEEP COMA */
'80426' = '1' /* CL SKL W OTH FX-COMA NOS */
'80429' = '1' /* CL SKUL W OTH FX-CONCUSS */
'80430' = '1' /* CL SKUL W OTH FX/HEM NEC */
'80431' = '1' /* CL SKL W OTH FX W/O COMA */
'80432' = '1' /* CL SKL W OTH FX-BRF COMA */
'80433' = '1' /* CL SKL W OTH FX-MOD COMA */
'80434' = '1' /* CL SKL/OTH FX-PROLN COMA */
'80435' = '1' /* CL SKUL/OTH FX-DEEP COMA */
'80436' = '1' /* CL SKL W OTH FX-COMA NOS */
'80439' = '1' /* CL SKUL W OTH FX-CONCUSS */
'80440' = '1' /* CL SKL/OTH FX/BR INJ NEC */
'80441' = '1' /* CL SKL W OTH FX W/O COMA */
'80442' = '1' /* CL SKL W OTH FX-BRF COMA */
'80443' = '1' /* CL SKL W OTH FX-MOD COMA */
'80444' = '1' /* CL SKL/OTH FX-PROLN COMA */
'80445' = '1' /* CL SKUL/OTH FX-DEEP COMA */
'80446' = '1' /* CL SKL W OTH FX-COMA NOS */
'80449' = '1' /* CL SKUL W OTH FX-CONCUSS */
'80450' = '1' /* OPN SKULL FX/OTH BONE FX */
'80451' = '1' /* OPN SKUL/OTH FX W/O COMA */
'80452' = '1' /* OPN SKUL/OTH FX-BRF COMA */
'80453' = '1' /* OPN SKUL/OTH FX-MOD COMA */
'80454' = '1' /* OPN SKL/OTH FX-PROL COMA */
'80455' = '1' /* OPN SKL/OTH FX-DEEP COMA */
'80456' = '1' /* OPN SKUL/OTH FX-COMA NOS */
'80459' = '1' /* OPN SKULL/OTH FX-CONCUSS */
'80460' = '1' /* OPN SKL/OTH FX/CEREB LAC */
'80461' = '1' /* OPN SKUL/OTH FX W/O COMA */
'80462' = '1' /* OPN SKUL/OTH FX-BRF COMA */
'80463' = '1' /* OPN SKUL/OTH FX-MOD COMA */
'80464' = '1' /* OPN SKL/OTH FX-PROL COMA */
'80465' = '1' /* OPN SKL/OTH FX-DEEP COMA */
'80466' = '1' /* OPN SKUL/OTH FX-COMA NOS */
'80469' = '1' /* OPN SKULL/OTH FX-CONCUSS */
'80470' = '1' /* OPN SKL/OTH FX/MENIN HEM */
'80471' = '1' /* OPN SKUL/OTH FX W/O COMA */
'80472' = '1' /* OPN SKUL/OTH FX-BRF COMA */
'80473' = '1' /* OPN SKUL/OTH FX-MOD COMA */
'80474' = '1' /* OPN SKL/OTH FX-PROL COMA */
'80475' = '1' /* OPN SKL/OTH FX-DEEP COMA */
'80476' = '1' /* OPN SKUL/OTH FX-COMA NOS */
'80479' = '1' /* OPN SKULL/OTH FX-CONCUSS */
'80480' = '1' /* OPN SKL W OTH FX/HEM NEC */
'80481' = '1' /* OPN SKUL/OTH FX W/O COMA */
'80482' = '1' /* OPN SKUL/OTH FX-BRF COMA */
'80483' = '1' /* OPN SKUL/OTH FX-MOD COMA */
'80484' = '1' /* OPN SKL/OTH FX-PROL COMA */
'80485' = '1' /* OPN SKL/OTH FX-DEEP COMA */
'80486' = '1' /* OPN SKUL/OTH FX-COMA NOS */
'80489' = '1' /* OPN SKULL/OTH FX-CONCUSS */
'80490' = '1' /* OP SKL/OTH FX/BR INJ NEC */
'80491' = '1' /* OPN SKUL/OTH FX W/O COMA */
'80492' = '1' /* OPN SKUL/OTH FX-BRF COMA */
'80493' = '1' /* OPN SKUL/OTH FX-MOD COMA */
'80494' = '1' /* OPN SKL/OTH FX-PROL COMA */
'80495' = '1' /* OPN SKL/OTH FX-DEEP COMA */
'80496' = '1' /* OPN SKUL/OTH FX-COMA NOS */
'80499' = '1' /* OPN SKULL/OTH FX-CONCUSS */
'80500' = '1' /* FX CERVICAL VERT NOS-CL */
'80501' = '1' /* FX C1 VERTEBRA-CLOSED */
'80502' = '1' /* FX C2 VERTEBRA-CLOSED */
'80503' = '1' /* FX C3 VERTEBRA-CLOSED */
'80504' = '1' /* FX C4 VERTEBRA-CLOSED */
'80505' = '1' /* FX C5 VERTEBRA-CLOSED */
'80506' = '1' /* FX C6 VERTEBRA-CLOSED */
'80507' = '1' /* FX C7 VERTEBRA-CLOSED */
'80508' = '1' /* FX MULT CERVICAL VERT-CL */
'80510' = '1' /* FX CERVICAL VERT NOS-OPN */
'80511' = '1' /* FX C1 VERTEBRA-OPEN */
'80512' = '1' /* FX C2 VERTEBRA-OPEN */
'80513' = '1' /* FX C3 VERTEBRA-OPEN */
'80514' = '1' /* FX C4 VERTEBRA-OPEN */
'80515' = '1' /* FX C5 VERTEBRA-OPEN */
'80516' = '1' /* FX C6 VERTEBRA-OPEN */
'80517' = '1' /* FX C7 VERTEBRA-OPEN */
'80518' = '1' /* FX MLT CERVICAL VERT-OPN */
'80600' = '1' /* C1-C4 FX-CL/CORD INJ NOS */
'80601' = '1' /* C1-C4 FX-CL/COM CORD LES */
'80602' = '1' /* C1-C4 FX-CL/ANT CORD SYN */
'80603' = '1' /* C1-C4 FX-CL/CEN CORD SYN */
'80604' = '1' /* C1-C4 FX-CL/CORD INJ NEC */
'80605' = '1' /* C5-C7 FX-CL/CORD INJ NOS */
'80606' = '1' /* C5-C7 FX-CL/COM CORD LES */
'80607' = '1' /* C5-C7 FX-CL/ANT CORD SYN */
'80608' = '1' /* C5-C7 FX-CL/CEN CORD SYN */
'80609' = '1' /* C5-C7 FX-CL/CORD INJ NEC */
'80610' = '1' /* C1-C4 FX-OP/CORD INJ NOS */
'80611' = '1' /* C1-C4 FX-OP/COM CORD LES */
'80612' = '1' /* C1-C4 FX-OP/ANT CORD SYN */
'80613' = '1' /* C1-C4 FX-OP/CEN CORD SYN */
'80614' = '1' /* C1-C4 FX-OP/CORD INJ NEC */
'80615' = '1' /* C5-C7 FX-OP/CORD INJ NOS */
'80616' = '1' /* C5-C7 FX-OP/COM CORD LES */
'80617' = '1' /* C5-C7 FX-OP/ANT CORD SYN */
'80618' = '1' /* C5-C7 FX-OP/CEN CORD SYN */
'80619' = '1' /* C5-C7 FX-OP/CORD INJ NEC */
'8500' = '1' /* CONCUSSION W/O COMA */
'8501' = '1' /* CONCUSSION-BRIEF COMA */
'85011' = '1' /* CONCUS-BRIEF COMA <31 MN */
'85012' = '1' /* CONCUS-BRF COMA 31-59 MN */
'8502' = '1' /* CONCUSSION-MODERATE COMA */
'8503' = '1' /* CONCUSSION-PROLONG COMA */
'8504' = '1' /* CONCUSSION-DEEP COMA */
'8505' = '1' /* CONCUSSION W COMA NOS */
'8509' = '1' /* CONCUSSION NOS */
'85100' = '1' /* CEREBRAL CORTX CONTUSION */
'85101' = '1' /* CORTEX CONTUSION-NO COMA */
'85102' = '1' /* CORTEX CONTUS-BRIEF COMA */
'85103' = '1' /* CORTEX CONTUS-MOD COMA */
'85104' = '1' /* CORTX CONTUS-PROLNG COMA */
'85105' = '1' /* CORTEX CONTUS-DEEP COMA */
'85106' = '1' /* CORTEX CONTUS-COMA NOS */
'85109' = '1' /* CORTEX CONTUS-CONCUS NOS */
'85110' = '1' /* CORTEX CONTUSION/OPN WND */
'85111' = '1' /* OPN CORTX CONTUS-NO COMA */
'85112' = '1' /* OPN CORT CONTUS-BRF COMA */
'85113' = '1' /* OPN CORT CONTUS-MOD COMA */
'85114' = '1' /* OPN CORT CONTU-PROL COMA */
'85115' = '1' /* OPN CORT CONTU-DEEP COMA */
'85116' = '1' /* OPN CORT CONTUS-COMA NOS */
'85119' = '1' /* OPN CORTX CONTUS-CONCUSS */
'85120' = '1' /* CEREBRAL CORTEX LACERAT */
'85121' = '1' /* CORTEX LACERAT W/O COMA */
'85122' = '1' /* CORTEX LACERA-BRIEF COMA */
'85123' = '1' /* CORTEX LACERAT-MOD COMA */
'85124' = '1' /* CORTEX LACERAT-PROL COMA */
'85125' = '1' /* CORTEX LACERAT-DEEP COMA */
'85126' = '1' /* CORTEX LACERAT-COMA NOS */
'85129' = '1' /* CORTEX LACERAT-CONCUSS */
'85130' = '1' /* CORTEX LACER W OPN WOUND */
'85131' = '1' /* OPN CORTEX LACER-NO COMA */
'85132' = '1' /* OPN CORTX LAC-BRIEF COMA */
'85133' = '1' /* OPN CORTX LACER-MOD COMA */
'85134' = '1' /* OPN CORTX LAC-PROLN COMA */
'85135' = '1' /* OPN CORTEX LAC-DEEP COMA */
'85136' = '1' /* OPN CORTX LACER-COMA NOS */
'85139' = '1' /* OPN CORTX LACER-CONCUSS */
'85140' = '1' /* CEREBEL/BRAIN STM CONTUS */
'85141' = '1' /* CEREBELL CONTUS W/O COMA */
'85142' = '1' /* CEREBELL CONTUS-BRF COMA */
'85143' = '1' /* CEREBELL CONTUS-MOD COMA */
'85144' = '1' /* CEREBEL CONTUS-PROL COMA */
'85145' = '1' /* CEREBEL CONTUS-DEEP COMA */
'85146' = '1' /* CEREBELL CONTUS-COMA NOS */
'85149' = '1' /* CEREBELL CONTUS-CONCUSS */
'85150' = '1' /* CEREBEL CONTUS W OPN WND */
'85151' = '1' /* OPN CEREBE CONT W/O COMA */
'85152' = '1' /* OPN CEREBE CONT-BRF COMA */
'85153' = '1' /* OPN CEREBE CONT-MOD COMA */
'85154' = '1' /* OPN CEREBE CONT-PROL COM */
'85155' = '1' /* OPN CEREBE CONT-DEEP COM */
'85156' = '1' /* OPN CEREBE CONT-COMA NOS */
'85159' = '1' /* OPN CEREBEL CONT-CONCUSS */
'85160' = '1' /* CEREBEL/BRAIN STEM LACER */
'85161' = '1' /* CEREBEL LACERAT W/O COMA */
'85162' = '1' /* CEREBEL LACER-BRIEF COMA */
'85163' = '1' /* CEREBEL LACERAT-MOD COMA */
'85164' = '1' /* CEREBEL LACER-PROLN COMA */
'85165' = '1' /* CEREBELL LACER-DEEP COMA */
'85166' = '1' /* CEREBEL LACERAT-COMA NOS */
'85169' = '1' /* CEREBEL LACER-CONCUSSION */
'85170' = '1' /* CEREBEL LACER W OPEN WND */
'85171' = '1' /* OPN CEREBEL LAC W/O COMA */
'85172' = '1' /* OPN CEREBEL LAC-BRF COMA */
'85173' = '1' /* OPN CEREBEL LAC-MOD COMA */
'85174' = '1' /* OPN CEREBE LAC-PROL COMA */
'85175' = '1' /* OPN CEREBE LAC-DEEP COMA */
'85176' = '1' /* OPN CEREBEL LAC-COMA NOS */
'85179' = '1' /* OPN CEREBELL LAC-CONCUSS */
'85180' = '1' /* BRAIN LACERATION NEC */
'85181' = '1' /* BRAIN LACER NEC W/O COMA */
'85182' = '1' /* BRAIN LAC NEC-BRIEF COMA */
'85183' = '1' /* BRAIN LACER NEC-MOD COMA */
'85184' = '1' /* BRAIN LAC NEC-PROLN COMA */
'85185' = '1' /* BRAIN LAC NEC-DEEP COMA */
'85186' = '1' /* BRAIN LACER NEC-COMA NOS */
'85189' = '1' /* BRAIN LACER NEC-CONCUSS */
'85190' = '1' /* BRAIN LAC NEC W OPEN WND */
'85191' = '1' /* OPN BRAIN LACER W/O COMA */
'85192' = '1' /* OPN BRAIN LAC-BRIEF COMA */
'85193' = '1' /* OPN BRAIN LACER-MOD COMA */
'85194' = '1' /* OPN BRAIN LAC-PROLN COMA */
'85195' = '1' /* OPEN BRAIN LAC-DEEP COMA */
'85196' = '1' /* OPN BRAIN LACER-COMA NOS */
'85199' = '1' /* OPEN BRAIN LACER-CONCUSS */
'85200' = '1' /* TRAUM SUBARACHNOID HEM */
'85201' = '1' /* SUBARACHNOID HEM-NO COMA */
'85202' = '1' /* SUBARACH HEM-BRIEF COMA */
'85203' = '1' /* SUBARACH HEM-MOD COMA */
'85204' = '1' /* SUBARACH HEM-PROLNG COMA */
'85205' = '1' /* SUBARACH HEM-DEEP COMA */
'85206' = '1' /* SUBARACH HEM-COMA NOS */
'85209' = '1' /* SUBARACH HEM-CONCUSSION */
'85210' = '1' /* SUBARACH HEM W OPN WOUND */
'85211' = '1' /* OPN SUBARACH HEM-NO COMA */
'85212' = '1' /* OP SUBARACH HEM-BRF COMA */
'85213' = '1' /* OP SUBARACH HEM-MOD COMA */
'85214' = '1' /* OP SUBARACH HEM-PROL COM */
'85215' = '1' /* OP SUBARACH HEM-DEEP COM */
'85216' = '1' /* OP SUBARACH HEM-COMA NOS */
'85219' = '1' /* OPN SUBARACH HEM-CONCUSS */
'85220' = '1' /* TRAUMATIC SUBDURAL HEM */
'85221' = '1' /* SUBDURAL HEM W/O COMA */
'85222' = '1' /* SUBDURAL HEM-BRIEF COMA */
'85223' = '1' /* SUBDURAL HEMORR-MOD COMA */
'85224' = '1' /* SUBDURAL HEM-PROLNG COMA */
'85225' = '1' /* SUBDURAL HEM-DEEP COMA */
'85226' = '1' /* SUBDURAL HEMORR-COMA NOS */
'85229' = '1' /* SUBDURAL HEM-CONCUSSION */
'85230' = '1' /* SUBDURAL HEM W OPN WOUND */
'85231' = '1' /* OPEN SUBDUR HEM W/O COMA */
'85232' = '1' /* OPN SUBDUR HEM-BRF COMA */
'85233' = '1' /* OPN SUBDUR HEM-MOD COMA */
'85234' = '1' /* OPN SUBDUR HEM-PROL COMA */
'85235' = '1' /* OPN SUBDUR HEM-DEEP COMA */
'85236' = '1' /* OPN SUBDUR HEM-COMA NOS */
'85239' = '1' /* OPN SUBDUR HEM-CONCUSS */
'85240' = '1' /* TRAUMATIC EXTRADURAL HEM */
'85241' = '1' /* EXTRADURAL HEM W/O COMA */
'85242' = '1' /* EXTRADUR HEM-BRIEF COMA */
'85243' = '1' /* EXTRADURAL HEM-MOD COMA */
'85244' = '1' /* EXTRADUR HEM-PROLN COMA */
'85245' = '1' /* EXTRADURAL HEM-DEEP COMA */
'85246' = '1' /* EXTRADURAL HEM-COMA NOS */
'85249' = '1' /* EXTADURAL HEM-CONCUSS */
'85250' = '1' /* EXTRADURAL HEM W OPN WND */
'85251' = '1' /* EXTRADURAL HEMOR-NO COMA */
'85252' = '1' /* EXTRADUR HEM-BRIEF COMA */
'85253' = '1' /* EXTRADURAL HEM-MOD COMA */
'85254' = '1' /* EXTRADUR HEM-PROLN COMA */
'85255' = '1' /* EXTRADUR HEM-DEEP COMA */
'85256' = '1' /* EXTRADURAL HEM-COMA NOS */
'85259' = '1' /* EXTRADURAL HEM-CONCUSS */
'85300' = '1' /* TRAUMATIC BRAIN HEM NEC */
'85301' = '1' /* BRAIN HEM NEC W/O COMA */
'85302' = '1' /* BRAIN HEM NEC-BRIEF COMA */
'85303' = '1' /* BRAIN HEM NEC-MOD COMA */
'85304' = '1' /* BRAIN HEM NEC-PROLN COMA */
'85305' = '1' /* BRAIN HEM NEC-DEEP COMA */
'85306' = '1' /* BRAIN HEM NEC-COMA NOS */
'85309' = '1' /* BRAIN HEM NEC-CONCUSSION */
'85310' = '1' /* BRAIN HEM NEC W OPN WND */
'85311' = '1' /* BRAIN HEM OPN W/O COMA */
'85312' = '1' /* BRAIN HEM OPN-BRF COMA */
'85313' = '1' /* BRAIN HEM OPEN-MOD COMA */
'85314' = '1' /* BRAIN HEM OPN-PROLN COMA */
'85315' = '1' /* BRAIN HEM OPEN-DEEP COMA */
'85316' = '1' /* BRAIN HEM OPEN-COMA NOS */
'85319' = '1' /* BRAIN HEM OPN-CONCUSSION */
'85400' = '1' /* BRAIN INJURY NEC */
'85401' = '1' /* BRAIN INJURY NEC-NO COMA */
'85402' = '1' /* BRAIN INJ NEC-BRIEF COMA */
'85403' = '1' /* BRAIN INJ NEC-MOD COMA */
'85404' = '1' /* BRAIN INJ NEC-PROLN COMA */
'85405' = '1' /* BRAIN INJ NEC-DEEP COMA */
'85406' = '1' /* BRAIN INJ NEC-COMA NOS */
'85409' = '1' /* BRAIN INJ NEC-CONCUSSION */
'85410' = '1' /* BRAIN INJURY W OPN WND */
'85411' = '1' /* OPN BRAIN INJ W/O COMA */
'85412' = '1' /* OPN BRAIN INJ-BRIEF COMA */
'85413' = '1' /* OPN BRAIN INJ-MOD COMA */
'85414' = '1' /* OPN BRAIN INJ-PROLN COMA */
'85415' = '1' /* OPN BRAIN INJ-DEEP COMA */
'85416' = '1' /* OPEN BRAIN INJ-COMA NOS */
'85419' = '1' /* OPN BRAIN INJ-CONCUSSION */
'9500 ' = '1' /* OPTIC NERVE INJURY */
'9501 ' = '1' /* INJURY TO OPTIC CHIASM */
'9502 ' = '1' /* INJURY TO OPTIC PATHWAYS */
'9503 ' = '1' /* INJURY TO VISUAL CORTEX */
'9509 ' = '1' /* INJ OPTIC NERV/PATH NOS */
'9510 ' = '1' /* INJURY OCULOMOTOR NERVE */
'9511 ' = '1' /* INJURY TROCHLEAR NERVE */
'9512 ' = '1' /* INJURY TRIGEMINAL NERVE */
'9513 ' = '1' /* INJURY ABDUCENS NERVE */
'9514 ' = '1' /* INJURY TO FACIAL NERVE */
'9515 ' = '1' /* INJURY TO ACOUSTIC NERVE */
'9516 ' = '1' /* INJURY ACCESSORY NERVE */
'9517 ' = '1' /* INJURY HYPOGLOSSAL NERVE */
'9518 ' = '1' /* INJURY CRANIAL NERVE NEC */
'9519 ' = '1' /* INJURY CRANIAL NERVE NOS */
'95200' = '1' /* C1-C4 SPIN CORD INJ NOS */
'95201' = '1' /* COMPLETE LES CORD/C1-C4 */
'95202' = '1' /* ANTERIOR CORD SYND/C1-C4 */
'95203' = '1' /* CENTRAL CORD SYND/C1-C4 */
'95204' = '1' /* C1-C4 SPIN CORD INJ NEC */
'95205' = '1' /* C5-C7 SPIN CORD INJ NOS */
'95206' = '1' /* COMPLETE LES CORD/C5-C7 */
'95207' = '1' /* ANTERIOR CORD SYND/C5-C7 */
'95208' = '1' /* CENTRAL CORD SYND/C5-C7 */
'95209' = '1' /* C5-C7 SPIN CORD INJ NEC */
'95210' = '1' /* T1-T6 SPIN CORD INJ NOS */
'95211' = '1' /* COMPLETE LES CORD/T1-T6 */
'95212' = '1' /* ANTERIOR CORD SYND/T1-T6 */
'95213' = '1' /* CENTRAL CORD SYND/T1-T6 */
'95214' = '1' /* T1-T6 SPIN CORD INJ NEC */
'95215' = '1' /* T7-T12 SPIN CORD INJ NOS */
'95216' = '1' /* COMPLETE LES CORD/T7-T12 */
'95217' = '1' /* ANTERIOR CORD SYN/T7-T12 */
'95218' = '1' /* CENTRAL CORD SYN/T7-T12 */
'95219' = '1' /* T7-T12 SPIN CORD INJ NEC */
OTHER = '0' ;

 /* ---------------------------------------- */
 /* Esophageal Cancer Resection (PRESOP)     */
 /*   Volume Indicator / IQI #1              */
 /*   Mortality (post-op) Indicator / IQI #8 */
 /* ---------------------------------------- */

 /* Esophageal resection */
 /* ICD-9-CM Procedure Codes: */

VALUE $PRESOPP
'424 ' = '1' /* ESOPHAGECTOMY */
'4240' = '1' /* ESOPHAGECTOMY NOS */
'4241' = '1' /* PARTIAL ESOPHAGECTOMY */
'4242' = '1' /* TOTAL ESOPHAGECTOMY */
'425 ' = '1' /* THORAC ESOPHAG ANAST */
'4251' = '1' /* THORAC ESOPHAGOESOPHAGOS */
'4252' = '1' /* THORAC ESOPHAGOGASTROST */
'4253' = '1' /* THORAC SM BOWEL INTERPOS */
'4254' = '1' /* THORAC ESOPHAGOENTER NEC */
'4255' = '1' /* THORAC LG BOWEL INTERPOS */
'4256' = '1' /* THORAC ESOPHAGOCOLOS NEC */
'4258' = '1' /* THORAC INTERPOSITION NEC */
'4259' = '1' /* THORAC ESOPHAG ANAST NEC */
'426 ' = '1' /* STERN ESOPHAG ANAST */
'4261' = '1' /* STERN ESOPHAGOESOPHAGOST */
'4262' = '1' /* STERN ESOPHAGOGASTROSTOM */
'4263' = '1' /* STERN SM BOWEL INTERPOS */
'4264' = '1' /* STERN ESOPHAGOENTER NEC */
'4265' = '1' /* STERN LG BOWEL INTERPOS */
'4266' = '1' /* STERN ESOPHAGOCOLOS NEC */
'4268' = '1' /* STERN INTERPOSITION NEC */
'4269' = '1' /* STERN ESOPHAG ANAST NEC */
OTHER  = '0' ;

 /* Esophageal resection */
 /* ICD-9-CM Procedure Codes: */

VALUE $PRESO2P
'4399' = '1' /* TOTAL GASTRECTOMY NEC */
OTHER  = '0' ;

 /* Include Only: Esophageal Cancer */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $PRESOPD
'1500 ' = '1'  /* MAL NEO CERVICAL ESOPHAG */
'1501 ' = '1'  /* MAL NEO THORACIC ESOPHAG */
'1502 ' = '1'  /* MAL NEO ABDOMIN ESOPHAG */
'1503 ' = '1'  /* MAL NEO UPPER 3RD ESOPH */
'1504 ' = '1'  /* MAL NEO MIDDLE 3RD ESOPH */
'1505 ' = '1'  /* MAL NEO LOWER 3RD ESOPH */
'1508 ' = '1'  /* MAL NEO ESOPHAGUS NEC */
'1509 ' = '1'  /* MAL NEO ESOPHAGUS NOS */
'1510 ' = '1'  /* MAL NEO STOMACH CARDIA */
OTHER  = '0' ;

 /* Include Only: Esophageal Cancer */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $PRESO2D
'1978 ' = '1'  /* SEC MAL NEO GI NEC */
'2301 ' = '1'  /* CA IN SITU ESOPHAGUS */
'2355 ' = '1'  /* UNC BEHAV NEO GI NEC */
OTHER  = '0' ;

 /* ---------------------------------------- */
 /* Pancreatic Cancer Reseciton (PRPANC)     */
 /*   Volume Indicator / IQI #2              */
 /*   Mortality (post-op) Indicator / IQI #9 */
 /* ---------------------------------------- */

 /* Pancreatic Resection */
 /* ICD-9-CM Procedure Codes: */

VALUE $PRPANCP
'526 ' = '1' /* TOTAL PANCREATECTOMY */
'527 ' = '1' /* RAD PANCREATICODUODENECT */
OTHER  = '0' ;

 /* Include Only: Pancreatic Cancer */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $PRPANCD
'1520 ' = '1'  /* MALIGNANT NEOPL DUODENUM */
'1561 ' = '1'  /* MAL NEO EXTRAHEPAT DUCTS */
'1562 ' = '1'  /* MAL NEO AMPULLA OF VATER */
'1570 ' = '1'  /* MAL NEO PANCREAS HEAD */
'1571 ' = '1'  /* MAL NEO PANCREAS BODY */
'1572 ' = '1'  /* MAL NEO PANCREAS TAIL */
'1573 ' = '1'  /* MAL NEO PANCREATIC DUCT */
'1574 ' = '1'  /* MAL NEO ISLET LANGERHANS */
'1578 ' = '1'  /* MALIG NEO PANCREAS NEC */
'1579 ' = '1'  /*-MALIG NEO PANCREAS NOS-*/
OTHER  = '0' ;

 /* Whipple procedure*/
 /* ICD-9-CM Procedure Codes: */

VALUE $PRPAN2P
'527 ' = '1' /* RAD PANCREATICODUODENECT */
OTHER  = '0' ;


 /* ----------------------------------------- */
 /* Abdominal Aortic Aneurysm Repair (PRAAAR) */
 /*   Volume Indicator / IQI #4               */
 /*   Mortality (post-op) Indicator / IQI #11 */
 /* ----------------------------------------- */

 /* AAA Repair */
 /* ICD-9-CM Procedure Codes: */

VALUE $PRAAARP
'3834' = '1'  /* AORTA RESECTION & ANAST */
'3844' = '1'  /* RESECT ABDM AORTA W REPL */
'3864' = '1'  /* EXCISION OF AORTA */
'3971' = '1'  /* ENDO IMPL GRFT ABD AORTA */
OTHER  = '0' ;

 /* Include Only: AAA */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $PRAAARD
'4413 ' = '1'  /* RUPT ABD AORTIC ANEURYSM */
OTHER  = '0' ;

VALUE $PRAAA2D
'4414 ' = '1'  /* ABDOM AORTIC ANEURYSM */
OTHER  = '0' ;

 /* ----------------------------------------- */
 /* CABG (PRCABG)                             */
 /*   Volume Indicator / IQI #5               */
 /*   Mortality (post-op) Indicator / IQI #12 */
 /*   Utilization (area) / IQI #26            */
 /* ----------------------------------------- */

 /* CABG */
 /* ICD-9-CM Procedure Codes: */

VALUE $PRCABGP
'3610' = '1'   /* AORTOCORONARY BYPASS NOS */
'3611' = '1'   /* AORTOCOR BYPAS-1 COR ART */
'3612' = '1'   /* AORTOCOR BYPAS-2 COR ART */
'3613' = '1'   /* AORTOCOR BYPAS-3 COR ART */
'3614' = '1'   /* AORTCOR BYPAS-4+ COR ART */
'3615' = '1'   /* 1 INT MAM-COR ART BYPASS */
'3616' = '1'   /* 2 INT MAM-COR ART BYPASS */
'3617' = '1'   /* ABD-CORON ART BYPASS */
'3619' = '1'   /* HRT REVAS BYPS ANAS NEC */
OTHER  = '0';

 /* ---------------------------------------- */
 /* PTCA volume (PRPTCA)                     */
 /*   Volume Indicator / IQI #6              */
 /*   Utilization (area) Indicator / IQI #27 */
 /*   Mortality Indicator / IQI #30          */
 /* ---------------------------------------- */

 /* PTCA */
 /* ICD-9-CM Procedure Codes: */

VALUE $PRPTCAP
'0066' = '1'   /* PTCA OR COR ATHERECTOMY */
'3601' = '1'   /* PTCA-1 VESSEL W/O AGENT */
'3602' = '1'   /* PTCA-1 VESSEL WITH AGNT */
'3605' = '1'   /* PTCA-MULTIPLE VESSEL */
OTHER  = '0' ;


 /* -------------------------------------- */
 /* Carotid Endarterectomy volume (PRCEAT) */
 /*   Volume Indicator / IQI #7            */
 /*   Mortality Indicator / IQI #31        */
 /* ---------------------------------------*/

 /* Carotid Endarterectomy */
 /* ICD-9-CM Procedure Codes: */

VALUE $PRCEATP
'3812' = '1'   /* HEAD & NECK ENDARTER NEC */
OTHER  = '0' ;


 * -------------------------------------------------------------- ;
 * --- FORMATS - PROVIDER LEVEL MORTALITY INDICATORS ------------ ;
 * -------------------------------------------------------------- ;

 /* ----------------------------------------- */
 /* Mortality after Hip Replacement (MTHIPR)  */
 /*   Mortality (post-op) Indicator / IQI #14 */
 /* ----------------------------------------- */

 /* Hip Replacement */
 /* ICD-9-CM Procedure Codes: */

VALUE $MTHIPRP
'0070' = '1'   /* REV HIP REPL-ACETAB/FEM */
'0071' = '1'   /* REV HIP REPL-ACETAB COMP */
'0072' = '1'   /* REV HIP REPL-FEM COMP */
'0073' = '1'   /* REV HIP REPL-LINER/HEAD */
'8151' = '1'   /* TOTAL HIP REPLACEMENT */
'8152' = '1'   /* PARTIAL HIP REPLACEMENT */
'8153' = '1'   /* REVISE HIP REPLACEMENT */
OTHER  = '0' ;

 /* Include Only: Osteoarthrosis of Hip */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $MTHIPRD
'71500' = '1'  /* GENL OSTEOARTHROSIS NOS */
'71509' = '1'  /* GENL OSTEOARTHROSIS MULT */
'71510' = '1'  /* LOC PRIM OSTEOART-UNSPEC */
'71515' = '1'  /* LOC PRIM OSTEOART-PELVIS */
'71518' = '1'  /* LOC PRIM OSTEOARTHR NEC */
'71520' = '1'  /* LOC 2ND OSTEOARTH-UNSPEC */
'71525' = '1'  /* LOC 2ND OSTEOARTH-PELVIS */
'71528' = '1'  /* LOC 2ND OSTEOARTHROS NEC */
'71530' = '1'  /* LOC OSTEOARTH NOS-UNSPEC */
'71535' = '1'  /* LOC OSTEOARTH NOS-PELVIS */
'71538' = '1'  /* LOC OSTEOAR NOS-SITE NEC */
'71580' = '1'  /* OSTEOARTHROSIS-MULT SITE */
'71589' = '1'  /* OSTEOARTHROSIS-MULT SITE */
'71590' = '1'  /* OSTEOARTHROS NOS-UNSPEC */
'71595' = '1'  /* OSTEOARTHROS NOS-PELVIS */
'71598' = '1'  /* OSTEOARTHRO NOS-OTH SITE */
'71650' = '1'  /* POLYARTHRITIS NOS-UNSPEC */
'71655' = '1'  /* POLYARTHRITIS NOS-PELVIS */
'71658' = '1'  /* POLYARTHRIT NOS-OTH SITE */
'71659' = '1'  /* POLYARTHRITIS NOS-MULT */
'71660' = '1'  /* MONOARTHRITIS NOS-UNSPEC */
'71665' = '1'  /* MONOARTHRITIS NOS-PELVIS */
'71668' = '1'  /* MONOARTHRIT NOS-OTH SITE */
'71690' = '1'  /* ARTHROPATHY NOS-UNSPEC */
'71695' = '1'  /* ARTHROPATHY NOS-PELVIS */
'71698' = '1'  /* ARTHROPATHY NOS-OTH SITE */
'71699' = '1'  /* ARTHROPATHY NOS-MULT */
OTHER   = '0' ;

 /* ----------------------------------------------- */
 /* Acute Myocardial Infarction Mortality (MRTAMI)  */
 /*   Mortality Indicator / IQI #15                 */
 /* ----------------------------------------------- */

 /* Acute Myocardial Infarction */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $MRTAMID
'41001' = '1'  /* AMI ANTEROLATERAL, INIT */
'41011' = '1'  /* AMI ANTERIOR WALL, INIT */
'41021' = '1'  /* AMI INFEROLATERAL, INIT */
'41031' = '1'  /* AMI INFEROPOST, INITIAL */
'41041' = '1'  /* AMI INFERIOR WALL, INIT */
'41051' = '1'  /* AMI LATERAL NEC, INITIAL */
'41061' = '1'  /* TRUE POST INFARCT, INIT */
'41071' = '1'  /* SUBENDO INFARCT, INITIAL */
'41081' = '1'  /* AMI NEC, INITIAL */
'41091' = '1'  /* AMI NOS, INITIAL */
OTHER   = '0' ;

 /* -------------------------------------- */
 /* Congestive Heart Failure rate (MRTCHF) */
 /*   Mortality Indicator / IQI #16        */
 /* -------------------------------------- */

 /* CHF */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $MRTCHFD
'39891' = '1'  /* RHEUMATIC HEART FAILURE */
'40201' = '1'  /* MAL HYPERT HRT DIS W CHF */
'40211' = '1'  /* BENIGN HYP HRT DIS W CHF */
'40291' = '1'  /* HYPERTEN HEART DIS W CHF */
'40401' = '1'  /* MAL HYPER HRT/REN W CHF */
'40403' = '1'  /* MAL HYP HRT/REN W CHF&RF */
'40411' = '1'  /* BEN HYPER HRT/REN W CHF */
'40413' = '1'  /* BEN HYP HRT/REN W CHF&RF */
'40491' = '1'  /* HYPER HRT/REN NOS W CHF */
'40493' = '1'  /* HYP HT/REN NOS W CHF&RF */
'4280 ' = '1'  /* CONGESTIVE HEART FAILURE */
'4281 ' = '1'  /* LEFT HEART FAILURE */
'42820' = '1'  /* SYSTOLIC HRT FAILURE NOS */
'42821' = '1'  /* AC SYSTOLIC HRT FAILURE */
'42822' = '1'  /* CHR SYSTOLIC HRT FAILURE */
'42823' = '1'  /* AC ON CHR SYST HRT FAIL */
'42830' = '1'  /* DIASTOLC HRT FAILURE NOS */
'42831' = '1'  /* AC DIASTOLIC HRT FAILURE */
'42832' = '1'  /* CHR DIASTOLIC HRT FAIL */
'42833' = '1'  /* AC ON CHR DIAST HRT FAIL */
'42840' = '1'  /* SYST/DIAST HRT FAIL NOS */
'42841' = '1'  /* AC SYST/DIASTOL HRT FAIL */
'42842' = '1'  /* CHR SYST/DIASTL HRT FAIL */
'42843' = '1'  /* AC/CHR SYST/DIA HRT FAIL */
'4289 ' = '1'  /* HEART FAILURE NOS */
OTHER   = '0' ;

 /* ------------------------------- */
 /* Stroke Mortality (MRTCVD)       */
 /*   Mortality Indicator / IQI #17 */
 /* ------------------------------- */

 /* Stroke */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $MRTCVDD
'430  ' = '1'  /* SUBARACHNOID HEMORRHAGE */
'431  ' = '1'  /* INTRACEREBRAL HEMORRHAGE */
'4320 ' = '1'  /* NONTRAUM EXTRADURAL HEM */
'4321 ' = '1'  /* SUBDURAL HEMORRHAGE */
'4329 ' = '1'  /* INTRACRANIAL HEMORR NOS */
'43301' = '1'  /* BASI ART OCCL W/ INFARCT */
'43311' = '1'  /* CAROTD OCCL W/ INFRCT */
'43321' = '1'  /* VERTB ART OCCL W/ INFRCT */
'43331' = '1'  /* MULT PRECER OCCL W/ INFRCT */
'43381' = '1'  /* PRECER OCCL NEC W/ INFRCT */
'43391' = '1'  /* PRECER OCCL NOS W/ INFRCT */
'43401' = '1'  /* CERE THROMBOSIS W/ INFRCT */
'43411' = '1'  /* CERE EMBOLISM W/ INFRCT */
'43491' = '1'  /* CEREB OCCL NOS W/ INFRCT */
'436  ' = '1'  /* CVA */
OTHER   = '0' ;

VALUE $MRTCV2D
'430  ' = '1'  /* SUBARACHNOID HEMORRHAGE */
'431  ' = '1'  /* INTRACEREBRAL HEMORRHAGE */
'4320 ' = '1'  /* NONTRAUM EXTRADURAL HEM */
'4321 ' = '1'  /* SUBDURAL HEMORRHAGE */
'4329 ' = '1'  /* INTRACRANIAL HEMORR NOS */
'43301' = '1'  /* BASI ART OCCL W/ INFARCT */
'43311' = '1'  /* CAROTD OCCL W/ INFRCT */
'43321' = '1'  /* VERTB ART OCCL W/ INFRCT */
'43331' = '1'  /* MULT PRECER OCCL W/ INFRCT */
'43381' = '1'  /* PRECER OCCL NEC W/ INFRCT */
'43391' = '1'  /* PRECER OCCL NOS W/ INFRCT */
'43401' = '1'  /* CERE THROMBOSIS W/ INFRCT */
'43411' = '1'  /* CERE EMBOLISM W/ INFRCT */
'43491' = '1'  /* CEREB OCCL NOS W/ INFRCT */
OTHER   = '0' ;

VALUE $MRTCV3D
'431  ' = '1'  /* INTRACEREBRAL HEMORRHAGE */
'4320 ' = '1'  /* NONTRAUM EXTRADURAL HEM */
'4321 ' = '1'  /* SUBDURAL HEMORRHAGE */
'4329 ' = '1'  /* INTRACRANIAL HEMORR NOS */
OTHER   = '0' ;

VALUE $MRTCV4D
'43301' = '1'  /* BASI ART OCCL W/ INFARCT */
'43311' = '1'  /* CAROTD OCCL W/ INFRCT */
'43321' = '1'  /* VERTB ART OCCL W/ INFRCT */
'43331' = '1'  /* MULT PRECER OCCL W/ INFRCT */
'43381' = '1'  /* PRECER OCCL NEC W/ INFRCT */
'43391' = '1'  /* PRECER OCCL NOS W/ INFRCT */
'43401' = '1'  /* CERE THROMBOSIS W/ INFRCT */
'43411' = '1'  /* CERE EMBOLISM W/ INFRCT */
'43491' = '1'  /* CEREB OCCL NOS W/ INFRCT */
OTHER   = '0' ;

 /* ---------------------------------------------- */
 /* Gastrointestinal Hemorrhage mortality (MRTGIH) */
 /*   Mortality Indicator / IQI #18                */
 /* ---------------------------------------------- */

 /* Gastrointestinal Hemorrhage */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $MRTGIHD
'4560 ' = '1'  /* ESOPHAG VARICES W BLEED */
'5307 ' = '1'  /* MALLORY-WEISS SYNDROME */
'53021' = '1'  /* ULCER ESOPHAGUS W BLEED */
'53082' = '1'  /* ESOPHAGEAL HEMORRHAGE */
'53100' = '1'  /* AC STOMACH ULCER W HEM */
'53101' = '1'  /* AC STOMAC ULC W HEM-OBST */
'53120' = '1'  /* AC STOMAC ULC W HEM/PERF */
'53121' = '1'  /* AC STOM ULC HEM/PERF-OBS */
'53140' = '1'  /* CHR STOMACH ULC W HEM */
'53141' = '1'  /* CHR STOM ULC W HEM-OBSTR */
'53160' = '1'  /* CHR STOMACH ULC HEM/PERF */
'53161' = '1'  /* CHR STOM ULC HEM/PERF-OB */
'53200' = '1'  /* AC DUODENAL ULCER W HEM */
'53201' = '1'  /* AC DUODEN ULC W HEM-OBST */
'53220' = '1'  /* AC DUODEN ULC W HEM/PERF */
'53221' = '1'  /* AC DUOD ULC HEM/PERF-OBS */
'53240' = '1'  /* CHR DUODEN ULCER W HEM */
'53241' = '1'  /* CHR DUODEN ULC HEM-OBSTR */
'53260' = '1'  /* CHR DUODEN ULC HEM/PERF */
'53261' = '1'  /* CHR DUOD ULC HEM/PERF-OB */
'53300' = '1'  /* AC PEPTIC ULCER W HEMORR */
'53301' = '1'  /* AC PEPTIC ULC W HEM-OBST */
'53320' = '1'  /* AC PEPTIC ULC W HEM/PERF */
'53321' = '1'  /* AC PEPT ULC HEM/PERF-OBS */
'53340' = '1'  /* CHR PEPTIC ULCER W HEM */
'53341' = '1'  /* CHR PEPTIC ULC W HEM-OBS */
'53360' = '1'  /* CHR PEPT ULC W HEM/PERF */
'53361' = '1'  /* CHR PEPT ULC HEM/PERF-OB */
'53400' = '1'  /* AC MARGINAL ULCER W HEM */
'53401' = '1'  /* AC MARGIN ULC W HEM-OBST */
'53420' = '1'  /* AC MARGIN ULC W HEM/PERF */
'53421' = '1'  /* AC MARG ULC HEM/PERF-OBS */
'53440' = '1'  /* CHR MARGINAL ULCER W HEM */
'53441' = '1'  /* CHR MARGIN ULC W HEM-OBS */
'53460' = '1'  /* CHR MARGIN ULC HEM/PERF */
'53461' = '1'  /* CHR MARG ULC HEM/PERF-OB */
'53501' = '1'  /* ACUTE GASTRITIS W HMRHG */
'53511' = '1'  /* ATRPH GASTRITIS W HMRHG */
'53521' = '1'  /* GSTR MCSL HYPRT W HMRG */
'53531' = '1'  /* ALCHL GSTRITIS W HMRHG */
'53541' = '1'  /* OTH SPF GASTRT W HMRHG */
'53551' = '1'  /* GSTR/DDNTS NOS W HMRHG */
'53561' = '1'  /* DUODENITIS W HMRHG */
'53783' = '1'  /* ANGIO STM/DUDN W HMRHG */
'53784' = '1'  /* DIEULAFOY LES,STOM&DUOD */
'56202' = '1'  /* DVRTCLO SML INT W HMRHG */
'56203' = '1'  /* DVRTCLI SML INT W HMRHG */
'56212' = '1'  /* DVRTCLO COLON W HMRHG */
'56213' = '1'  /* DVRTCLI COLON W HMRHG */
'5693 ' = '1'  /* RECTAL & ANAL HEMORRHAGE */
'56985' = '1'  /* ANGIO INTES W HMRHG */
'56986' = '1'  /* DIEULAFOY LES, INTESTINE */
'5780 ' = '1'  /* HEMATEMESIS */
'5781 ' = '1'  /* BLOOD IN STOOL */
'5789 ' = '1'  /* GASTROINTEST HEMORR NOS */
OTHER   = '0' ;

 /* ------------------------------- */
 /* Hip Fracture Mortality (MTHIPF) */
 /*   Mortality Indicator / IQI #19 */
 /* ------------------------------- */

 /* Hip Fracture */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $MTHIPFD
'82000' = '1'  /* FX FEMUR INTRCAPS NOS-CL */
'82001' = '1'  /* FX UP FEMUR EPIPHY-CLOS */
'82002' = '1'  /* FX FEMUR, MIDCERVIC-CLOS */
'82003' = '1'  /* FX BASE FEMORAL NCK-CLOS */
'82009' = '1'  /* FX FEMUR INTRCAPS NEC-CL */
'82010' = '1'  /* FX FEMUR INTRCAP NOS-OPN */
'82011' = '1'  /* FX UP FEMUR EPIPHY-OPEN */
'82012' = '1'  /* FX FEMUR, MIDCERVIC-OPEN */
'82013' = '1'  /* FX BASE FEMORAL NCK-OPEN */
'82019' = '1'  /* FX FEMUR INTRCAP NEC-OPN */
'82020' = '1'  /* TROCHANTERIC FX NOS-CLOS */
'82021' = '1'  /* INTERTROCHANTERIC FX-CL */
'82022' = '1'  /* SUBTROCHANTERIC FX-CLOSE */
'82030' = '1'  /* TROCHANTERIC FX NOS-OPEN */
'82031' = '1'  /* INTERTROCHANTERIC FX-OPN */
'82032' = '1'  /* SUBTROCHANTERIC FX-OPEN */
'8208 ' = '1'  /* FX NECK OF FEMUR NOS-CL */
'8209 ' = '1'  /* FX NECK OF FEMUR NOS-OPN */
OTHER   = '0' ;

 /* Exclude: periprosthetic fracture */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $MTHIP2D
'99644' = '1'  /* PERIPROSTHETC FX-PROS JT */
OTHER   = '0' ;

 /* ------------------------------- */
 /* Pneumonia mortality (MTPNEU)    */
 /*   Mortality Indicator / IQI #20 */
 /* ------------------------------- */

 /* Pneumonia */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $MTPNEUD
'00322' = '1'  /* SALMONELLA PNEUMONIA */
'0212 ' = '1'  /* PULMONARY TULAREMIA */
'0391 ' = '1'  /* PULMONARY ACTINOMYCOSIS */
'0521 ' = '1'  /* VARICELLA PNEUMONITIS */
'0551 ' = '1'  /* POSTMEASLES PNEUMONIA */
'0730 ' = '1'  /* ORNITHOSIS PNEUMONIA */
'1124 ' = '1'  /* CANDIDIASIS OF LUNG */
'1140 ' = '1'  /* PRIMARY COCCIDIOIDOMYCOS */
'1144 ' = '1'  /* CHRONIC PULMON COCCIDIOIDOMYCOSIS  */
'1145 ' = '1'  /* UNSPEC PULMON COCCIDIOIDOMYCOSIS  */
'11505' = '1'  /* HISTOPLASM CAPS PNEUMON */
'11515' = '1'  /* HISTOPLASM DUB PNEUMONIA  */
'11595' = '1'  /* HISTOPLASMOSIS PNEUMONIA */
'1304 ' = '1'  /* TOXOPLASMA PNEUMONITIS */
'1363 ' = '1'  /* PNEUMOCYSTOSIS */
'4800 ' = '1'  /* ADENOVIRAL PNEUMONIA */
'4801 ' = '1'  /* RESP SYNCYT VIRAL PNEUM */
'4802 ' = '1'  /* PARINFLUENZA VIRAL PNEUM */
'4803 ' = '1'  /* PNEUMONIA DUE TO SARS */
'4808 ' = '1'  /* VIRAL PNEUMONIA NEC */
'4809 ' = '1'  /* VIRAL PNEUMONIA NOS */
'481  ' = '1'  /* PNEUMOCOCCAL PNEUMONIA */
'4820 ' = '1'  /* K. PNEUMONIAE PNEUMONIA */
'4821 ' = '1'  /* PSEUDOMONAL PNEUMONIA */
'4822 ' = '1'  /* H.INFLUENZAE PNEUMONIA */
'48230' = '1'  /* STREP PNEUMONIA UNSPEC */
'48231' = '1'  /* GRP A STREP PNEUMONIA */
'48232' = '1'  /* GRP B STREP PNEUMONIA */
'48239' = '1'  /* OTH STREP PNEUMONIA */
'4824 ' = '1'  /* STAPHYLOCOCCAL PNEUMONIA */
'48240' = '1'  /* STAPH PNEUMONIA UNSP */
'48241' = '1'  /* METH SUS PNEUM D/T STAPH */
'48242' = '1'  /* METH RES PNEU D/T STAPH */
'48249' = '1'  /* STAPH PNEUMON OTH */
'48281' = '1'  /* ANAEROBIC PNEUMONIA */
'48282' = '1'  /* E COLI PNEUMONIA */
'48283' = '1'  /* OTH GRAM NEG PNEUMONIA */
'48284' = '1'  /* LEGIONNAIRES DX */
'48289' = '1'  /* BACT PNEUMONIA NEC */
'4829 ' = '1'  /* BACTERIAL PNEUMONIA NOS */
'4830 ' = '1'  /* MYCOPLASMA PNEUMONIA */
'4831 ' = '1'  /* CHLAMYDIA PNEUMONIA */
'4838 ' = '1'  /* OTH SPEC ORG PNEUMONIA */
'4841 ' = '1'  /* PNEUM W CYTOMEG INCL DIS */
'4843 ' = '1'  /* PNEUMONIA IN WHOOP COUGH */
'4845 ' = '1'  /* PNEUMONIA IN ANTHRAX */
'4846 ' = '1'  /* PNEUM IN ASPERGILLOSIS */
'4847 ' = '1'  /* PNEUM IN OTH SYS MYCOSES */
'4848 ' = '1'  /* PNEUM IN INFECT DIS NEC */
'485  ' = '1'  /* BRONCOPNEUMONIA ORG NOS */
'486  ' = '1'  /* PNEUMONIA, ORGANISM NOS */
'4870 ' = '1'  /* INFLUENZA WITH PNEUMONIA */ 
OTHER  = '0' ;


 * -------------------------------------------------------------- ;
 * --- FORMATS - PROVIDER LEVEL UTILIZATION INDICATORS ---------- ;
 * -------------------------------------------------------------- ;

 /* -------------------------------------------------- */
 /* Cesarean Section rate (PRCSEC)                     */
 /*   Utilization (provider) Indicator / IQI #21       */
 /* -------------------------------------------------- */

 /* All Births (Population at Risk): */
 /* DRG Codes: */

VALUE $PRBRTHG
'370' = '1'  /* CESAREAN SECTION W CC */
'371' = '1'  /* CESAREAN SECTION W/O CC */
'372' = '1'  /* VAGINAL DELIVERY W COMPLICATING DIAGNOSES */
'373' = '1'  /* VAGINAL DELIVERY W/O COMPLICATING DIAGNOSES */
'374' = '1'  /* VAGINAL DELIVERY W STERILIZATION &/OR D&C */
'375' = '1'  /* VAGINAL DELIVERY W O.R. PROC EXCEPT STERIL &/OR D&C */
OTHER  = '0' ;

 /* All Births (Population at Risk): */
 /* MSDRG Codes: */

VALUE $PRBRT2G
'765' = '1'  /* Cesarean section w CC/MCC */
'766' = '1'  /* Cesarean section w/o CC/MCC */
'767' = '1'  /* Vaginal delivery w sterilization &/or D&C */
'768' = '1'  /* Vaginal delivery w O.R. proc except steril &/or D&C */
'774' = '1'  /* Vaginal delivery w complicating diagnoses */
'775' = '1'  /* Vaginal delivery w/o complicating diagnoses */
OTHER  = '0' ;

 /* C-Section (Outcome of Interest): */
 /* DRG Codes: */

VALUE $PRCSECG
'370' = '1'  /* CESAREAN SECTION W CC */
'371' = '1'  /* CESAREAN SECTION W/O CC */
OTHER  = '0' ;

 /* C-Section (Outcome of Interest): */
 /* MSDRG Codes: */

VALUE $PRCSE2G
'765' = '1'  /* Cesarean section w CC/MCC */
'766' = '1'  /* Cesarean section w/o CC/MCC */
OTHER  = '0' ;

 /* C-Section (Outcome of Interest): */
 /* ICD-9-CM Procedure Codes: */

VALUE $PRCSECP
'740 ' = '1'  /* CLASSICAL C-SECTION */
'741 ' = '1'  /* LOW CERVICAL C-SECTION */
'742 ' = '1'  /* EXTRAPERITONEAL C-SECT */
'744 ' = '1'  /* CESAREAN SECTION NEC */
'7499' = '1'  /* CESAREAN SECTION NOS */
OTHER  = '0' ;

VALUE $PRCSE2P
'7491' = '1'  /* HYSTEROTOMY TO TERMIN PG */
OTHER  = '0' ;

 /* Exclude: Breech delivery, Preterm, Fetal Death, 
    Multiple Birth                                    */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $PRCSECD
'64420' = '1'  /* EARLY ONSET DELIV-UNSPEC */
'64421' = '1'  /* EARLY ONSET DELIVERY-DEL */
'65100' = '1'  /* TWIN PREGNANCY-UNSPEC */
'65101' = '1'  /* TWIN PREGNANCY-DELIVERED */
'65103' = '1'  /* TWIN PREGNANCY-ANTEPART */
'65110' = '1'  /* TRIPLET PREGNANCY-UNSPEC */
'65111' = '1'  /* TRIPLET PREGNANCY-DELIV */
'65113' = '1'  /* TRIPLET PREG-ANTEPARTUM */
'65120' = '1'  /* QUADRUPLET PREG-UNSPEC */
'65121' = '1'  /* QUADRUPLET PREG-DELIVER */
'65123' = '1'  /* QUADRUPLET PREG-ANTEPART */
'65130' = '1'  /* TWINS W FETAL LOSS-UNSP */
'65131' = '1'  /* TWINS W FETAL LOSS-DEL */
'65133' = '1'  /* TWINS W FETAL LOSS-ANTE */
'65140' = '1'  /* TRIPLETS W FET LOSS-UNSP */
'65141' = '1'  /* TRIPLETS W FET LOSS-DEL */
'65143' = '1'  /* TRIPLETS W FET LOSS-ANTE */
'65150' = '1'  /* QUADS W FETAL LOSS-UNSP */
'65151' = '1'  /* QUADS W FETAL LOSS-DEL */
'65153' = '1'  /* QUADS W FETAL LOSS-ANTE */
'65160' = '1'  /* MULT GES W FET LOSS-UNSP */
'65161' = '1'  /* MULT GES W FET LOSS-DEL */
'65163' = '1'  /* MULT GES W FET LOSS-ANTE */
'65180' = '1'  /* MULTI GESTAT NEC-UNSPEC */
'65181' = '1'  /* MULTI GESTAT NEC-DELIVER */
'65183' = '1'  /* MULTI GEST NEC-ANTEPART */
'65190' = '1'  /* MULTI GESTAT NOS-UNSPEC */
'65191' = '1'  /* MULT GESTATION NOS-DELIV */
'65193' = '1'  /* MULTI GEST NOS-ANTEPART */
'65220' = '1'  /* BREECH PRESENTAT-UNSPEC */
'65221' = '1'  /* BREECH PRESENTAT-DELIVER */
'65223' = '1'  /* BREECH PRESENT-ANTEPART */
'65230' = '1'  /* TRANSV/OBLIQ LIE-UNSPEC */
'65231' = '1'  /* TRANSVER/OBLIQ LIE-DELIV */
'65233' = '1'  /* TRANSV/OBLIQ LIE-ANTEPAR */
'65240' = '1'  /* FACE/BROW PRESENT-UNSPEC */
'65241' = '1'  /* FACE/BROW PRESENT-DELIV */
'65243' = '1'  /* FACE/BROW PRES-ANTEPART */
'65260' = '1'  /* MULT GEST MALPRESEN-UNSP */
'65261' = '1'  /* MULT GEST MALPRES-DELIV */
'65263' = '1'  /* MULT GES MALPRES-ANTEPAR */
'65640' = '1'  /* INTRAUTERINE DEATH-UNSP */
'65641' = '1'  /* INTRAUTER DEATH-DELIVER */
'65643' = '1'  /* INTRAUTER DEATH-ANTEPART */
'66050' = '1'  /* LOCKED TWINS-UNSPECIFIED */
'66051' = '1'  /* LOCKED TWINS-DELIVERED */
'66053' = '1'  /* LOCKED TWINS-ANTEPARTUM */
'66230' = '1'  /* DELAY DEL 2ND TWIN-UNSP */
'66231' = '1'  /* DELAY DEL 2ND TWIN-DELIV */
'66233' = '1'  /* DELAY DEL 2 TWIN-ANTEPAR */
'66960' = '1'  /* BREECH EXTR NOS-UNSPEC */
'66961' = '1'  /* BREECH EXTR NOS-DELIVER */
'67810' = '1'  /* FETAL CONJOIN TWINS-UNSP */
'67811' = '1'  /* FETAL CONJOIN TWINS-DEL */
'67813' = '1'  /* FETAL CONJOIN TWINS-ANTE */
'7615 ' = '1'  /* MULT PREGNANCY AFF NB */
'V271 ' = '1'  /* DELIVER-SINGLE STILLBORN */
'V272 ' = '1'  /* DELIVER-TWINS, BOTH LIVE */
'V273 ' = '1'  /* DEL-TWINS, 1 NB, 1 SB */
'V274 ' = '1'  /* DELIVER-TWINS, BOTH SB */
'V275 ' = '1'  /* DEL-MULT BIRTH, ALL LIVE */
'V276 ' = '1'  /* DEL-MULT BRTH, SOME LIVE */
'V277 ' = '1'  /* DEL-MULT BIRTH, ALL SB */
OTHER  = '0' ;

 /* ICD-9-CM Procedure Codes: */

VALUE $PRCSE3P
'7251' = '1'  /* PART BRCH EXTRAC W FORCP */
'7252' = '1'  /* PART BREECH EXTRACT NEC */
'7253' = '1'  /* TOT BRCH EXTRAC W FORCEP */
'7254' = '1'  /* TOT BREECH EXTRAC NEC */
OTHER  = '0' ;


 /* -------------------------------------------------- */
 /* Vaginal Birth after Cesarean Section rate (PRVBAC) */
 /*   Utilization (provider) Indicator / IQI #22       */
 /* -------------------------------------------------- */

 /* Previous C-Section (Population at Risk): */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $PRVBACD
'65420' = '1'  /* PREV C-SECT NOS-UNSPEC */
'65421' = '1'  /* PREV C-SECT NOS-DELIVER */
'65423' = '1'  /* PREV C-SECT NOS-ANTEPART */
OTHER   = '0' ;

 /* Vaginal Birth (Outcome of Interest): */
 /* DRG Codes: */

VALUE $PRVAGBG
'372' = '1'  /* VAGINAL DELIVERY W COMPLICATING DIAGNOSES */
'373' = '1'  /* VAGINAL DELIVERY W/O COMPLICATING DIAGNOSES */
'374' = '1'  /* VAGINAL DELIVERY W STERILIZATION &/OR D&C */
'375' = '1'  /* VAGINAL DELIVERY W O.R. PROC EXCEPT STERIL &/OR D&C */
OTHER  = '0' ;

 /* Vaginal Birth (Outcome of Interest): */
 /* MSDRG Codes: */

VALUE $PRVAG2G
'767' = '1'  /* Vaginal delivery w sterilization &/or D&C */
'768' = '1'  /* Vaginal delivery w O.R. proc except steril &/or D&C */
'774' = '1'  /* Vaginal delivery w complicating diagnoses */
'775' = '1'  /* Vaginal delivery w/o complicating diagnoses */
OTHER  = '0' ;


 /* -------------------------------------------- */
 /* Laparoscopic Cholecystectomy rate (PRLAPO)   */
 /*   Utilization (provider) Indicator / IQI #23 */
 /* -------------------------------------------- */

 /* Laparoscopic Cholecystectomy (Outcome of Interest): */
 /* ICD-9-CM Procedure Code: */

VALUE $PRLAPOP
'5123' = '1'   /* LAPAROSCOPIC CHOLE */
OTHER  = '0' ;

 /* Cholecystectomy (Population at Risk): */
 /* ICD-9-CM Procedure Codes: */

VALUE $PRLAP2P
'5122' = '1'   /* CHOLECYSTECTOMY */
'5123' = '1'   /* LAPAROSCOPIC CHOLE */
OTHER  = '0' ;

 /* Include Only: Uncomplicated Cholecystitis and/or Cholelithiasis */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $PRLAPOD
'57400' = '1'  /* CHOLELITH W AC CHOLECYST */
'57401' = '1'  /* CHOLELITH/AC GB INF-OBST */
'57410' = '1'  /* CHOLELITH W CHOLECYS NEC */
'57411' = '1'  /* CHOLELITH/GB INF NEC-OBS */
'57420' = '1'  /* CHOLELITHIASIS NOS */
'57421' = '1'  /* CHOLELITHIAS NOS W OBSTR */
'5750 ' = '1'  /* ACUTE CHOLECYSTITIS */
'5751 ' = '1'  /* CHOLECYSTITIS NEC */
'57510' = '1'  /* CHOLECYSTITIS NOS */
'57511' = '1'  /* CHRON CHOLECYSTITIS */
'57512' = '1'  /* AC/CHR CHOLECYSTITIS */
OTHER   = '0' ;

 /* -------------------------------------------- */
 /* Incidental Appendectomy rate (PRAPPN)        */
 /*   Utilization (provider) Indicator / IQI #24 */
 /* -------------------------------------------- */

 /* Incidental Appendectomy (Outcome of Interest): */
 /* ICD-9-CM Procedure Code: */

VALUE $PRAPPNP
'471 ' = '1'   /* INCIDENTAL APPENDECTOMY */
'4711' = '1'   /* LAPAROSCOP INCID APPEND */
'4719' = '1'   /* OTH INCID APPEND */
OTHER  = '0' ;

 /* Incidental Appendectomy (Population at Risk): */
 /* ICD-9-CM Procedure Code: */

VALUE $PRAPP2P
'1711' = '1' /* LAP DIR ING HERN-GRAFT */
'1712' = '1' /* LAP INDIR ING HERN-GRAFT */
'1713' = '1' /* LAP ING HERN-GRAFT NOS */
'1721' = '1' /* LAP BIL DIR ING HRN-GRFT */
'1722' = '1' /* LAP BI INDIR ING HRN-GRF */
'1723' = '1' /* LAP BI DR/IND ING HRN-GR */
'1724' = '1' /* LAP BIL ING HERN-GRF NOS */
'412  ' = '1' /* SPLENOTOMY */
'4133 ' = '1' /* OPEN BIOPSY OF SPLEEN */
'4141 ' = '1' /* MARSUPIALIZATION OF SPLENIC CYST */
'4142 ' = '1' /* EXCISION OF LESION OR TISSUE OF SPLEEN */
'4143 ' = '1' /* PARTIAL SPLENECTOMY */
'415  ' = '1' /* TOTAL SPLENECTOMY */
'4193 ' = '1' /* EXCISION OF ACCESSORY SPLEEN */
'4194 ' = '1' /* TRANSPLANTATION OF SPLEEN */
'4195 ' = '1' /* REPAIR AND PLASTIC OPERATIONS ON SPLEEN */
'4199 ' = '1' /* OTHER OPERATIONS ON SPLEEN */
'4240 ' = '1' /* ESOPHAGECTOMY, NOS */
'4241 ' = '1' /* PARTIAL ESOPHAGECTOMY (HAS 1 CASE) */
'4242 ' = '1' /* TOTAL ESOPHAGECTOMY (HASE 1 CASE) */
'4253 ' = '1' /* INTRATHORACIC ESOPHAGEAL ANASTOMOSIS W/ INTERPOSITION OF SMALL BOWEL */
'4254 ' = '1' /* OTHER INTRATHORACIC ESOPHAGOENTEROSTOMY */
'4255 ' = '1' /* INTRATHORACIC ESOPHAGEAL ANASTOMOSIS W/ INTERPOSITION OF COLON */
'4256 ' = '1' /* OTHER INTRATHORACIC ESOPHAGOCOLOSTOMY */
'4263 ' = '1' /* ANTESTERNAL ESOPHAGEAL ANASTOMOSIS W/ INTERPOSITION OF SMALL BOWEL */
'4264 ' = '1' /* OTHER ANTESTERNAL ESOPHAGOENTEROSTOMY */
'4265 ' = '1' /* ANTESTERNAL ESOPHAGEAL ANASTOMOSIS W/ INTERPOSITION OF COLON */
'4266 ' = '1' /* OTHER ANTESTERNAL ESOPHAGOCOLOSTOMY */
'4291 ' = '1' /* LIGATION OF ESOPHAGEAL VARICES */
'430  ' = '1' /* GASTROTOMY */
'433  ' = '1' /* PYLOROMYOTOMY */
'4342 ' = '1' /* LOCAL EXCISION OF OTHER LESION OR TISSUE OF STOMACH (HAS 10 CASES) */
'4349 ' = '1' /* OTHER DESTRUCTION OF LESION OR TISSUE OF STOMACH (HAS 1 CASE) */
'435  ' = '1' /* PARTIAL GASTRECTOMY W/ ANASTOMOSIS TO ESOPHAGUS */
'436  ' = '1' /* PARTIAL GASTRECTOMY W/ ANASTOMOSIS TO DUODENUM */
'437  ' = '1' /* PARTIAL GASTRECTOMY W/ ANASTOMOSIS TO JEJUNUM */
'4381 ' = '1' /* PARTIAL GASTRECTOMY W/ JEJUNA TRANSPOSITION */
'4389 ' = '1' /* OTHER PARTIAL GASTRECTOMY */
'4391 ' = '1' /* TOTAL GASTRECTOMY W/ INTESTINAL INTERPOSITION */
'4399 ' = '1' /* OTHER TOTAL GASTRECTOMY */
'4400 ' = '1' /* VAGOTOMY, NOS */
'4401 ' = '1' /* TRUNCAL VAGOTOMY (HAS ONE CASE) */
'4402 ' = '1' /* HIGHLY SELECTIVE VAGOTOMY */
'4403 ' = '1' /* OTHER SELECTIVE VAGOTOMY */
'4411 ' = '1' /* TRANSABDOMINAL GASTROSCOPY */
'4415 ' = '1' /* OPEN BIOPSY OF STOMACH (HAS ONE CASE) */
'4421 ' = '1' /* DILATION OF PYLORUS BY INCISION */
'4429 ' = '1' /* OTHER PYLOROPLASTY HAS 6 CASES */
'4431 ' = '1' /* HIGH GASTRIC BYPASS HAS 1 CASE */
'4438 ' = '1' /* LAPAROSCOPIC GASTROENTEROSTOMY */
'4439 ' = '1' /* OTHER GASTROENTEROSTOMY */
'4440 ' = '1' /* SUTURE OF PEPTIC ULCER, NOS */
'4441 ' = '1' /* SUTURE OF GASTRIC ULCER SITE */
'4442 ' = '1' /* SUTURE OF DUODENAL ULCER SITE */
'445  ' = '1' /* REVISION OF GASTRIC ANASTOMOSIS */
'4461 ' = '1' /* SUTURE OF LACERATION OF STOMACH */
'4463 ' = '1' /* CLOSURE OF OTHER GASTRIC FISTULA HAS 14 CASES */
'4464 ' = '1' /* GASTROPEXY */
'4465 ' = '1' /* ESOPHAGOGASTROPLASTY */
'4466 ' = '1' /* OTHER PROCEDURES FOR CREATION OF ESOPHAGOGASTRIC SPHINCTERIC COMPETENCE */
'4467 ' = '1' /* LAPAROSCOPIC PROCEDURES FOR CREATION OF ESOPHAGOGASTRIC SPHINCTERIC COMPETENCE */
'4468 ' = '1' /* LAPAROSCOPIC GASTROPLASTY */
'4469 ' = '1' /* OTHER REPAIR OF STOMACH */
'4491 ' = '1' /* LIGATION OF GASTRIC VARICES */
'4492 ' = '1' /* INTRAOPERATIVE MANIPULATION OF STOMACH */
'4495 ' = '1' /* LAPAROSCOPIC GASTRIC RESTRICTIVE PROCEDURE */
'4496 ' = '1' /* LAPAROSCOPIC REVISION OF GASTRIC RESTRICTIVE PROCEDURE */
'4497 ' = '1' /* LAPAROSCOPIC REVISION OF GASTRIC RESTRICTIVE DEVICES */
'4499 ' = '1' /* GASTRIC OPERATION NEC (OCT 04) */
'4500 ' = '1' /* INCISION OF INTESTINE, NOS */
'4501 ' = '1' /* INCISION OF DUODENUM */
'4502 ' = '1' /* OTHER INCISION OF SMALL INTESTINE */
'4503 ' = '1' /* INCISION OF LARGE INTESTINE */
'4511 ' = '1' /* TRANSABDOMINAL ENDOSCOPY */
'4515 ' = '1' /* OPEN BIOPSY OF SMALL INTESTINE */
'4521 ' = '1' /* TRANSABDOMINAL ENDOSCOPY OF LARGE INTESTINE */
'4526 ' = '1' /* OPEN BIOPSY OF LARGE INTESTINE */
'4531 ' = '1' /* OTHER LOCAL EXCISION OF LESION OF DUODENUM */
'4532 ' = '1' /* OTHER DESTRUCTION OF LESION OF DUODENUM */
'4533 ' = '1' /* LOCAL EXCISION OF LESION OR TISSUE OF SMALL INTESTINE, EXCEPT DUODENUM */
'4534 ' = '1' /* OTHER DESTRUCTION OF LESION OF SMALL INTESTINE, EXCEPT DUODENUM */
'4541 ' = '1' /* EXCISION OF LESION OR TISSUE OF LARGE INTESTINE */
'4549 ' = '1' /* OTHER DESTRUCTION OF LESION OF LARGE INTESTINE */
'4550 ' = '1' /* ISOLATION OF INTESTINAL SEGMENT, NOS */
'4551 ' = '1' /* ISOLATION OF SEGMENT OF SMALL INTESTINE */
'4552 ' = '1' /* ISOLATION OF SEGMENT OF LARGE INTESTINE */
'4561 ' = '1' /* MULTIPLE SEGMENTAL RESECTION OF SMALL INTESTINE */
'4562 ' = '1' /* OTHER PARTIAL RESECTION OF SMALL INTESTINE */
'4563 ' = '1' /* TOTAL REMOVAL OF SMALL INTESTINE */
'458  ' = '1' /* TOTAL INTRA-ABDOMINAL COLECTOMY */
'4590 ' = '1' /* INTESTINAL ANASTOMOSIS, NOS */
'4591 ' = '1' /* SMALL-TO-SMALL INTESTINAL ANASTOMOSIS */
'4592 ' = '1' /* ANASTOMOSIS OF SMALL INTESTINE TO RECTAL STUMP */
'4593 ' = '1' /* OTHER SMALL-TO-LARGE INTESTINAL ANASTOMOSIS */
'4594 ' = '1' /* LARGE-TO-LARGE INTESTINAL ANASTOMOSIS */
'4595 ' = '1' /* ANASTOMOSIS TO ANUS */
'4601 ' = '1' /* EXTERIORIZATION OF SMALL INTESTINE */
'4603 ' = '1' /* EXTERIORIZATION OF LARGE INTESTINE */
'4610 ' = '1' /* COLOSTOMY, NOS */
'4611 ' = '1' /* TEMPORARY COLOSTOMY */
'4613 ' = '1' /* PERMANENT COLOSTOMY */
'4614 ' = '1' /* DELAYED OPENING OF COLOSTOMY */
'4620 ' = '1' /* ILEOSTOMY, NOS */
'4621 ' = '1' /* TEMPORARY ILESOSTOMY */
'4622 ' = '1' /* CONTINENT ILEOSTOMY */
'4623 ' = '1' /* OTHER PERMANENT ILEOSTOMY */
'4640 ' = '1' /* REVISION OF INTESTINA STOMA, NOS */
'4641 ' = '1' /* REVISION OF STOMA OF SMALL INTESTINE */
'4642 ' = '1' /* REPAIR OF PERICOLOSTOMY HERNIA */
'4643 ' = '1' /* OTHER REVISION OF STOMA OF LARGE INTESTINE */
'4650 ' = '1' /* CLOSURE OF INTESTINAL STOMA, NOT OTHERWISE SPECIFIED */
'4651 ' = '1' /* CLOSURE OF STOMA OF SMALL INTESTINE */
'4652 ' = '1' /* CLOSURE OF STOMA OF LARGE INTESTINE */
'4660 ' = '1' /* FIXATION OF INTESTINE, NOS */
'4661 ' = '1' /* FIXATION OF SMALL INTESTINE TO ABDOMINAL WALL */
'4662 ' = '1' /* OTHER FIXATION OF SMALL INTESTINE */
'4663 ' = '1' /* FIXATION OF LARGE INTESTINE TO ABDOMINAL WALL */
'4664 ' = '1' /* OTHER FIXATION OF LARGE INTESTINE */
'4672 ' = '1' /* CLOSURE OF FISTULA OF DUODENUM */
'4673 ' = '1' /* SUTURE OF LACERATION OF SMALL INTESTINE, EXCEPT DUODENUM */
'4674 ' = '1' /* CLOSURE OF FISTULA OF SMALL INTESTINE, EXCEPT DUODENUM */
'4675 ' = '1' /* SUTURE OF LACERATION OF LARGE INTESTINE */
'4676 ' = '1' /* CLOSURE OF FISTULA OF LARGE INTESTINE */
'4679 ' = '1' /* OTHER REPAIR OF INTESTINE */
'4680 ' = '1' /* INTRA-ABDOMINAL MANIPULATION OF INTESTINE, NOS */
'4681 ' = '1' /* INTRA-ABDOMINAL MANIPULATION OF SMALL INTESTINE */
'4682 ' = '1' /* INTRA-ABDOMINAL MANIPULATION OF LARGE INTESTINE */
'4691 ' = '1' /* MYOTOMY OF SIGMOID COLON */
'4692 ' = '1' /* MYOTOMY OF OTHER PARTS OF COLON */
'4693 ' = '1' /* REVISION OF ANASTOMOSIS OF SMALL INTESTINE */
'4694 ' = '1' /* REVISION OF ANASTOMOSIS OF LARGE INTESTINE */
'4697 ' = '1' /* TRANSPLANT OF INTESTINE */
'4699 ' = '1' /* OTHER OPERATIONS ON INTESTINES */
'4821 ' = '1' /* TRANSABDOMINAL PROCTOSIGMOIDOSCOPY */
'4825 ' = '1' /* OPEN BIOPSY OF RECTUM */
'4840' = '1' /* PULL-THRU RES RECTUM NOS */
'4841 ' = '1' /* SUBMUCOSAL RESECTION OF RECTUM */
'4842' = '1' /* LAP PULL-THRU RES RECTUM */
'4843' = '1' /* OPN PULL-THRU RES RECTUM */
'4849 ' = '1' /* OTHER PULL-THROUGH RESECTION OF RECTUM */
'485  ' = '1' /* ABDOMINOPERINEAL RESECTION OF RECTUM */
'4850' = '1' /* ABDPERNEAL RES RECTM NOS */
'4851' = '1' /* LAP ABDPERNEAL RESC REC */
'4852' = '1' /* OPN ABDPERNEAL RESC REC */
'4859' = '1' /* ABDPERNEAL RESC RECT NEC */
'4871 ' = '1' /* SUTURE OF LACERATION OF RECTUM */
'4874 ' = '1' /* RECTORECTOSTOMY */
'4875 ' = '1' /* ABDOMINAL PROCTOPEXY */
'500  ' = '1' /* HEPATOTOMY */
'5012 ' = '1' /* OPEN BIOPSY OF LIVER */
'5014 ' = '1' /* LAPAROPSCOPIC LIVER BIOPSY */
'5019 ' = '1' /* OTHER DIAGNOSTIC PROCEDURES ON LIVER */
'5021 ' = '1' /* MARSUPIALIZATION OF LESION OF LIVER */
'5022 ' = '1' /* PARTIAL HEPATECTOMY HAS 3 CASES */
'5023 ' = '1' /* OPN ABLTN LIVER LES/TISS OCT06- */
'5025 ' = '1' /* LAPAROPSCOPIC ABLATION OF LIVER LESION OR TISSUE */
'5026 ' = '1' /* ABLTN LIVER LES/TISS NEC OCT06- */
'5029 ' = '1' /* OTHER DESTRUCTION OF LESION OF LIVER HAS 2 CASES */
'503  ' = '1' /* LOBECTOMY OF LIVER */
'504  ' = '1' /* TOTAL HEPATECTOMY */
'5051 ' = '1' /* AUXILIARY LIVER TRANSPLANT */
'5059 ' = '1' /* OTHER TRANSPLANT OF LIVER */
'5061 ' = '1' /* CLOSURE OF LACERATION OF LIVER */
'5069 ' = '1' /* OTHER REPAIR OF LIVER */
'5102 ' = '1' /* TROCAR CHOLECYSTOSTOMY */
'5103 ' = '1' /* OTHER CHOLECYSTOSTOMY */
'5104 ' = '1' /* OTHER CHOLECYSTOTOMY */
'5113 ' = '1' /* OPEN BIOPSY OF GALLBLADDER OR BILE DUCTS */
'5119 ' = '1' /* OTHER DIAGNOSTIC PROCEDURES ON BILIARY TRACT */
'5121 ' = '1' /* OTHER PARTIAL CHOLECYSTECTOMY */
'5122 ' = '1' /* CHOLECYSTECTOMY */
'5123 ' = '1' /* LAPAROSCOPIC CHOLECYSTECTOMY SE 5122 WITH 116 CASES, THIS ONE HAS 7 CASES */
'5124 ' = '1' /* LAPAROSCOPIC PARTIAL CHOLECYSTECTOMY  */
'5131 ' = '1' /* ANASTOMOSIS OF GALLBLADDER TO HEPATIC DUCTS */
'5132 ' = '1' /* ANASTOMOSIS OF GALLBLADDER TO INTESTINE */
'5133 ' = '1' /* ANASTOMOSIS OF GALLBLADDER TO PANCREAS */
'5134 ' = '1' /* ANASTOMOSIS OF GALLBLADDER TO STOMACH */
'5135 ' = '1' /* OTHER GALLBLADDER ANASTOMOSIS */
'5136 ' = '1' /* CHOLEDOCHOENTEROSTOMY */
'5137 ' = '1' /* ANASTOMOSIS OF HEPATIC DUCT TO GASTROINTESTINAL TRACT */
'5139 ' = '1' /* OTHER BILE DUCT ANASTOMOSIS */
'5141 ' = '1' /* COMMON DUCT EXPLORATION FOR REMOVAL OF CALCULUS */
'5142 ' = '1' /* COMMON DUCT EXPLORATION FOR RELIEF OF OTHER OBSTRUCTION */
'5143 ' = '1' /* INSERTION OF CHOLEDOCHOHEPATIC TUBE FOR DECOMPRESSION */
'5149 ' = '1' /* INCISION OF OTHER BILE DUCTS FOR RELIEF OF OBSTRUCTION */
'5151 ' = '1' /* EXPLORATION OF COMMON DUCT */
'5159 ' = '1' /* INCISION OF OTHER BILE DUCT */
'5161 ' = '1' /* EXCISION OF CYSTIC DUCT REMNANT */
'5162 ' = '1' /* EXCISION OF AMPULLA OF VATER (WITH REIMPLANTATION OF COMMON DUCT) */
'5163 ' = '1' /* OTHER EXCISION OF COMMON DUCT */
'5169 ' = '1' /* EXCISION OF OTHER BILE DUCT */
'5171 ' = '1' /* SIMPLE SUTURE OF COMMON BILE DUCT */
'5172 ' = '1' /* CHOLEDOCHOPLASTY */
'5179 ' = '1' /* REPAIR OF OTHER BILE DUCTS */
'5181 ' = '1' /* DILATION OF SPHINCTER OF ODDI */
'5182 ' = '1' /* PANCREATIC SPHINCTEROTOMY */
'5183 ' = '1' /* PANCREATIC SPHINCTEROPLASTY */
'5189 ' = '1' /* OTHER OPERATIONS ON SPHINCTER OF ODDI */
'5191 ' = '1' /* REPAIR OF LACERATION OF GALLBLADDER */
'5192 ' = '1' /* CLOSURE OF CHOLECYSTOSTOMY */
'5193 ' = '1' /* CLOSURE OF OTHER BILIARY FISTULA */
'5194 ' = '1' /* REVISION OF ANASTOMOSIS OF BILIARY TRACT */
'5195 ' = '1' /* REMOVAL OF PROSTHETIC DEVICE FROM BILE DUCT */
'5199 ' = '1' /* OTHER OPERATIONS ON BILIARY TRACT */
'5201 ' = '1' /* DRAINAGE OF PANCREATIC CYST BY CATHETER */
'5209 ' = '1' /* OTHER PANCREATOTOMY */
'5212 ' = '1' /* OPEN BIOPSY OF PANCREAS */
'5219 ' = '1' /* OTHER DIAGNOSTIC PROCEDURES ON PANCREAS */
'5222 ' = '1' /* OTHER EXCISION OR DESTRUCT OF LESION OR TISSUE OF PANCREAS OR PANC DUCT */
'523  ' = '1' /* MARSUPIALIZATION OF PANCREATIC CYST */
'524  ' = '1' /* INTERNAL DRAINAGE OF PANCREATIC CYST */
'5251 ' = '1' /* PROXIMAL PANCREATECTOMY */
'5252 ' = '1' /* DISTAL PANCREATECTOMY */
'5253 ' = '1' /* RADICAL SUBTOTAL PANCREATECTOMY */
'5259 ' = '1' /* OTHER PARTIAL PANCREATECTOMY (HAS 1 CASE) */
'526  ' = '1' /* TOTAL PANCREATECTOMY */
'527  ' = '1' /* RADICAL PANCREATICODUODENECTOMY */
'5280 ' = '1' /* PANCREATIC TRANSPLANT, NOS */
'5281 ' = '1' /* REIMPLANTATION */
'5282 ' = '1' /* HOMOTRANSPLANT OF PANCREAS */
'5283 ' = '1' /* HETEROTRANSPLANT OF PANCREAS */
'5292 ' = '1' /* CANNULATION OF PANCREATIC DUCT */
'5295 ' = '1' /* OTHER REPAIR OF PANCREAS */
'5296 ' = '1' /* ANASTOMOSIS OF PANCREAS (HAS 1 CASE) */
'5299 ' = '1' /* OTHER OPERATIONS ON PANCREAS */
'5300 ' = '1' /* UNILATERAL REPAIR OF INGUINAL HERNIA, NOS */
'5301 ' = '1' /* REPAIR OF DIRECT INGUINAL HERNIA HAS 2 CASES */
'5302 ' = '1' /* REPAIR OF INDIRECT INGUINAL HERNIA HAS 2 CASES */
'5303 ' = '1' /* REPAIR OF DIRECT INGUINAL HERNIA W/ GRAFT OR PROSTHESIS HAS 1 CASE */
'5304 ' = '1' /* REPAIR OF INDIRECT INGUINAL HERNIA W/ GRAFT OR PROSTHESIS */
'5305 ' = '1' /* REPAIR OF INGUINAL HERNIA W/ GRAFT OR PROSTHESIS, NOS */
'5310 ' = '1' /* BILATERAL REPAIR OF INGUINAL HERNIA, NOS */
'5311 ' = '1' /* BILATERAL REPAIR OF DIRECT INGUINAL HERNIA HAS 1 CASE */
'5312 ' = '1' /* BILATERAL REPAIR OF INDIRECT INGUINAL HERNIA */
'5313 ' = '1' /* BILATERAL REPAIR OF INGUINAL HERNIA, ONE DIRECT AND ONE INDIRECT */
'5314 ' = '1' /* BILATERAL REPAIR OF DIRECT INGUINAL HERNIA W/ GRAFT OR PROSTHESIS */
'5315 ' = '1' /* BILATERAL REPAIR OF INDIRECT INGUINAL HERNIA W/ GRAFT OR PROSTHESIS */
'5316 ' = '1' /* BILATERAL REPAIR OF INGUIN HERNIA, 1 DIRECT 1 INDIRECT, W/ GRAFT OR PROS */
'5317 ' = '1' /* BILATERAL INGUINAL HERNIA REPAIR W/ GRAFT OR PROSTHESIS, NOS */
'5321 ' = '1' /* UNILATERAL REPAIR OF FEMORAL HERNIA */
'5329 ' = '1' /* OTHER UNILATERAL FEMORAL HERNIORRHAPHY HAS 1 CASE */
'5331 ' = '1' /* BILATERAL REPAIR OF FEMORAL HERNIA W/ GRAFT OR PROSTHESIS */
'5339 ' = '1' /* OTHER BILATERAL FEMORAL HERNIORRHAPHY */
'5341 ' = '1' /* REPAIR OF UMBILICAL HERNIA W/ PROSTHESIS */
'5342' = '1' /* LAP UMBIL HERNIA-GRAFT */
'5343' = '1' /* LAP UMBILICAL HERNIA NEC */
'5349 ' = '1' /* OTHER UMBILICAL HERNIORRHAPHY HAS 2 CASES */
'5351 ' = '1' /* INCISIONAL HERNIA REPAIR HAS 2 CASES */
'5359 ' = '1' /* REPAIR OF OTHER HERNIA OF ANTERIOR ABDOMINAL WALL (HAS 5 CASES) */
'5361 ' = '1' /* INCISIONAL HERNIA REPAIR W/ PROSTHESIS (HAS 6 CASES) */
'5362' = '1' /* LAP INCIS HERN REPR-GRFT */
'5363' = '1' /* LAP HERN ANT ABD-GFT NEC */
'5369 ' = '1' /* REPAIR OF OTHER HERNIA OF ANTERIOR ABDOMINAL WALL W/ PROSTHESIS HAS 1 CASE */
'537  ' = '1' /* REPAIR OF DIAPHRAGMATIC HERNIA, ABDOMINAL APPROACH */
'5371' = '1' /* LAP ABD REP-DIAPHR HERN */
'5372' = '1' /* OPN ABD DIAPHRM HERN NEC */
'5375' = '1' /* ABD REP-DIAPHR HERN NOS */
'540  ' = '1' /* INCISION OF ABDOMINAL WALL */
'5411 ' = '1' /* EXPLORATORY LAPAROTOMY */
'5412 ' = '1' /* REOPENING OF RECENT LAPAROTOMY SITE */
'5419 ' = '1' /* OTHER LAPAROTOMY */
'5421 ' = '1' /* LAPAROSCOPY */
'5422 ' = '1' /* BIOPSY OF ABDOMINAL WALL OR UMBILICUS */
'5423 ' = '1' /* BIOPSY OF ABDOMINAL WALL OR UMBILICUS (HAS 2 CASES) */
'5429 ' = '1' /* OTHER DIAGNOSTIC PROCEDURES ON ABDOMINAL REGION */
'543  ' = '1' /* EXCISION OR DESTRUCTION OF LESION OR TISSUE OF ABDOMINAL WALL OR UMBILICUS */
'544  ' = '1' /* EXCISION OR DESTRUCTION OF PERITONEAL TISSUE */
'5451 ' = '1' /* LAPAROSCOPIC LYSIS OF PERITONEAL ADHESIONS */
'5459 ' = '1' /* OTHER LYSIS OF PERITONEAL ADHESIONS HAS 463 CASES */
'5461 ' = '1' /* RECLOSURE OF POSTOPERATIVE DISRUPTION OF ABDOMINAL WALL */
'5462 ' = '1' /* DELAYED CLOSURE OF GRANULATING ABDOMINAL WOUND */
'5463 ' = '1' /* OTHER SUTURE OF ABDOMINAL WALL */
'5464 ' = '1' /* SUTURE OF PERITONEUM */
'5471 ' = '1' /* REPAIR OF GASTROSCHISIS */
'5472 ' = '1' /* OTHER REPAIR OF ABDOMINAL WALLS */
'5473 ' = '1' /* OTHER REPAIR OF PERITONEUM */
'5474 ' = '1' /* OTHER REPAIR OF OMENTUM */
'5475 ' = '1' /* OTHER REPAIR OF MESENTERY */
'5492 ' = '1' /* REMOVAL OF FOREIGN BODY FROM PERITONEAL CAVITY HAS 1 CASE */
'5493 ' = '1' /* CREATION OF CUTANEOPERITONEAL FISTULA */
'5494 ' = '1' /* CREATION OF PERITONEOVASCULAR SHUNT */
'5495 ' = '1' /* INCISION OF PERITONEUM */
'5651 ' = '1' /* FORMATION OF CUTANEOUS URETERO-ILEOSTOMY */
'5652 ' = '1' /* REVISION OF CUTANEOUS URETERO-ILEOSTOMY */
'5661 ' = '1' /* FORMATION OF OTHER CUTANEOUS URETEROSTOMY */
'5662 ' = '1' /* REVISION OF OTHER CUTANEOUS URETEROSTOMY */
'5671 ' = '1' /* URINARY DIVERSION TO INTESTINE */
'5672 ' = '1' /* REVISION OF URETEROINTESTINAL ANASTOMOSIS */
'5900 ' = '1' /* RETROPERITONEAL DISSECTION, NOS */
'6501 ' = '1' /* LAPAROSCOPIC OOPHOROTOMY */
'6509 ' = '1' /* OTHER OOPHORECTOMY */
'6512 ' = '1' /* OTHER BIOPSY OF OVARY */
'6521 ' = '1' /* MARSUPIALIZATION OF OVARIAN CYST */
'6522 ' = '1' /* WEDGE RESECTION OF OVARY */
'6523 ' = '1' /* LAPAROSCOPIC MARSUPIALIZATION OF OVARIAN CYST */
'6524 ' = '1' /* LAPAROSCOPIC WEDGE RESECTION OF OVARY */
'6525 ' = '1' /* OTHER LAPAROSCOPIC LOCAL EXCISION OR DESTRUCTION OF OVARY */
'6529 ' = '1' /* OTHER LOCAL EXCISION OR DESTRUCTION OF OVARY */
'6531 ' = '1' /* LAPAROSCOPIC UNILATERAL OOPHORECTOMY */
'6539 ' = '1' /* OTHER UNLILATERAL OOPHORECTOMY */
'6541 ' = '1' /* LAPAROSCOPIC UNILATERAL SALPINGO-OOPHORECTOMY */
'6549 ' = '1' /* OTHER UNILATERAL SALPINGOOPHORECTOMY */
'6551 ' = '1' /* OTHER REMOVAL OF BOTH OVARIES AT SAME OPERATIVE EPISODE */
'6552 ' = '1' /* OTHER REMOVAL OF REMAINING OVARY */
'6553 ' = '1' /* LAPAROSCOPIC REMOVAL OF BOTH OVARIES AT SAME OPERATIVE EPISODE */
'6554 ' = '1' /* LAPAROSCOPIC REMOVAL OF REMAINING OVARY */
'6561 ' = '1' /* OTHER REMOVAL OF BOTH OVARIES AND TUBES AT SAME OPERATIVE EPISODE */
'6562 ' = '1' /* OTHER REMOVAL OF REMAINING OVARY AND TUBE */
'6563 ' = '1' /* LAPAROSCOPIC REMOVAL OF BOTH OVARIES AND TUBES AT SAME OPERATIVE EPISODE */
'6564 ' = '1' /* LAPAROSCOPIC REMOVAL OF REMAINING OVARY AND TUBE */
'6571 ' = '1' /* OTHER SIMPLE SUTURE OF OVARY */
'6572 ' = '1' /* OTHER REIMPLANTATION OF OVARY */
'6573 ' = '1' /* OTHER SALPINGO OOPHOROPLASTY */
'6574 ' = '1' /* LAPAROSCOPIC SIMPLE SUTURE OF OVARY */
'6575 ' = '1' /* LAPAROSCOPIC REIMPLANTATION OF OVARY */
'6576 ' = '1' /* LAPAROSCOPIC SALPINGO-OOPHOROPLASTY */
'6579 ' = '1' /* OTHER REPAIR OF OVARY */
'6581 ' = '1' /* LAPAROSCOPIC LYSIS OF ADHESIONS OF OVARY AND FALLOPIAN TUBE */
'6589 ' = '1' /* OTHER LYSIS OF ADHESIONS OF OVARY AND FALLOPIAN TUBE */
'6592 ' = '1' /* TRANSPLANTATION OF OVARY */
'6593 ' = '1' /* MANUAL RUPTURE OF OVARIAN CYST */
'6594 ' = '1' /* OVARIAN DENERVATION */
'6595 ' = '1' /* RELEASE OF TORSION OF OVARY */
'6599 ' = '1' /* OTHER OPERATIONS ON OVARY */
'6601 ' = '1' /* SALPINGOTOMY */
'6602 ' = '1' /* SALPINGOSTOMY */
'6611 ' = '1' /* BIOPSY OF FALLOPIAN TUBE */
'6619 ' = '1' /* OTHER DIAGNOSTIC PROCEDURES ON FALLOPIAN TUBES */
'6631 ' = '1' /* OTHER BILATERAL LIGATION AND CRUSHING OF FALLOPIAN TUBES */
'6632 ' = '1' /* OTHER BILATERAL LIGATION AND DIVISION OF FALLOPIAN TUBES */
'6639 ' = '1' /* OTHER BILATERAL DESTRUCTION OR OCCLUSION OF FALLOPIAN TUBES */
'664  ' = '1' /* TOTAL UNILATERAL SALPINGECTOMY */
'6651 ' = '1' /* REMOVAL OF BOTH FALLOPIAN TUBES AT SAME OPERATIVE EPISODE */
'6652 ' = '1' /* REMOVAL OF REMAINING FALLOPIAN TUBE */
'6661 ' = '1' /* EXCISION OR DESTRUCTION OF LESION OF FALLOPIAN TUBE */
'6662 ' = '1' /* SALPINGECTOMY W/ REMOVAL OF TUBAL PREGNANCY */
'6663 ' = '1' /* BILATERAL PARTIAL SALPINGECTOMY, NOS */
'6669 ' = '1' /* OTHER PARTIAL SALPINGECTOMY */
'6671 ' = '1' /* SIMPLE SUTURE OF FALLOPIAN TUBE */
'6672 ' = '1' /* SALPINGO-OOPHOROSTOMY */
'6673 ' = '1' /* SALPINGO-SALPINGOSTOMY */
'6674 ' = '1' /* SALPINGO-UTEROSTOMY */
'6679 ' = '1' /* OTHER REPAIR OF FALLOPIAN TUBE */
'6692 ' = '1' /* UNILATERAL DESTRUCTION OR OCCLUSION OF FALLOPIAN TUBE */
'6693 ' = '1' /* IMPLANTATION OR REPLACEMENT OF PROSTHESIS OF FALLOPIAN TUBE */
'6694 ' = '1' /* REMOVAL OF PROSTHESIS OF FALLOPIAN TUBE */
'6696 ' = '1' /* DILATION OF FALLOPIAN TUBE */
'6697 ' = '1' /* BURYING OF FIMBRIAE IN UTERINE WALL */
'6699 ' = '1' /* OTHER OPERATION OF FALLOPIAN TUBE */
'680  ' = '1' /* OTHER INCISION AND EXCISION OF UTERUS */
'6813 ' = '1' /* OPEN BIOPSY OF UTERUS */
'6814 ' = '1' /* OPEN BIOPSY OF UTERINE LIGAMENTS */
'6819 ' = '1' /* OTHER DIAGNOSTIC PROCEDURES ON UTERUS AND SUPPORTING STRUCTURES */
'6823 ' = '1' /* ENDOMETRIAL ABLATION */
'6829 ' = '1' /* OTHER EXCISION OR DESTRUCTION OF LESION OF UTERUS */
'683  ' = '1' /* SUBTOTAL ABDOMINAL HYSTERECTOMY */
'6831 ' = '1' /* LAPAROSCOPIC SUPRACERVICAL HYSTERECTOMY [LSH] */
'6839 ' = '1' /* OTHER SUBTOTAL ABDOMINAL HYSTERECTOMY */
'684  ' = '1' /* TOTAL ABDOMINAL HYSTERECTOMY */
'6841 ' = '1' /* LAP TOTAL ABDOMINAL HYST OCT06- */
'6849 ' = '1' /* TOTAL ABD HYST NEC/NOS OCT06- */
'686  ' = '1' /* RADICAL ABDOMINAL HYSTERECTOMY */
'6861 ' = '1' /* LAP RADICAL ABDOMNL HYST OCT06- */
'6869 ' = '1' /* RADICAL ABD HYST NEC/NOS OCT06- */
'688  ' = '1' /* PELVIC EVISCERATION */
'689  ' = '1' /* OTHER AND UNSPECIFIED HYSTERECTOMY */
'6919 ' = '1' /* OTHER EXCISION OR DESTRUCTION OF UTERUS AND SUPPORTING STRUCTURES */
'6921 ' = '1' /* INTERPOSITION OPERATION */
'6922 ' = '1' /* OTHER UTERINE SUSPENSION */
'6923 ' = '1' /* VAGINAL REPAIR OF CHRONIC INVERSION OF UTERUS */
'6929 ' = '1' /* OTHER REPAIR OF UTERUS AND SUPPORTING STRUCTURES */
'693  ' = '1' /* PARACERVICAL UTERINE DENERVATION */
'6941 ' = '1' /* SUTURE OF LACERATION OF UTERUS */
'6942 ' = '1' /* CLOSURE OF FISTULA OF UTERUS */
'6949 ' = '1' /* OTHER REPAIR OF UTERUS */
'6998 ' = '1' /* OTHER OPERATIONS ON SUPPORTING STRUCTURES OF UTERUS */
OTHER  = '0' ;

 /* Exclude: Colectomy or Pelvic Evisceration */
 /* ICD-9-CM Procedure Code: */

VALUE $PRAPP3P
'1731' = '1' /* LAP MUL SEG RES LG INTES */
'1732' = '1' /* LAPAROSCOPIC CECECTOMY */
'1733' = '1' /* LAP RIGHT HEMICOLECTOMY */
'1734' = '1' /* LAP RES TRANSVERSE COLON */
'1735' = '1' /* LAP LEFT HEMICOLECTOMY */
'1736' = '1' /* LAP SIGMOIDECTOMY */
'1739' = '1' /* LAP PT EX LRG INTEST NEC */
'4571' = '1' /* OPN MUL SEG LG INTES NEC */
'4572' = '1' /* OPEN CECECTOMY NEC */
'4573' = '1' /* OPN RT HEMICOLECTOMY NEC */
'4574' = '1' /* OPN TRANSV COLON RES NEC */
'4575' = '1' /* OPN LFT HEMICOLECTMY NEC */
'4576' = '1' /* OPEN SIGMOIDECTOMY NEC */
'4579' = '1' /* PRT LG INTES EXC NEC/NOS */
'458 ' = '1' /* TOT ABD COLECTMY */
'4581' = '1' /* LAP TOT INTR-AB COLECTMY */
'4582' = '1' /* OP TOT INTR-ABD COLECTMY */
'4583' = '1' /* TOT ABD COLECTMY NEC/NOS */
'688 ' = '1' /* PELVIC EVISCERATION */
OTHER  = '0' ;

 /* Exclude: Cancer adj to appendix */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $PRAPPND
'1534' = '1' /*  MALIGNANT NEOPLASM CECUM */
'1535' = '1' /*  MALIGNANT NEO APPENDIX */
'1536' = '1' /*  MALIG NEO ASCEND COLON */
'1538' = '1' /*  MALIGNANT NEO COLON NEC */
'1539' = '1' /*  MALIGNANT NEO COLON NOS */
'1588' = '1' /*  MAL NEO PERITONEUM NEC */
'1589' = '1' /*  MAL NEO PERITONEUM NOS */
'1590' = '1' /*  MALIG NEO INTESTINE NOS */
'1598' = '1' /*  MAL NEO GI/INTRA-ABD NEC */
'1599' = '1' /*  MAL NEO GI TRACT ILL-DEF */
'1952' = '1' /*  MALIG NEO ABDOMEN */
'1975' = '1' /*  SEC MALIG NEO LG BOWEL */
'1976' = '1' /*  SEC MAL NEO PERITONEUM */
OTHER  = '0' ;

 /* Intra-Abdominal Procedure (Population at Risk): */
 /* DRGs: */

VALUE PRAPPNG
146 = '1'     /* RECTAL RESECTION W CC */
147 = '1'     /* RECTAL RESECTION W/O CC */
148 = '1'     /* MAJ BOWEL PROC W CC */
149 = '1'     /* MAJ BOWEL PROC W/0 CC */
150 = '1'     /* PERITONEAL ADHES W CC */
151 = '1'     /* PERITONEAL ADHES W/O CC */
152 = '1'     /* MIN BOWEL PROC W CC */
153 = '1'     /* MIN BOWEL PROC W/O CC */
154 = '1'     /* UGI PROC AGE >17 W CC */
155 = '1'     /* UGI PROC AGE >17 W/O CC */
170 = '1'     /* OTH GI OR PROC W CC */
171 = '1'     /* OTH GI OR PROC W/O CC */
191 = '1'     /* PANC LVR SHNT PRC W CC */
192 = '1'     /* PANC LVR SHNT PRC W/O CC */
193 = '1'     /* BILIARY PROC W/ CC */
194 = '1'     /* BILIARY PROC W/O CC */
195 = '1'     /* CHOLE W/ CDE W/ CC */
196 = '1'     /* CHOLE W/ CDE W/O CC */
197 = '1'     /* CHOLE W/ CC */
198 = '1'     /* CHOLE W/O CC */
201 = '1'     /* OTH BILIARY/PANC PROC */
354 = '1'     /* UTER PROC MALIG W/ CC */
355 = '1'     /* UTER PROC MALIG W/O CC */
356 = '1'     /* FEMALE REPROD RECONSTR */
357 = '1'     /* UTER PROC OVARIAN MALIG */
358 = '1'     /* UTER PROC NONMALIG W/ CC */
359 = '1'     /* UTER PROC NONMALI W/O CC */
365 = '1'     /* OTH FEMAL REPROD PROC */
567 = '1'     /* STOMACH, ESOPHAGEAL & DUODENAL PROC AGE > 17 W CC W MAJOR GI DX */
568 = '1'     /* STOMACH, ESOPHAGEAL & DUODENAL PROCEDURES PROC AGE > 17 W CC W/O MAJOR GI DX */
569 = '1'     /* MAJOR SMALL & LARGE BOWEL PROCEDURES W CC W MAJOR GI DX */
570 = '1'     /* MAJOR SMALL & LARGE BOWEL PROCEDURES W CC W/O MAJOR GI DX */
OTHER = '0' ;

 /* -------------------------------------------- */
 /* Bi-lateral Catheterization rate (PRCATH)     */
 /*   Utilization (provider) Indicator / IQI #25 */
 /* -------------------------------------------- */

 /* Bi-lateral Catheterization (Outcome of Interest): */
 /* ICD-9-CM Procedure Code: */

VALUE $PRCATHP
'3723' = '1'  /* RT/LEFT HEART CARD CATH */
OTHER  = '0' ;

 /*  Catheterization (Population at Risk) */
 /* ICD-9-CM Procedure Code: */

VALUE $PRCAT2P
'3722' = '1'  /* LEFT HEART CARDIAC CATH */
'3723' = '1'  /* RT/LEFT HEART CARD CATH */
OTHER  = '0' ;

 /* Include only: Coronary artery disease */
 /* ICD-9-CM Diagnosis Code: */

VALUE $PRCATHD
'41000' = '1'  /* AMI ANTEROLATERAL,UNSPEC */
'41001' = '1'  /* AMI ANTEROLATERAL, INIT */
'41002' = '1'  /* AMI ANTEROLATERAL,SUBSEQ */
'41010' = '1'  /* AMI ANTERIOR WALL,UNSPEC */
'41011' = '1'  /* AMI ANTERIOR WALL, INIT */
'41012' = '1'  /* AMI ANTERIOR WALL,SUBSEQ */
'41020' = '1'  /* AMI INFEROLATERAL,UNSPEC */
'41021' = '1'  /* AMI INFEROLATERAL, INIT */
'41022' = '1'  /* AMI INFEROLATERAL,SUBSEQ */
'41030' = '1'  /* AMI INFEROPOST, UNSPEC */
'41031' = '1'  /* AMI INFEROPOST, INITIAL */
'41032' = '1'  /* AMI INFEROPOST, SUBSEQ */
'41040' = '1'  /* AMI INFERIOR WALL,UNSPEC */
'41041' = '1'  /* AMI INFERIOR WALL, INIT */
'41042' = '1'  /* AMI INFERIOR WALL,SUBSEQ */
'41050' = '1'  /* AMI LATERAL NEC, UNSPEC */
'41051' = '1'  /* AMI LATERAL NEC, INITIAL */
'41052' = '1'  /* AMI LATERAL NEC, SUBSEQ */
'41060' = '1'  /* TRUE POST INFARCT,UNSPEC */
'41061' = '1'  /* TRUE POST INFARCT, INIT */
'41062' = '1'  /* TRUE POST INFARCT,SUBSEQ */
'41070' = '1'  /* SUBENDO INFARCT, UNSPEC */
'41071' = '1'  /* SUBENDO INFARCT, INITIAL */
'41072' = '1'  /* SUBENDO INFARCT, SUBSEQ */
'41080' = '1'  /* AMI NEC, UNSPECIFIED */
'41081' = '1'  /* AMI NEC, INITIAL */
'41082' = '1'  /* AMI NEC, SUBSEQUENT */
'41090' = '1'  /* AMI NOS, UNSPECIFIED */
'41091' = '1'  /* AMI NOS, INITIAL */
'41092' = '1'  /* AMI NOS, SUBSEQUENT */
'4110 ' = '1'  /* POST MI SYNDROME */
'4111 ' = '1'  /* INTERMED CORONARY SYND */
'41181' = '1'  /* CORONARY OCCLSN W/O MI */
'41189' = '1'  /* AC ISCHEMIC HRT DIS NEC */
'412  ' = '1'  /* OLD MYOCARDIAL INFARCT */
'4130 ' = '1'  /* ANGINA DECUBITUS */
'4131 ' = '1'  /* PRINZMETAL ANGINA */
'4139 ' = '1'  /* ANGINA PECTORIS NEC/NOS */
'4140 ' = '1'  /* CORONARY ATHEROSCLEROSIS */
'41400' = '1'  /* COR ATH UNSP VSL NTV/GFT */
'41401' = '1'  /* CRNRY ATHRSCL NATVE VSSL */
'41402' = '1'  /* CRN ATH ATLG VN BPS GRFT */
'41403' = '1'  /* CRN ATH NONATLG BLG GRFT */
'41404' = '1'  /* COR ATH ARTRY BYPAS GRFT */
'41405' = '1'  /* COR ATH BYPASS GRAFT NOS */
'41406' = '1'  /* COR ATH NATV ART TP HRT */
'41407' = '1'  /* COR ATH BPS GRAFT TP HRT */
'41410' = '1'  /* ANEURYSM, HEART (WALL) */
'41411' = '1'  /* CORONARY VESSEL ANEURYSM */
'41412' = '1'  /* DISSECTION COR ARTERY */
'41419' = '1'  /* ANEURYSM OF HEART NEC */
'4143 ' = '1'  /* COR ATH D/T LPD RCH PLAQ */
'4148 ' = '1'  /* CHR ISCHEMIC HRT DIS NEC */
'4149 ' = '1'  /* CHR ISCHEMIC HRT DIS NOS */
OTHER  = '0' ;

 /* Exclude: Indications for righ cath */
 /* ICD-9-CM Diagnosis Code: */

VALUE $PRCAT2D
'3910 ' = '1'  /* ACUTE RHEUMATIC PERICARD */
'3911 ' = '1'  /* ACUTE RHEUMATIC ENDOCARD */
'3912 ' = '1'  /* AC RHEUMATIC MYOCARDITIS */
'3918 ' = '1'  /* AC RHEUMAT HRT DIS NEC */
'3919 ' = '1'  /* AC RHEUMAT HRT DIS NOS */
'3920 ' = '1'  /* RHEUM CHOREA W HRT INVOL */
'3929 ' = '1'  /* RHEUMATIC CHOREA NOS */
'393  ' = '1'  /* CHR RHEUMATIC PERICARD */
'3940 ' = '1'  /* MITRAL STENOSIS */
'3941 ' = '1'  /* RHEUMATIC MITRAL INSUFF */
'3942 ' = '1'  /* MITRAL STENOSIS W INSUFF */
'3949 ' = '1'  /* MITRAL VALVE DIS NEC/NOS */
'3960 ' = '1'  /* MITRAL/AORTIC STENOSIS */
'3961 ' = '1'  /* MITRAL STENOS/AORT INSUF */
'3962 ' = '1'  /* MITRAL INSUF/AORT STENOS */
'3963 ' = '1'  /* MITRAL/AORTIC VAL INSUFF */
'3968 ' = '1'  /* MITR/AORTIC MULT INVOLV */
'3969 ' = '1'  /* MITRAL/AORTIC V DIS NOS */
'3970 ' = '1'  /* TRICUSPID VALVE DISEASE */
'3971 ' = '1'  /* RHEUM PULMON VALVE DIS */
'3979 ' = '1'  /* RHEUM ENDOCARDITIS NOS */
'3980 ' = '1'  /* RHEUMATIC MYOCARDITIS */
'39890' = '1'  /* RHEUMATIC HEART DIS NOS */
'39891' = '1'  /* RHEUMATIC HEART FAILURE */
'39899' = '1'  /* RHEUMATIC HEART DIS NEC */
'40200' = '1'  /* MAL HYPERTEN HRT DIS NOS */
'40201' = '1'  /* MAL HYPERT HRT DIS W CHF */
'40210' = '1'  /* BEN HYPERTEN HRT DIS NOS */
'40211' = '1'  /* BENIGN HYP HRT DIS W CHF */
'40290' = '1'  /* HYPERTENSIVE HRT DIS NOS */
'40291' = '1'  /* HYPERTEN HEART DIS W CHF */
'40400' = '1'  /* MAL HY HT/REN W/O HF/RF */
'40401' = '1'  /* MAL HYPER HRT/REN W HF */
'40402' = '1'  /* MAL HY HT/REN W REN FAIL */
'40403' = '1'  /* MAL HYP HRT/REN W HF/RF */
'40410' = '1'  /* BEN HY HT/REN W/O HF/RF */
'40411' = '1'  /* BEN HYPER HRT/REN W HF */
'40412' = '1'  /* BEN HY HT/REN W REN FAIL */
'40413' = '1'  /* BEN HYP HRT/REN W HF/RF */
'40490' = '1'  /* HY HT/REN NOS W/O HF/RF */
'40491' = '1'  /* HYPER HRT/REN NOS W HF */
'40492' = '1'  /* HY HT/REN NOS W REN FAIL */
'40493' = '1'  /* HYP HRT/REN NOS W HF/RF */
'4150 ' = '1'  /* ACUTE COR PULMONALE */
'4151 ' = '1'  /* PULMON EMBOLISM/INFARCT */
'41511' = '1'  /* IATROGEN PULM EMB/INFARC */
'41512' = '1'  /* SEPTIC PULMONARY EMBOLSM */
'41519' = '1'  /* PULM EMBOL/INFARCT NEC */
'4160 ' = '1'  /* PRIM PULM HYPERTENSION */
'4161 ' = '1'  /* KYPHOSCOLIOTIC HEART DIS */
'4168 ' = '1'  /* CHR PULMON HEART DIS NEC */
'4169 ' = '1'  /* CHR PULMON HEART DIS NOS */
'4170 ' = '1'  /* ARTERIOVEN FISTU PUL VES */
'4171 ' = '1'  /* PULMON ARTERY ANEURYSM */
'4178 ' = '1'  /* PULMON CIRCULAT DIS NEC */
'4179 ' = '1'  /* PULMON CIRCULAT DIS NOS */
'4200 ' = '1' /* AC PERICARDIT IN OTH DIS */
'42090' = '1' /* ACUTE PERICARDITIS NOS */
'42091' = '1' /* AC IDIOPATH PERICARDITIS */
'42099' = '1' /* ACUTE PERICARDITIS NEC */
'4210 ' = '1' /* AC/SUBAC BACT ENDOCARD */
'4211 ' = '1' /* AC ENDOCARDIT IN OTH DIS */
'4219 ' = '1' /* AC/SUBAC ENDOCARDIT NOS */
'4220 ' = '1' /* AC MYOCARDIT IN OTH DIS */
'42290' = '1' /* ACUTE MYOCARDITIS NOS */
'42291' = '1' /* IDIOPATHIC MYOCARDITIS */
'42292' = '1' /* SEPTIC MYOCARDITIS */
'42293' = '1' /* TOXIC MYOCARDITIS */
'42299' = '1' /* ACUTE MYOCARDITIS NEC */
'4230 ' = '1' /* HEMOPERICARDIUM */
'4231 ' = '1' /* ADHESIVE PERICARDITIS */
'4232 ' = '1' /* CONSTRICTIV PERICARDITIS */
'4233 ' = '1' /* CARDIAC TAMPONADE */
'4238 ' = '1' /* PERICARDIAL DISEASE NEC */
'4239 ' = '1' /* PERICARDIAL DISEASE NOS */
'4240 ' = '1' /* MITRAL VALVE DISORDER */
'4241 ' = '1' /* AORTIC VALVE DISORDER */
'4242 ' = '1' /* NONRHEUM TRICUSP VAL DIS */
'4243 ' = '1' /* PULMONARY VALVE DISORDER */
'42490' = '1' /* ENDOCARDITIS NOS */
'42491' = '1' /* ENDOCARDITIS IN OTH DIS */
'42499' = '1' /* ENDOCARDITIS NEC */
'4250 ' = '1' /* ENDOMYOCARDIAL FIBROSIS */
'4251 ' = '1' /* HYPERTR OBSTR CARDIOMYOP */
'4252 ' = '1' /* OBSC AFRIC CARDIOMYOPATH */
'4253 ' = '1' /* ENDOCARD FIBROELASTOSIS */
'4254 ' = '1' /* PRIM CARDIOMYOPATHY NEC */
'4255 ' = '1' /* ALCOHOLIC CARDIOMYOPATHY */
'4257 ' = '1' /* METABOLIC CARDIOMYOPATHY */
'4258 ' = '1' /* CARDIOMYOPATH IN OTH DIS */
'4259 ' = '1' /* SECOND CARDIOMYOPATH NOS */
'4280 ' = '1' /* CHF NOS */
'4281 ' = '1' /* LEFT HEART FAILURE */
'42820' = '1' /* SYSTOLIC HRT FAILURE NOS */
'42821' = '1' /* AC SYSTOLIC HRT FAILURE */
'42822' = '1' /* CHR SYSTOLIC HRT FAILURE */
'42823' = '1' /* AC ON CHR SYST HRT FAIL */
'42830' = '1' /* DIASTOLC HRT FAILURE NOS */
'42831' = '1' /* AC DIASTOLIC HRT FAILURE */
'42832' = '1' /* CHR DIASTOLIC HRT FAIL */
'42833' = '1' /* AC ON CHR DIAST HRT FAIL */
'42840' = '1' /* SYST/DIAST HRT FAIL NOS */
'42841' = '1' /* AC SYST/DIASTOL HRT FAIL */
'42842' = '1' /* CHR SYST/DIASTL HRT FAIL */
'42843' = '1' /* AC/CHR SYST/DIA HRT FAIL */
'4289 ' = '1' /* HEART FAILURE NOS */
'7450 ' = '1'  /* COMMON TRUNCUS */
'74510' = '1'  /* COMPL TRANSPOS GREAT VES */
'74511' = '1'  /* DOUBLE OUTLET RT VENTRIC */
'74512' = '1'  /* CORRECT TRANSPOS GRT VES */
'74519' = '1'  /* TRANSPOS GREAT VESS NEC */
'7452 ' = '1'  /* TETRALOGY OF FALLOT */
'7453 ' = '1'  /* COMMON VENTRICLE */
'7454 ' = '1'  /* VENTRICULAR SEPT DEFECT */
'7455 ' = '1'  /* SECUNDUM ATRIAL SEPT DEF */
'74560' = '1'  /* ENDOCARD CUSHION DEF NOS */
'74561' = '1'  /* OSTIUM PRIMUM DEFECT */
'74569' = '1'  /* ENDOCARD CUSHION DEF NEC */
'7457 ' = '1'  /* COR BILOCULARE */
'7458 ' = '1'  /* SEPTAL CLOSURE ANOM NEC */
'7459 ' = '1'  /* SEPTAL CLOSURE ANOM NOS */
'74600' = '1'  /* PULMONARY VALVE ANOM NOS */
'74601' = '1'  /* CONG PULMON VALV ATRESIA */
'74602' = '1'  /* CONG PULMON VALVE STENOS */
'74609' = '1'  /* PULMONARY VALVE ANOM NEC */
'7461 ' = '1'  /* CONG TRICUSP ATRES/STEN */
'7462 ' = '1'  /* EBSTEIN'S ANOMALY */
'7463 ' = '1'  /* CONG AORTA VALV STENOSIS */
'7464 ' = '1'  /* CONG AORTA VALV INSUFFIC */
'7465 ' = '1'  /* CONGEN MITRAL STENOSIS */
'7466 ' = '1'  /* CONG MITRAL INSUFFICIENC */
'7467 ' = '1'  /* HYPOPLAS LEFT HEART SYND */
'74681' = '1'  /* CONG SUBAORTIC STENOSIS */
'74682' = '1'  /* COR TRIATRIATUM */
'74683' = '1'  /* INFUNDIB PULMON STENOSIS */
'74684' = '1'  /* OBSTRUCT HEART ANOM NEC */
'74685' = '1'  /* CORONARY ARTERY ANOMALY */
'74686' = '1'  /* CONGENITAL HEART BLOCK */
'74687' = '1'  /* MALPOSITION OF HEART */
'74689' = '1'  /* CONG HEART ANOMALY NEC */
'7469 ' = '1'  /* CONG HEART ANOMALY NOS */
'7470 ' = '1'  /* PATENT DUCTUS ARTERIOSUS */
'74710' = '1'  /* COARCTATION OF AORTA */
'74711' = '1'  /* INTERRUPT OF AORTIC ARCH */
'74720' = '1'  /* CONG ANOM OF AORTA NOS */
'74721' = '1'  /* ANOMALIES OF AORTIC ARCH */
'74722' = '1'  /* AORTIC ATRESIA/STENOSIS */
'74729' = '1'  /* CONG ANOM OF AORTA NEC */
'7473 ' = '1'  /* PULMONARY ARTERY ANOM */
'74740' = '1'  /* GREAT VEIN ANOMALY NOS */
'74741' = '1'  /* TOT ANOM PULM VEN CONNEC */
'74742' = '1'  /* PART ANOM PULM VEN CONN */
'74749' = '1'  /* GREAT VEIN ANOMALY NEC */
'7475 ' = '1'  /* UMBILICAL ARTERY ABSENCE */
'74760' = '1'  /* UNSP PRPHERL VASC ANOMAL */
'74761' = '1'  /* GSTRONTEST VESL ANOMALY */
'74762' = '1'  /* RENAL VESSEL ANOMALY */
'74763' = '1'  /* UPR LIMB VESSEL ANOMALY */
'74764' = '1'  /* LWR LIMB VESSEL ANOMALY */
'74769' = '1'  /* OTH SPCF PRPH VSCL ANOML */
'74781' = '1'  /* CEREBROVASCULAR ANOMALY */
'74782' = '1'  /* SPINAL VESSEL ANOMALY */
'74783' = '1'  /* PERSISTENT FETAL CIRC */
'74789' = '1'  /* CIRCULATORY ANOMALY NEC */
'7479 ' = '1'  /* CIRCULATORY ANOMALY NOS */
OTHER  = '0' ;

 * -------------------------------------------------------------- ;
 * --- FORMATS - AREA LEVEL UTILIZATION INDICATORS -------------- ;
 * -------------------------------------------------------------- ;

 /* ---------------------------------------- */
 /* Hysterectomy rate (PRHYST)               */
 /*   Utilization (area) Indicator / IQI #28 */
 /* ---------------------------------------- */

 /* Hysterectomy */
 /* ICD-9-CM Procedure Codes: */

VALUE $PRHYSTP
'683 ' = '1'   /* SUBTOT ABD HYSTERECTOMY */
'6831' = '1'   /* LAP SCERVIC HYSTERECTOMY */
'6839' = '1'   /* OTH SUBTOT ABD HYSTERECT */
'684 ' = '1'   /* TOTAL ABD HYSTERECTOMY */
'6841' = '1'   /* LAP TOTAL ABDOMINAL HYST */
'6849' = '1'   /* TOTAL ABD HYST NEC/NOS */
'685 ' = '1'   /* VAGINAL HYSTERECTOMY */
'6851' = '1'   /* LAPAR ASSIST VAG HYS */
'6859' = '1'   /* OTH VAG HYS */
'686 ' = '1'   /* RADICAL ABD HYSTERECTOMY */
'6861' = '1'   /* LAP RADICAL ABDOMNL HYST */
'6869' = '1'   /* RADICAL ABD HYST NEC/NOS */
'687 ' = '1'   /* RADICAL VAG HYSTERECTOMY */
'6871' = '1'   /* LAP RADICAL VAGINAL HYST */
'6879' = '1'   /* RADICAL VAG HYST NEC/NOS */
'689 ' = '1'   /* HYSTERECTOMY NEC/NOS */
OTHER  = '0' ;

 /* Exclude: Female Genital Cancer */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $PRHYS1D
'179  ' = '1'  /* MALIG NEOPL UTERUS NOS */
'1800 ' = '1'  /* MALIG NEO ENDOCERVIX */
'1801 ' = '1'  /* MALIG NEO EXOCERVIX */
'1808 ' = '1'  /* MALIG NEO CERVIX NEC */
'1809 ' = '1'  /* MAL NEO CERVIX UTERI NOS */
'181  ' = '1'  /* MALIGNANT NEOPL PLACENTA */
'1820 ' = '1'  /* MALIG NEO CORPUS UTERI */
'1821 ' = '1'  /* MAL NEO UTERINE ISTHMUS */
'1828 ' = '1'  /* MAL NEO BODY UTERUS NEC */
'1830 ' = '1'  /* MALIGN NEOPL OVARY */
'1832 ' = '1'  /* MAL NEO FALLOPIAN TUBE */
'1833 ' = '1'  /* MAL NEO BROAD LIGAMENT */
'1834 ' = '1'  /* MALIG NEO PARAMETRIUM */
'1835 ' = '1'  /* MAL NEO ROUND LIGAMENT */
'1838 ' = '1'  /* MAL NEO ADNEXA NEC */
'1839 ' = '1'  /* MAL NEO ADNEXA NOS */
'1840 ' = '1'  /* MALIGN NEOPL VAGINA */
'1841 ' = '1'  /* MAL NEO LABIA MAJORA */
'1842 ' = '1'  /* MAL NEO LABIA MINORA */
'1843 ' = '1'  /* MALIGN NEOPL CLITORIS */
'1844 ' = '1'  /* MALIGN NEOPL VULVA NOS */
'1848 ' = '1'  /* MAL NEO FEMALE GENIT NEC */
'1849 ' = '1'  /* MAL NEO FEMALE GENIT NOS */
'2331 ' = '1'  /* CA IN SITU CERVIX UTERI */
'2332 ' = '1'  /* CA IN SITU UTERUS NEC */
'2333 ' = '1'  /* CA IN SITU FEM GEN NEC */
'23330' = '1'  /* CA IN SITU FEM GEN NOS */
'23331' = '1'  /* CARCINOMA IN SITU VAGINA */
'23332' = '1'  /* CARCINOMA IN SITU VULVA */
'23339' = '1'  /* CA IN SITU FEM GEN NEC */
'2360 ' = '1'  /* UNCERT BEHAV NEO UTERUS */
'2361 ' = '1'  /* UNC BEHAV NEO PLACENTA */
'2362 ' = '1'  /* UNC BEHAV NEO OVARY */
'2363 ' = '1'  /* UNC BEHAV NEO FEMALE NEC */
OTHER   = '0' ;

 /* Exclude: Pelvic or Lower Abdominal Trauma */
 /* ICD-9-CM Diagnosis Codes: */

VALUE $PRHYS2D
'8674 ' = '1'  /* UTERUS INJURY-CLOSED */
'8675 ' = '1'  /* UTERUS INJURY-OPEN */
'8676 ' = '1'  /* PELVIC ORGAN INJ NEC-CL */
'8677 ' = '1'  /* PELVIC ORGAN INJ NEC-OPN */
'8678 ' = '1'  /* PELVIC ORGAN INJ NOS-CL */
'8679 ' = '1'  /* PELVIC ORGAN INJ NOS-OPN */
'86800' = '1'  /* INTRA-ABDOM INJ NOS-CLOS */
'86803' = '1'  /* PERITONEUM INJURY-CLOSED */
'86804' = '1'  /* RETROPERITONEUM INJ-CL */
'86809' = '1'  /* INTRA-ABDOM INJ NEC-CLOS */
'86810' = '1'  /* INTRA-ABDOM INJ NOS-OPEN */
'86813' = '1'  /* PERITONEUM INJURY-OPEN */
'86814' = '1'  /* RETROPERITONEUM INJ-OPEN */
'86819' = '1'  /* INTRA-ABDOM INJ NEC-OPEN */
'8690 ' = '1'  /* INTERNAL INJ NOS-CLOSED */
'8691 ' = '1'  /* INTERNAL INJURY NOS-OPEN */
'8796 ' = '1'  /* OPEN WOUND OF TRUNK NEC */
'8797 ' = '1'  /* OPEN WND TRUNK NEC-COMPL */
'8798 ' = '1'  /* OPEN WOUND SITE NOS */
'8799 ' = '1'  /* OPN WOUND SITE NOS-COMPL */
'9060 ' = '1'  /* LT EFF OPN WND HEAD/TRNK */
'9081 ' = '1'  /* LATE EFF INT INJ ABDOMEN */
'9082 ' = '1'  /* LATE EFF INT INJURY NEC */
'9391 ' = '1'  /* FOREIGN BODY UTERUS */
'9474 ' = '1'  /* BURN OF VAGINA & UTERUS */
OTHER   = '0' ;

 /* ---------------------------------------------- */
 /* Laminectomy and/or spinal fusion rate (PRLAMI) */
 /*   Utilization (area) Indicator / IQI #29       */
 /* ---------------------------------------------- */

 /* Laminectomy and/or Spinal Fusion */
 /* ICD-9-CM Procedure Codes: */

VALUE $PRLAMIP
'0302' = '1'   /* REOPEN LAMINECTOMY SITE */
'0309' = '1'   /* SPINAL CANAL EXPLOR NEC */
'8050' = '1'   /* EXC/DEST INTVRT DISC NOS */
'8051' = '1'   /* EXCISION INTERVERT DISC */
'8059' = '1'   /* OTH EXC/DEST INTVRT DISC */
'8100' = '1'   /* SPINAL FUSION NOS */
'8101' = '1'   /* ATLAS-AXIS FUSION */
'8102' = '1'   /* OTH CERV FUSION, ANTER */
'8103' = '1'   /* OTH CERV FUSION, POSTER */
'8104' = '1'   /* DORSAL FUSION, ANTERIOR */
'8105' = '1'   /* DORSAL FUSION, POSTERIOR */
'8106' = '1'   /* LUMBAR FUSION, ANTERIOR */
'8107' = '1'   /* LUMBAR FUSION, LATERAL */
'8108' = '1'   /* LUMBAR FUSION, POSTERIOR */
'8109' = '1'   /* REFUSION OF SPINE */
'8130' = '1'   /* SPINAL REFUSION NOS */
'8131' = '1'   /* REFUSION OF ATLAS-AXIS */
'8132' = '1'   /* REFUSION OF OTH CERV ANT */
'8133' = '1'   /* REFUS OF OTH CERV POST */
'8134' = '1'   /* REFUSION OF DORSAL ANT */
'8135' = '1'   /* REFUSION OF DORSAL POST */
'8136' = '1'   /* REFUSION OF LUMBAR ANT */
'8137' = '1'   /* REFUSION OF LUMBAR LAT */
'8138' = '1'   /* REFUSION OF LUMBAR POST */
'8139' = '1'   /* REFUSION OF SPINE NEC */
'8161' = '1'   /* 360 SPINAL FUSION */
'8162' = '1'   /* FUS/REFUS 2-3 VERTEBRAE */
'8163' = '1'   /* FUS/REFUS 4-8 VERTEBRAE */
'8164' = '1'   /* FUS/REFUS 9 VERTEBRAE */
'8451' = '1'   /* INS SPINAL FUSION DEVICE */
OTHER  = '0' ;

 * ----------------------------------------------------- ;
 * ---   DRG FORMATS      ------------------------------ ;
 * ----------------------------------------------------- ;

 /* CMS-DRG (V24) TO MDC */;

VALUE MDCFMT
001 = 01
002 = 01
003 = 01
004 = 01
005 = 01
006 = 01
007 = 01
008 = 01
009 = 01
010 = 01
011 = 01
012 = 01
013 = 01
014 = 01
015 = 01
016 = 01
017 = 01
018 = 01
019 = 01
020 = 01
021 = 01
022 = 01
023 = 01
024 = 01
025 = 01
026 = 01
027 = 01
028 = 01
029 = 01
030 = 01
031 = 01
032 = 01
033 = 01
034 = 01
035 = 01
036 = 02
037 = 02
038 = 02
039 = 02
040 = 02
041 = 02
042 = 02
043 = 02
044 = 02
045 = 02
046 = 02
047 = 02
048 = 02
049 = 03
050 = 03
051 = 03
052 = 03
053 = 03
054 = 03
055 = 03
056 = 03
057 = 03
058 = 03
059 = 03
060 = 03
061 = 03
062 = 03
063 = 03
064 = 03
065 = 03
066 = 03
067 = 03
068 = 03
069 = 03
070 = 03
071 = 03
072 = 03
073 = 03
074 = 03
075 = 04
076 = 04
077 = 04
078 = 04
079 = 04
080 = 04
081 = 04
082 = 04
083 = 04
084 = 04
085 = 04
086 = 04
087 = 04
088 = 04
089 = 04
090 = 04
091 = 04
092 = 04
093 = 04
094 = 04
095 = 04
096 = 04
097 = 04
098 = 04
099 = 04
100 = 04
101 = 04
102 = 04
103 = 88
104 = 05
105 = 05
106 = 05
107 = 05
108 = 05
109 = 05
110 = 05
111 = 05
112 = 05
113 = 05
114 = 05
115 = 05
116 = 05
117 = 05
118 = 05
119 = 05
120 = 05
121 = 05
122 = 05
123 = 05
124 = 05
125 = 05
126 = 05
127 = 05
128 = 05
129 = 05
130 = 05
131 = 05
132 = 05
133 = 05
134 = 05
135 = 05
136 = 05
137 = 05
138 = 05
139 = 05
140 = 05
141 = 05
142 = 05
143 = 05
144 = 05
145 = 05
146 = 06
147 = 06
148 = 06
149 = 06
150 = 06
151 = 06
152 = 06
153 = 06
154 = 06
155 = 06
156 = 06
157 = 06
158 = 06
159 = 06
160 = 06
161 = 06
162 = 06
163 = 06
164 = 06
165 = 06
166 = 06
167 = 06
168 = 03
169 = 03
170 = 06
171 = 06
172 = 06
173 = 06
174 = 06
175 = 06
176 = 06
177 = 06
178 = 06
179 = 06
180 = 06
181 = 06
182 = 06
183 = 06
184 = 06
185 = 03
186 = 03
187 = 03
188 = 06
189 = 06
190 = 06
191 = 07
192 = 07
193 = 07
194 = 07
195 = 07
196 = 07
197 = 07
198 = 07
199 = 07
200 = 07
201 = 07
202 = 07
203 = 07
204 = 07
205 = 07
206 = 07
207 = 07
208 = 07
209 = 08
210 = 08
211 = 08
212 = 08
213 = 08
214 = 08
215 = 08
216 = 08
217 = 08
218 = 08
219 = 08
220 = 08
221 = 08
222 = 08
223 = 08
224 = 08
225 = 08
226 = 08
227 = 08
228 = 08
229 = 08
230 = 08
231 = 08
232 = 08
233 = 08
234 = 08
235 = 08
236 = 08
237 = 08
238 = 08
239 = 08
240 = 08
241 = 08
242 = 08
243 = 08
244 = 08
245 = 08
246 = 08
247 = 08
248 = 08
249 = 08
250 = 08
251 = 08
252 = 08
253 = 08
254 = 08
255 = 08
256 = 08
257 = 09
258 = 09
259 = 09
260 = 09
261 = 09
262 = 09
263 = 09
264 = 09
265 = 09
266 = 09
267 = 09
268 = 09
269 = 09
270 = 09
271 = 09
272 = 09
273 = 09
274 = 09
275 = 09
276 = 09
277 = 09
278 = 09
279 = 09
280 = 09
281 = 09
282 = 09
283 = 09
284 = 09
285 = 10
286 = 10
287 = 10
288 = 10
289 = 10
290 = 10
291 = 10
292 = 10
293 = 10
294 = 10
295 = 10
296 = 10
297 = 10
298 = 10
299 = 10
300 = 10
301 = 10
302 = 11
303 = 11
304 = 11
305 = 11
306 = 11
307 = 11
308 = 11
309 = 11
310 = 11
311 = 11
312 = 11
313 = 11
314 = 11
315 = 11
316 = 11
317 = 11
318 = 11
319 = 11
320 = 11
321 = 11
322 = 11
323 = 11
324 = 11
325 = 11
326 = 11
327 = 11
328 = 11
329 = 11
330 = 11
331 = 11
332 = 11
333 = 11
334 = 12
335 = 12
336 = 12
337 = 12
338 = 12
339 = 12
340 = 12
341 = 12
342 = 12
343 = 12
344 = 12
345 = 12
346 = 12
347 = 12
348 = 12
349 = 12
350 = 12
351 = 12
352 = 12
353 = 13
354 = 13
355 = 13
356 = 13
357 = 13
358 = 13
359 = 13
360 = 13
361 = 13
362 = 13
363 = 13
364 = 13
365 = 13
366 = 13
367 = 13
368 = 13
369 = 13
370 = 14
371 = 14
372 = 14
373 = 14
374 = 14
375 = 14
376 = 14
377 = 14
378 = 14
379 = 14
380 = 14
381 = 14
382 = 14
383 = 14
384 = 14
385 = 15
386 = 15
387 = 15
388 = 15
389 = 15
390 = 15
391 = 15
392 = 16
393 = 16
394 = 16
395 = 16
396 = 16
397 = 16
398 = 16
399 = 16
400 = 17
401 = 17
402 = 17
403 = 17
404 = 17
405 = 17
406 = 17
407 = 17
408 = 17
409 = 17
410 = 17
411 = 17
412 = 17
413 = 17
414 = 17
415 = 18
416 = 18
417 = 18
418 = 18
419 = 18
420 = 18
421 = 18
422 = 18
423 = 18
424 = 19
425 = 19
426 = 19
427 = 19
428 = 19
429 = 19
430 = 19
431 = 19
432 = 19
433 = 20
434 = 20
435 = 20
436 = 20
437 = 20
438 = 20
439 = 21
440 = 21
441 = 21
442 = 21
443 = 21
444 = 21
445 = 21
446 = 21
447 = 21
448 = 21
449 = 21
450 = 21
451 = 21
452 = 21
453 = 21
454 = 21
455 = 21
456 = 22
457 = 22
458 = 22
459 = 22
460 = 22
461 = 23
462 = 23
463 = 23
464 = 23
465 = 23
466 = 23
467 = 23
468 = 99
469 = 99
470 = 99
471 = 08
472 = 22
473 = 17
474 = 04
475 = 04
476 = 99
477 = 99
478 = 05
479 = 05
480 = 88
481 = 88
482 = 88
483 = 88
484 = 24
485 = 24
486 = 24
487 = 24
488 = 25
489 = 25
490 = 25
491 = 08
492 = 17
493 = 07
494 = 07
495 = 88
496 = 08
497 = 08
498 = 08
499 = 08
500 = 08
501 = 08
502 = 08
503 = 08
504 = 22
505 = 22
506 = 22
507 = 22
508 = 22
509 = 22
510 = 22
511 = 22
512 = 88
513 = 88
514 = 05
515 = 05
516 = 05
517 = 05
518 = 05
519 = 08
520 = 08
521 = 20
522 = 20
523 = 20
524 = 01
525 = 05
526 = 05
527 = 05
528 = 01
529 = 01
530 = 01
531 = 01
532 = 01
533 = 01
534 = 01
535 = 05
536 = 05
537 = 08
538 = 08
539 = 17
540 = 17
541 = 88
542 = 88
543 = 01
544 = 08
545 = 08
546 = 08
547 = 05
548 = 05
549 = 05
550 = 05
551 = 05
552 = 05
553 = 05
554 = 05
555 = 05
556 = 05
557 = 05
558 = 05
559 = 01
560 = 01
561 = 01
562 = 01
563 = 01
564 = 01
565 = 04
566 = 04
567 = 06
568 = 06
569 = 06
570 = 06
571 = 06
572 = 06
573 = 11
574 = 16
575 = 18
576 = 18
577 = 01
578 = 18
579 = 18
OTHER  = 99 ;

 /* MS-DRG (V25) TO MDC */;

VALUE MDCF2T
001 = 88
002 = 88
003 = 88
004 = 88
005 = 88
006 = 88
007 = 88
008 = 88
009 = 88
010 = 88
011 = 88
012 = 88
013 = 88
020 = 01
021 = 01
022 = 01
023 = 01
024 = 01
025 = 01
026 = 01
027 = 01
028 = 01
029 = 01
030 = 01
031 = 01
032 = 01
033 = 01
034 = 01
035 = 01
036 = 01
037 = 01
038 = 01
039 = 01
040 = 01
041 = 01
042 = 01
052 = 01
053 = 01
054 = 01
055 = 01
056 = 01
057 = 01
058 = 01
059 = 01
060 = 01
061 = 01
062 = 01
063 = 01
064 = 01
065 = 01
066 = 01
067 = 01
068 = 01
069 = 01
070 = 01
071 = 01
072 = 01
073 = 01
074 = 01
075 = 01
076 = 01
077 = 01
078 = 01
079 = 01
080 = 01
081 = 01
082 = 01
083 = 01
084 = 01
085 = 01
086 = 01
087 = 01
088 = 01
089 = 01
090 = 01
091 = 01
092 = 01
093 = 01
094 = 01
095 = 01
096 = 01
097 = 01
098 = 01
099 = 01
100 = 01
101 = 01
102 = 01
103 = 01
113 = 02
114 = 02
115 = 02
116 = 02
117 = 02
121 = 02
122 = 02
123 = 02
124 = 02
125 = 02
129 = 03
130 = 03
131 = 03
132 = 03
133 = 03
134 = 03
135 = 03
136 = 03
137 = 03
138 = 03
139 = 03
146 = 03
147 = 03
148 = 03
149 = 03
150 = 03
151 = 03
152 = 03
153 = 03
154 = 03
155 = 03
156 = 03
157 = 03
158 = 03
159 = 03
163 = 04
164 = 04
165 = 04
166 = 04
167 = 04
168 = 04
175 = 04
176 = 04
177 = 04
178 = 04
179 = 04
180 = 04
181 = 04
182 = 04
183 = 04
184 = 04
185 = 04
186 = 04
187 = 04
188 = 04
189 = 04
190 = 04
191 = 04
192 = 04
193 = 04
194 = 04
195 = 04
196 = 04
197 = 04
198 = 04
199 = 04
200 = 04
201 = 04
202 = 04
203 = 04
204 = 04
205 = 04
206 = 04
207 = 04
208 = 04
215 = 05
216 = 05
217 = 05
218 = 05
219 = 05
220 = 05
221 = 05
222 = 05
223 = 05
224 = 05
225 = 05
226 = 05
227 = 05
228 = 05
229 = 05
230 = 05
231 = 05
232 = 05
233 = 05
234 = 05
235 = 05
236 = 05
237 = 05
238 = 05
239 = 05
240 = 05
241 = 05
242 = 05
243 = 05
244 = 05
245 = 05
246 = 05
247 = 05
248 = 05
249 = 05
250 = 05
251 = 05
252 = 05
253 = 05
254 = 05
255 = 05
256 = 05
257 = 05
258 = 05
259 = 05
260 = 05
261 = 05
262 = 05
263 = 05
264 = 05
280 = 05
281 = 05
282 = 05
283 = 05
284 = 05
285 = 05
286 = 05
287 = 05
288 = 05
289 = 05
290 = 05
291 = 05
292 = 05
293 = 05
294 = 05
295 = 05
296 = 05
297 = 05
298 = 05
299 = 05
300 = 05
301 = 05
302 = 05
303 = 05
304 = 05
305 = 05
306 = 05
307 = 05
308 = 05
309 = 05
310 = 05
311 = 05
312 = 05
313 = 05
314 = 05
315 = 05
316 = 05
326 = 06
327 = 06
328 = 06
329 = 06
330 = 06
331 = 06
332 = 06
333 = 06
334 = 06
335 = 06
336 = 06
337 = 06
338 = 06
339 = 06
340 = 06
341 = 06
342 = 06
343 = 06
344 = 06
345 = 06
346 = 06
347 = 06
348 = 06
349 = 06
350 = 06
351 = 06
352 = 06
353 = 06
354 = 06
355 = 06
356 = 06
357 = 06
358 = 06
368 = 06
369 = 06
370 = 06
371 = 06
372 = 06
373 = 06
374 = 06
375 = 06
376 = 06
377 = 06
378 = 06
379 = 06
380 = 06
381 = 06
382 = 06
383 = 06
384 = 06
385 = 06
386 = 06
387 = 06
388 = 06
389 = 06
390 = 06
391 = 06
392 = 06
393 = 06
394 = 06
395 = 06
405 = 07
406 = 07
407 = 07
408 = 07
409 = 07
410 = 07
411 = 07
412 = 07
413 = 07
414 = 07
415 = 07
416 = 07
417 = 07
418 = 07
419 = 07
420 = 07
421 = 07
422 = 07
423 = 07
424 = 07
425 = 07
432 = 07
433 = 07
434 = 07
435 = 07
436 = 07
437 = 07
438 = 07
439 = 07
440 = 07
441 = 07
442 = 07
443 = 07
444 = 07
445 = 07
446 = 07
453 = 08
454 = 08
455 = 08
456 = 08
457 = 08
458 = 08
459 = 08
460 = 08
461 = 08
462 = 08
463 = 08
464 = 08
465 = 08
466 = 08
467 = 08
468 = 08
469 = 08
470 = 08
471 = 08
472 = 08
473 = 08
474 = 08
475 = 08
476 = 08
477 = 08
478 = 08
479 = 08
480 = 08
481 = 08
482 = 08
483 = 08
484 = 08
485 = 08
486 = 08
487 = 08
488 = 08
489 = 08
490 = 08
491 = 08
492 = 08
493 = 08
494 = 08
495 = 08
496 = 08
497 = 08
498 = 08
499 = 08
500 = 08
501 = 08
502 = 08
503 = 08
504 = 08
505 = 08
506 = 08
507 = 08
508 = 08
509 = 08
510 = 08
511 = 08
512 = 08
513 = 08
514 = 08
515 = 08
516 = 08
517 = 08
533 = 08
534 = 08
535 = 08
536 = 08
537 = 08
538 = 08
539 = 08
540 = 08
541 = 08
542 = 08
543 = 08
544 = 08
545 = 08
546 = 08
547 = 08
548 = 08
549 = 08
550 = 08
551 = 08
552 = 08
553 = 08
554 = 08
555 = 08
556 = 08
557 = 08
558 = 08
559 = 08
560 = 08
561 = 08
562 = 08
563 = 08
564 = 08
565 = 08
566 = 08
573 = 09
574 = 09
575 = 09
576 = 09
577 = 09
578 = 09
579 = 09
580 = 09
581 = 09
582 = 09
583 = 09
584 = 09
585 = 09
592 = 09
593 = 09
594 = 09
595 = 09
596 = 09
597 = 09
598 = 09
599 = 09
600 = 09
601 = 09
602 = 09
603 = 09
604 = 09
605 = 09
606 = 09
607 = 09
614 = 10
615 = 10
616 = 10
617 = 10
618 = 10
619 = 10
620 = 10
621 = 10
622 = 10
623 = 10
624 = 10
625 = 10
626 = 10
627 = 10
628 = 10
629 = 10
630 = 10
637 = 10
638 = 10
639 = 10
640 = 10
641 = 10
642 = 10
643 = 10
644 = 10
645 = 10
652 = 11
653 = 11
654 = 11
655 = 11
656 = 11
657 = 11
658 = 11
659 = 11
660 = 11
661 = 11
662 = 11
663 = 11
664 = 11
665 = 11
666 = 11
667 = 11
668 = 11
669 = 11
670 = 11
671 = 11
672 = 11
673 = 11
674 = 11
675 = 11
682 = 11
683 = 11
684 = 11
685 = 11
686 = 11
687 = 11
688 = 11
689 = 11
690 = 11
691 = 11
692 = 11
693 = 11
694 = 11
695 = 11
696 = 11
697 = 11
698 = 11
699 = 11
700 = 11
707 = 12
708 = 12
709 = 12
710 = 12
711 = 12
712 = 12
713 = 12
714 = 12
715 = 12
716 = 12
717 = 12
718 = 12
722 = 12
723 = 12
724 = 12
725 = 12
726 = 12
727 = 12
728 = 12
729 = 12
730 = 12
734 = 13
735 = 13
736 = 13
737 = 13
738 = 13
739 = 13
740 = 13
741 = 13
742 = 13
743 = 13
744 = 13
745 = 13
746 = 13
747 = 13
748 = 13
749 = 13
750 = 13
754 = 13
755 = 13
756 = 13
757 = 13
758 = 13
759 = 13
760 = 13
761 = 13
765 = 14
766 = 14
767 = 14
768 = 14
769 = 14
770 = 14
774 = 14
775 = 14
776 = 14
777 = 14
778 = 14
779 = 14
780 = 14
781 = 14
782 = 14
789 = 15
790 = 15
791 = 15
792 = 15
793 = 15
794 = 15
795 = 15
799 = 16
800 = 16
801 = 16
802 = 16
803 = 16
804 = 16
808 = 16
809 = 16
810 = 16
811 = 16
812 = 16
813 = 16
814 = 16
815 = 16
816 = 16
820 = 17
821 = 17
822 = 17
823 = 17
824 = 17
825 = 17
826 = 17
827 = 17
828 = 17
829 = 17
830 = 17
834 = 17
835 = 17
836 = 17
837 = 17
838 = 17
839 = 17
840 = 17
841 = 17
842 = 17
843 = 17
844 = 17
845 = 17
846 = 17
847 = 17
848 = 17
849 = 17
853 = 18
854 = 18
855 = 18
856 = 18
857 = 18
858 = 18
862 = 18
863 = 18
864 = 18
865 = 18
866 = 18
867 = 18
868 = 18
869 = 18
870 = 18
871 = 18
872 = 18
876 = 19
880 = 19
881 = 19
882 = 19
883 = 19
884 = 19
885 = 19
886 = 19
887 = 19
894 = 20
895 = 20
896 = 20
897 = 20
901 = 21
902 = 21
903 = 21
904 = 21
905 = 21
906 = 21
907 = 21
908 = 21
909 = 21
913 = 21
914 = 21
915 = 21
916 = 21
917 = 21
918 = 21
919 = 21
920 = 21
921 = 21
922 = 21
923 = 21
927 = 22
928 = 22
929 = 22
933 = 22
934 = 22
935 = 22
939 = 23
940 = 23
941 = 23
945 = 23
946 = 23
947 = 23
948 = 23
949 = 23
950 = 23
951 = 23
955 = 24
956 = 24
957 = 24
958 = 24
959 = 24
963 = 24
964 = 24
965 = 24
969 = 25
970 = 25
974 = 25
975 = 25
976 = 25
977 = 25
981 = 99
982 = 99
983 = 99
984 = 99
985 = 99
986 = 99
987 = 99
988 = 99
989 = 99
998 = 99
999 = 99
OTHER  = 99 ;

 * ----------------------------------------------------- ;
 * ---   AREA FORMATS     ------------------------------ ;
 * ---   Translates FIPS State and County Code (SSCCC)   ;
 * ---   to MSA (Metropolitan Statistical Area)          ;
 * ----------------------------------------------------- ;

/* MODIFIED FIPS */

VALUE $M1AREA
'02013' = '02001'
'02016' = '02001'
'02020' = '02001'
'02050' = '02001'
'02060' = '02001'
'02068' = '02001'
'02070' = '02001'
'02090' = '02001'
'02100' = '02001'
'02110' = '02001'
'02122' = '02001'
'02130' = '02001'
'02150' = '02001'
'02164' = '02001'
'02170' = '02001'
'02180' = '02001'
'02185' = '02001'
'02188' = '02001'
'02201' = '02001'
'02220' = '02001'
'02232' = '02001'
'02240' = '02001'
'02261' = '02001'
'02270' = '02001'
'02280' = '02001'
'02282' = '02001'
'02290' = '02001'
'15005' = '15009'
'24510' = '24007'
'29510' = '29191'
'32510' = '32025'
'51515' = '51019'
'51520' = '51119'
'51530' = '51163'
'51540' = '51003'
'51560' = '51005'
'51570' = '51041'
'51580' = '51005'
'51590' = '51143'
'51595' = '51081'
'51600' = '51059'
'51610' = '51059'
'51620' = '51175'
'51630' = '51177'
'51640' = '51077'
'51660' = '51165'
'51670' = '51149'
'51678' = '51163'
'51680' = '51031'
'51683' = '51153'
'51685' = '51153'
'51690' = '51089'
'51710' = '51129'
'51720' = '51195'
'51730' = '51053'
'51735' = '51199'
'51740' = '51129'
'51750' = '51121'
'51760' = '51087'
'51770' = '51161'
'51775' = '51161'
'51780' = '51083'
'51790' = '51015'
'51800' = '51123'
'51820' = '51015'
'51830' = '51095'
'51840' = '51069'
;

/* OMB 1999 METRO AREA */

VALUE $M2AREA
'01001' = '5240 '
'01003' = '5160 '
'01009' = '1000 '
'01015' = '0450 '
'01033' = '2650 '
'01045' = '2180 '
'01051' = '5240 '
'01055' = '2880 '
'01069' = '2180 '
'01073' = '1000 '
'01077' = '2650 '
'01079' = '2030 '
'01081' = '0580 '
'01083' = '3440 '
'01089' = '3440 '
'01097' = '5160 '
'01101' = '5240 '
'01103' = '2030 '
'01113' = '1800 '
'01115' = '1000 '
'01117' = '1000 '
'01125' = '8600 '
'02020' = '0380 '
'04005' = '2620 '
'04013' = '6200 '
'04015' = '4120 '
'04019' = '8520 '
'04021' = '6200 '
'04027' = '9360 '
'05007' = '2580 '
'05031' = '3700 '
'05033' = '2720 '
'05035' = '4920 '
'05045' = '4400 '
'05069' = '6240 '
'05085' = '4400 '
'05091' = '8360 '
'05119' = '4400 '
'05125' = '4400 '
'05131' = '2720 '
'05143' = '2580 '
'06001' = '5775 '
'06007' = '1620 '
'06013' = '5775 '
'06017' = '6920 '
'06019' = '2840 '
'06029' = '0680 '
'06037' = '4480 '
'06039' = '2840 '
'06041' = '7360 '
'06047' = '4940 '
'06053' = '7120 '
'06055' = '8720 '
'06059' = '5945 '
'06061' = '6920 '
'06065' = '6780 '
'06067' = '6920 '
'06071' = '6780 '
'06073' = '7320 '
'06075' = '7360 '
'06077' = '8120 '
'06079' = '7460 '
'06081' = '7360 '
'06083' = '7480 '
'06085' = '7400 '
'06087' = '7485 '
'06089' = '6690 '
'06095' = '8720 '
'06097' = '7500 '
'06099' = '5170 '
'06101' = '9340 '
'06107' = '8780 '
'06111' = '8735 '
'06113' = '9270 '
'06115' = '9340 '
'08001' = '2080 '
'08005' = '2080 '
'08013' = '1125 '
'08031' = '2080 '
'08035' = '2080 '
'08041' = '1720 '
'08059' = '2080 '
'08069' = '2670 '
'08077' = '2995 '
'08101' = '6560 '
'08123' = '3060 '
'09001' = '5483 '
'09003' = '3283 '
'09007' = '3283 '
'09009' = '5483 '
'09011' = '5523 '
'09013' = '3283 '
'10001' = '2190 '
'10003' = '9160 '
'11001' = '8840 '
'12001' = '2900 '
'12005' = '6015 '
'12009' = '4900 '
'12011' = '2680 '
'12015' = '6580 '
'12019' = '3600 '
'12021' = '5345 '
'12031' = '3600 '
'12033' = '6080 '
'12035' = '2020 '
'12039' = '8240 '
'12053' = '8280 '
'12057' = '8280 '
'12069' = '5960 '
'12071' = '2700 '
'12073' = '8240 '
'12081' = '7510 '
'12083' = '5790 '
'12085' = '2710 '
'12086' = '5000 '
'12089' = '3600 '
'12091' = '2750 '
'12095' = '5960 '
'12097' = '5960 '
'12099' = '8960 '
'12101' = '8280 '
'12103' = '8280 '
'12105' = '3980 '
'12109' = '3600 '
'12111' = '2710 '
'12113' = '6080 '
'12115' = '7510 '
'12117' = '5960 '
'12127' = '2020 '
'13013' = '0520 '
'13015' = '0520 '
'13021' = '4680 '
'13029' = '7520 '
'13045' = '0520 '
'13047' = '1560 '
'13051' = '7520 '
'13053' = '1800 '
'13057' = '0520 '
'13059' = '0500 '
'13063' = '0520 '
'13067' = '0520 '
'13073' = '0600 '
'13077' = '0520 '
'13083' = '1560 '
'13089' = '0520 '
'13095' = '0120 '
'13097' = '0520 '
'13103' = '7520 '
'13113' = '0520 '
'13117' = '0520 '
'13121' = '0520 '
'13135' = '0520 '
'13145' = '1800 '
'13151' = '0520 '
'13153' = '4680 '
'13169' = '4680 '
'13177' = '0120 '
'13189' = '0600 '
'13195' = '0500 '
'13215' = '1800 '
'13217' = '0520 '
'13219' = '0500 '
'13223' = '0520 '
'13225' = '4680 '
'13227' = '0520 '
'13245' = '0600 '
'13247' = '0520 '
'13255' = '0520 '
'13289' = '4680 '
'13295' = '1560 '
'13297' = '0520 '
'15003' = '3320 '
'16001' = '1080 '
'16005' = '6340 '
'16027' = '1080 '
'17007' = '6880 '
'17019' = '1400 '
'17027' = '7040 '
'17031' = '1600 '
'17037' = '1600 '
'17043' = '1600 '
'17063' = '1600 '
'17073' = '1960 '
'17083' = '7040 '
'17089' = '1600 '
'17091' = '3740 '
'17093' = '1600 '
'17097' = '1600 '
'17111' = '1600 '
'17113' = '1040 '
'17115' = '2040 '
'17119' = '7040 '
'17129' = '7880 '
'17133' = '7040 '
'17141' = '6880 '
'17143' = '6120 '
'17161' = '1960 '
'17163' = '7040 '
'17167' = '7880 '
'17179' = '6120 '
'17197' = '1600 '
'17201' = '6880 '
'17203' = '6120 '
'18001' = '2760 '
'18003' = '2760 '
'18011' = '3480 '
'18019' = '4520 '
'18021' = '8320 '
'18023' = '3920 '
'18029' = '1640 '
'18033' = '2760 '
'18035' = '5280 '
'18039' = '2330 '
'18043' = '4520 '
'18057' = '3480 '
'18059' = '3480 '
'18061' = '4520 '
'18063' = '3480 '
'18067' = '3850 '
'18069' = '2760 '
'18081' = '3480 '
'18089' = '2960 '
'18095' = '3480 '
'18097' = '3480 '
'18105' = '1020 '
'18109' = '3480 '
'18115' = '1640 '
'18127' = '2960 '
'18129' = '2440 '
'18141' = '7800 '
'18143' = '4520 '
'18145' = '3480 '
'18157' = '3920 '
'18159' = '3850 '
'18163' = '2440 '
'18165' = '8320 '
'18167' = '8320 '
'18173' = '2440 '
'18179' = '2760 '
'18183' = '2760 '
'19013' = '8920 '
'19049' = '2120 '
'19061' = '2200 '
'19103' = '3500 '
'19113' = '1360 '
'19153' = '2120 '
'19155' = '5920 '
'19163' = '1960 '
'19181' = '2120 '
'19193' = '7720 '
'20015' = '9040 '
'20045' = '4150 '
'20079' = '9040 '
'20091' = '3760 '
'20103' = '3760 '
'20121' = '3760 '
'20173' = '9040 '
'20177' = '8440 '
'20209' = '3760 '
'21015' = '1640 '
'21017' = '4280 '
'21019' = '3400 '
'21029' = '4520 '
'21037' = '1640 '
'21043' = '3400 '
'21047' = '1660 '
'21049' = '4280 '
'21059' = '5990 '
'21067' = '4280 '
'21077' = '1640 '
'21081' = '1640 '
'21089' = '3400 '
'21101' = '2440 '
'21111' = '4520 '
'21113' = '4280 '
'21117' = '1640 '
'21151' = '4280 '
'21185' = '4520 '
'21191' = '1640 '
'21209' = '4280 '
'21239' = '4280 '
'22001' = '3880 '
'22005' = '0760 '
'22015' = '7680 '
'22017' = '7680 '
'22019' = '3960 '
'22033' = '0760 '
'22051' = '5560 '
'22055' = '3880 '
'22057' = '3350 '
'22063' = '0760 '
'22071' = '5560 '
'22073' = '5200 '
'22075' = '5560 '
'22079' = '0220 '
'22087' = '5560 '
'22089' = '5560 '
'22093' = '5560 '
'22095' = '5560 '
'22097' = '3880 '
'22099' = '3880 '
'22103' = '5560 '
'22109' = '3350 '
'22119' = '7680 '
'22121' = '0760 '
'23001' = '4243 '
'23005' = '6403 '
'23019' = '0733 '
'24001' = '1900 '
'24003' = '0720 '
'24005' = '0720 '
'24009' = '8840 '
'24013' = '0720 '
'24015' = '9160 '
'24017' = '8840 '
'24021' = '8840 '
'24025' = '0720 '
'24027' = '0720 '
'24031' = '8840 '
'24033' = '8840 '
'24035' = '0720 '
'24043' = '3180 '
'24510' = '0720 '
'25001' = '0743 '
'25003' = '6323 '
'25005' = '1123 '
'25009' = '1123 '
'25013' = '8003 '
'25015' = '8003 '
'25017' = '1123 '
'25021' = '1123 '
'25023' = '1123 '
'25025' = '1123 '
'25027' = '1123 '
'26005' = '3000 '
'26017' = '6960 '
'26021' = '0870 '
'26025' = '3720 '
'26037' = '4040 '
'26045' = '4040 '
'26049' = '2640 '
'26065' = '4040 '
'26075' = '3520 '
'26077' = '3720 '
'26081' = '3000 '
'26087' = '2160 '
'26091' = '0440 '
'26093' = '0440 '
'26099' = '2160 '
'26111' = '6960 '
'26115' = '2160 '
'26121' = '3000 '
'26125' = '2160 '
'26139' = '3000 '
'26145' = '6960 '
'26147' = '2160 '
'26159' = '3720 '
'26161' = '0440 '
'26163' = '2160 '
'27003' = '5120 '
'27009' = '6980 '
'27019' = '5120 '
'27025' = '5120 '
'27027' = '2520 '
'27037' = '5120 '
'27053' = '5120 '
'27055' = '3870 '
'27059' = '5120 '
'27109' = '6820 '
'27119' = '2985 '
'27123' = '5120 '
'27137' = '2240 '
'27139' = '5120 '
'27141' = '5120 '
'27145' = '6980 '
'27163' = '5120 '
'27171' = '5120 '
'28033' = '4920 '
'28035' = '3285 '
'28045' = '0920 '
'28047' = '0920 '
'28049' = '3560 '
'28059' = '0920 '
'28073' = '3285 '
'28089' = '3560 '
'28121' = '3560 '
'29003' = '7000 '
'29019' = '1740 '
'29021' = '7000 '
'29037' = '3760 '
'29043' = '7920 '
'29047' = '3760 '
'29049' = '3760 '
'29071' = '7040 '
'29077' = '7920 '
'29095' = '3760 '
'29097' = '3710 '
'29099' = '7040 '
'29107' = '3760 '
'29113' = '7040 '
'29145' = '3710 '
'29165' = '3760 '
'29177' = '3760 '
'29183' = '7040 '
'29189' = '7040 '
'29219' = '7040 '
'29225' = '7920 '
'29510' = '7040 '
'30013' = '3040 '
'30063' = '5140 '
'30111' = '0880 '
'31025' = '5920 '
'31043' = '7720 '
'31055' = '5920 '
'31109' = '4360 '
'31153' = '5920 '
'31177' = '5920 '
'32003' = '4120 '
'32023' = '4120 '
'32031' = '6720 '
'33011' = '1123 '
'33015' = '1123 '
'33017' = '1123 '
'34001' = '0560 '
'34003' = '0875 '
'34005' = '6160 '
'34007' = '6160 '
'34009' = '0560 '
'34011' = '8760 '
'34013' = '5640 '
'34015' = '6160 '
'34017' = '3640 '
'34019' = '5015 '
'34021' = '8480 '
'34023' = '5015 '
'34025' = '5190 '
'34027' = '5640 '
'34029' = '5190 '
'34031' = '0875 '
'34033' = '6160 '
'34035' = '5015 '
'34037' = '5640 '
'34039' = '5640 '
'34041' = '5640 '
'35001' = '0200 '
'35013' = '4100 '
'35028' = '7490 '
'35043' = '0200 '
'35049' = '7490 '
'35061' = '0200 '
'36001' = '0160 '
'36005' = '5600 '
'36007' = '0960 '
'36011' = '8160 '
'36013' = '3610 '
'36015' = '2335 '
'36027' = '2281 '
'36029' = '1280 '
'36037' = '6840 '
'36043' = '8680 '
'36047' = '5600 '
'36051' = '6840 '
'36053' = '8160 '
'36055' = '6840 '
'36057' = '0160 '
'36059' = '5380 '
'36061' = '5600 '
'36063' = '1280 '
'36065' = '8680 '
'36067' = '8160 '
'36069' = '6840 '
'36071' = '5660 '
'36073' = '6840 '
'36075' = '8160 '
'36079' = '5600 '
'36081' = '5600 '
'36083' = '0160 '
'36085' = '5600 '
'36087' = '5600 '
'36091' = '0160 '
'36093' = '0160 '
'36095' = '0160 '
'36103' = '5380 '
'36107' = '0960 '
'36113' = '2975 '
'36115' = '2975 '
'36117' = '6840 '
'36119' = '5600 '
'37001' = '3120 '
'37003' = '3290 '
'37019' = '9200 '
'37021' = '0480 '
'37023' = '3290 '
'37025' = '1520 '
'37027' = '3290 '
'37035' = '3290 '
'37037' = '6640 '
'37051' = '2560 '
'37053' = '5720 '
'37057' = '3120 '
'37059' = '3120 '
'37063' = '6640 '
'37065' = '6895 '
'37067' = '3120 '
'37069' = '6640 '
'37071' = '1520 '
'37081' = '3120 '
'37101' = '6640 '
'37109' = '1520 '
'37115' = '0480 '
'37119' = '1520 '
'37127' = '6895 '
'37129' = '9200 '
'37133' = '3605 '
'37135' = '6640 '
'37147' = '3150 '
'37151' = '3120 '
'37159' = '1520 '
'37169' = '3120 '
'37179' = '1520 '
'37183' = '6640 '
'37191' = '2980 '
'37197' = '3120 '
'38015' = '1010 '
'38017' = '2520 '
'38035' = '2985 '
'38059' = '1010 '
'39003' = '4320 '
'39007' = '1680 '
'39011' = '4320 '
'39013' = '9000 '
'39015' = '1640 '
'39017' = '3200 '
'39019' = '1320 '
'39023' = '2000 '
'39025' = '1640 '
'39029' = '9320 '
'39033' = '4800 '
'39035' = '1680 '
'39041' = '1840 '
'39045' = '1840 '
'39049' = '1840 '
'39051' = '8400 '
'39055' = '1680 '
'39057' = '2000 '
'39061' = '1640 '
'39081' = '8080 '
'39085' = '1680 '
'39087' = '3400 '
'39089' = '1840 '
'39093' = '1680 '
'39095' = '8400 '
'39097' = '1840 '
'39099' = '9320 '
'39103' = '1680 '
'39109' = '2000 '
'39113' = '2000 '
'39129' = '1840 '
'39133' = '0080 '
'39139' = '4800 '
'39151' = '1320 '
'39153' = '0080 '
'39155' = '9320 '
'39165' = '1640 '
'39167' = '6020 '
'39173' = '8400 '
'40017' = '5880 '
'40027' = '5880 '
'40031' = '4200 '
'40037' = '8560 '
'40047' = '2340 '
'40083' = '5880 '
'40087' = '5880 '
'40109' = '5880 '
'40113' = '8560 '
'40125' = '5880 '
'40131' = '8560 '
'40135' = '2720 '
'40143' = '8560 '
'40145' = '8560 '
'41003' = '1890 '
'41005' = '6440 '
'41009' = '6440 '
'41029' = '4890 '
'41039' = '2400 '
'41047' = '7080 '
'41051' = '6440 '
'41053' = '7080 '
'41067' = '6440 '
'41071' = '6440 '
'42003' = '6280 '
'42007' = '6280 '
'42011' = '6680 '
'42013' = '0280 '
'42017' = '6160 '
'42019' = '6280 '
'42021' = '3680 '
'42025' = '0240 '
'42027' = '8050 '
'42029' = '6160 '
'42037' = '7560 '
'42041' = '3240 '
'42043' = '3240 '
'42045' = '6160 '
'42049' = '2360 '
'42051' = '6280 '
'42069' = '7560 '
'42071' = '4000 '
'42075' = '3240 '
'42077' = '0240 '
'42079' = '7560 '
'42081' = '9140 '
'42085' = '7610 '
'42091' = '6160 '
'42095' = '0240 '
'42099' = '3240 '
'42101' = '6160 '
'42103' = '5660 '
'42111' = '3680 '
'42125' = '6280 '
'42129' = '6280 '
'42131' = '7560 '
'42133' = '9280 '
'44001' = '6483 '
'44003' = '6483 '
'44007' = '6483 '
'44009' = '6483 '
'45003' = '0600 '
'45007' = '3160 '
'45015' = '1440 '
'45019' = '1440 '
'45021' = '3160 '
'45035' = '1440 '
'45037' = '0600 '
'45041' = '2655 '
'45045' = '3160 '
'45051' = '5330 '
'45063' = '1760 '
'45077' = '3160 '
'45079' = '1760 '
'45083' = '3160 '
'45085' = '8140 '
'45091' = '1520 '
'46083' = '7760 '
'46099' = '7760 '
'46103' = '6660 '
'47001' = '3840 '
'47009' = '3840 '
'47019' = '3660 '
'47021' = '5360 '
'47023' = '3580 '
'47037' = '5360 '
'47043' = '5360 '
'47047' = '4920 '
'47065' = '1560 '
'47073' = '3660 '
'47093' = '3840 '
'47105' = '3840 '
'47113' = '3580 '
'47115' = '1560 '
'47125' = '1660 '
'47147' = '5360 '
'47149' = '5360 '
'47155' = '3840 '
'47157' = '4920 '
'47163' = '3660 '
'47165' = '5360 '
'47167' = '4920 '
'47171' = '3660 '
'47173' = '3840 '
'47179' = '3660 '
'47187' = '5360 '
'47189' = '5360 '
'48009' = '9080 '
'48021' = '0640 '
'48027' = '3810 '
'48029' = '7240 '
'48037' = '8360 '
'48039' = '1145 '
'48041' = '1260 '
'48055' = '0640 '
'48061' = '1240 '
'48071' = '3360 '
'48085' = '1920 '
'48091' = '7240 '
'48099' = '3810 '
'48113' = '1920 '
'48121' = '1920 '
'48135' = '5800 '
'48139' = '1920 '
'48141' = '2320 '
'48157' = '3360 '
'48167' = '2920 '
'48181' = '7640 '
'48183' = '4420 '
'48187' = '7240 '
'48199' = '0840 '
'48201' = '3360 '
'48203' = '4420 '
'48209' = '0640 '
'48213' = '1920 '
'48215' = '4880 '
'48221' = '2800 '
'48231' = '1920 '
'48245' = '0840 '
'48251' = '2800 '
'48257' = '1920 '
'48291' = '3360 '
'48303' = '4600 '
'48309' = '8800 '
'48329' = '5800 '
'48339' = '3360 '
'48355' = '1880 '
'48361' = '0840 '
'48367' = '2800 '
'48375' = '0320 '
'48381' = '0320 '
'48397' = '1920 '
'48409' = '1880 '
'48423' = '8640 '
'48439' = '2800 '
'48441' = '0040 '
'48451' = '7200 '
'48453' = '0640 '
'48459' = '4420 '
'48469' = '8750 '
'48473' = '3360 '
'48479' = '4080 '
'48485' = '9080 '
'48491' = '0640 '
'48493' = '7240 '
'49011' = '7160 '
'49025' = '2620 '
'49035' = '7160 '
'49049' = '6520 '
'49057' = '7160 '
'50007' = '1303 '
'50011' = '1303 '
'50013' = '1303 '
'51003' = '1540 '
'51009' = '4640 '
'51013' = '8840 '
'51019' = '4640 '
'51023' = '6800 '
'51031' = '4640 '
'51036' = '6760 '
'51041' = '6760 '
'51043' = '8840 '
'51047' = '8840 '
'51053' = '6760 '
'51059' = '8840 '
'51061' = '8840 '
'51065' = '1540 '
'51073' = '5720 '
'51075' = '6760 '
'51079' = '1540 '
'51085' = '6760 '
'51087' = '6760 '
'51093' = '5720 '
'51095' = '5720 '
'51099' = '8840 '
'51107' = '8840 '
'51115' = '5720 '
'51127' = '6760 '
'51143' = '1950 '
'51145' = '6760 '
'51149' = '6760 '
'51153' = '8840 '
'51161' = '6800 '
'51169' = '3660 '
'51177' = '8840 '
'51179' = '8840 '
'51187' = '8840 '
'51191' = '3660 '
'51199' = '5720 '
'51510' = '8840 '
'51515' = '4640 '
'51520' = '3660 '
'51540' = '1540 '
'51550' = '5720 '
'51570' = '6760 '
'51590' = '1950 '
'51600' = '8840 '
'51610' = '8840 '
'51630' = '8840 '
'51650' = '5720 '
'51670' = '6760 '
'51680' = '4640 '
'51683' = '8840 '
'51685' = '8840 '
'51700' = '5720 '
'51710' = '5720 '
'51730' = '6760 '
'51735' = '5720 '
'51740' = '5720 '
'51760' = '6760 '
'51770' = '6800 '
'51775' = '6800 '
'51800' = '5720 '
'51810' = '5720 '
'51830' = '5720 '
'53005' = '6740 '
'53011' = '6440 '
'53021' = '6740 '
'53029' = '7600 '
'53033' = '7600 '
'53035' = '1150 '
'53053' = '8200 '
'53061' = '7600 '
'53063' = '7840 '
'53067' = '5910 '
'53073' = '0860 '
'53077' = '9260 '
'54003' = '8840 '
'54009' = '8080 '
'54011' = '3400 '
'54029' = '8080 '
'54037' = '8840 '
'54039' = '1480 '
'54051' = '9000 '
'54057' = '1900 '
'54069' = '9000 '
'54079' = '1480 '
'54099' = '3400 '
'54107' = '6020 '
'55009' = '3080 '
'55015' = '0460 '
'55017' = '2290 '
'55025' = '4720 '
'55031' = '2240 '
'55035' = '2290 '
'55059' = '3800 '
'55063' = '3870 '
'55073' = '8940 '
'55079' = '5080 '
'55087' = '0460 '
'55089' = '5080 '
'55093' = '5120 '
'55101' = '6600 '
'55105' = '3620 '
'55109' = '5120 '
'55117' = '7620 '
'55131' = '5080 '
'55133' = '5080 '
'55139' = '0460 '
'56021' = '1580 '
'56025' = '1350 '
;

/* OMB 2003 METRO AREA */

VALUE $M3AREA
'01001' = '33860'
'01003' = '19300'
'01005' = '21640'
'01007' = '13820'
'01009' = '13820'
'01015' = '11500'
'01017' = '46740'
'01021' = '13820'
'01031' = '21460'
'01033' = '22520'
'01037' = '10760'
'01043' = '18980'
'01045' = '21460'
'01047' = '42820'
'01049' = '22840'
'01051' = '33860'
'01055' = '23460'
'01061' = '20020'
'01063' = '46220'
'01065' = '46220'
'01067' = '20020'
'01069' = '20020'
'01071' = '42460'
'01073' = '13820'
'01077' = '22520'
'01079' = '19460'
'01081' = '12220'
'01083' = '26620'
'01085' = '33860'
'01087' = '46260'
'01089' = '26620'
'01095' = '10700'
'01097' = '33660'
'01101' = '33860'
'01103' = '19460'
'01109' = '45980'
'01113' = '17980'
'01115' = '13820'
'01117' = '13820'
'01121' = '45180'
'01123' = '10760'
'01125' = '46220'
'01127' = '13820'
'02020' = '11260'
'02090' = '21820'
'02110' = '27940'
'02130' = '28540'
'02150' = '28980'
'02170' = '11260'
'04003' = '43420'
'04005' = '22380'
'04007' = '37740'
'04009' = '40940'
'04011' = '40940'
'04013' = '38060'
'04015' = '29420'
'04019' = '46060'
'04021' = '38060'
'04023' = '35700'
'04025' = '39140'
'04027' = '49740'
'05005' = '34260'
'05007' = '22220'
'05009' = '25460'
'05013' = '15780'
'05019' = '11660'
'05025' = '38220'
'05027' = '31620'
'05031' = '27860'
'05033' = '22900'
'05035' = '32820'
'05045' = '30780'
'05047' = '22900'
'05051' = '26300'
'05053' = '30780'
'05055' = '37500'
'05057' = '26260'
'05063' = '12900'
'05069' = '38220'
'05079' = '38220'
'05085' = '30780'
'05087' = '22220'
'05091' = '45500'
'05093' = '14180'
'05099' = '26260'
'05101' = '25460'
'05103' = '15780'
'05105' = '30780'
'05107' = '48340'
'05111' = '27860'
'05115' = '40780'
'05119' = '30780'
'05123' = '22620'
'05125' = '30780'
'05131' = '22900'
'05139' = '20980'
'05143' = '22220'
'05145' = '42620'
'05149' = '40780'
'06001' = '41860'
'06007' = '17020'
'06013' = '41860'
'06015' = '18860'
'06017' = '40900'
'06019' = '23420'
'06023' = '21700'
'06025' = '20940'
'06027' = '13860'
'06029' = '12540'
'06031' = '25260'
'06033' = '17340'
'06035' = '45000'
'06037' = '31100'
'06039' = '31460'
'06041' = '41860'
'06045' = '46380'
'06047' = '32900'
'06053' = '41500'
'06055' = '34900'
'06057' = '46020'
'06059' = '31100'
'06061' = '40900'
'06065' = '40140'
'06067' = '40900'
'06069' = '41940'
'06071' = '40140'
'06073' = '41740'
'06075' = '41860'
'06077' = '44700'
'06079' = '42020'
'06081' = '41860'
'06083' = '42060'
'06085' = '41940'
'06087' = '42100'
'06089' = '39820'
'06095' = '46700'
'06097' = '42220'
'06099' = '33700'
'06101' = '49700'
'06103' = '39780'
'06107' = '47300'
'06109' = '38020'
'06111' = '37100'
'06113' = '40900'
'06115' = '49700'
'08001' = '19740'
'08005' = '19740'
'08013' = '14500'
'08014' = '19740'
'08019' = '19740'
'08031' = '19740'
'08035' = '19740'
'08037' = '20780'
'08039' = '19740'
'08041' = '17820'
'08043' = '15860'
'08047' = '19740'
'08059' = '19740'
'08065' = '20780'
'08067' = '20420'
'08069' = '22660'
'08075' = '44540'
'08077' = '24300'
'08085' = '33940'
'08087' = '22820'
'08093' = '19740'
'08101' = '39380'
'08117' = '43540'
'08119' = '17820'
'08123' = '24540'
'09001' = '14860'
'09003' = '25540'
'09005' = '45860'
'09007' = '25540'
'09009' = '35300'
'09011' = '35980'
'09013' = '25540'
'09015' = '48740'
'10001' = '20100'
'10003' = '37980'
'10005' = '42580'
'11001' = '47900'
'12001' = '23540'
'12003' = '27260'
'12005' = '37460'
'12009' = '37340'
'12011' = '33100'
'12015' = '39460'
'12017' = '26140'
'12019' = '27260'
'12021' = '34940'
'12023' = '29380'
'12027' = '11580'
'12031' = '27260'
'12033' = '37860'
'12035' = '37380'
'12039' = '45220'
'12041' = '23540'
'12049' = '48100'
'12051' = '17500'
'12053' = '45300'
'12055' = '42700'
'12057' = '45300'
'12061' = '46940'
'12065' = '45220'
'12069' = '36740'
'12071' = '15980'
'12073' = '45220'
'12081' = '42260'
'12083' = '36100'
'12085' = '38940'
'12086' = '33100'
'12087' = '28580'
'12089' = '27260'
'12091' = '23020'
'12093' = '36380'
'12095' = '36740'
'12097' = '36740'
'12099' = '33100'
'12101' = '45300'
'12103' = '45300'
'12105' = '29460'
'12107' = '37260'
'12109' = '27260'
'12111' = '38940'
'12113' = '37860'
'12115' = '42260'
'12117' = '36740'
'12119' = '45540'
'12127' = '19660'
'12129' = '45220'
'13003' = '20060'
'13007' = '10500'
'13009' = '33300'
'13013' = '12060'
'13015' = '12060'
'13017' = '22340'
'13021' = '31420'
'13025' = '15260'
'13027' = '46660'
'13029' = '42340'
'13031' = '44340'
'13033' = '12260'
'13035' = '12060'
'13039' = '41220'
'13045' = '12060'
'13047' = '16860'
'13051' = '42340'
'13053' = '17980'
'13055' = '44900'
'13057' = '12060'
'13059' = '12020'
'13063' = '12060'
'13067' = '12060'
'13069' = '20060'
'13071' = '34220'
'13073' = '12260'
'13077' = '12060'
'13079' = '31420'
'13081' = '18380'
'13083' = '16860'
'13085' = '12060'
'13087' = '12460'
'13089' = '12060'
'13095' = '10500'
'13097' = '12060'
'13101' = '46660'
'13103' = '42340'
'13113' = '12060'
'13115' = '40660'
'13117' = '12060'
'13121' = '12060'
'13127' = '15260'
'13129' = '15660'
'13135' = '12060'
'13137' = '18460'
'13139' = '23580'
'13141' = '33300'
'13143' = '12060'
'13145' = '17980'
'13149' = '12060'
'13151' = '12060'
'13153' = '47580'
'13155' = '22340'
'13159' = '12060'
'13167' = '20140'
'13169' = '31420'
'13171' = '12060'
'13173' = '46660'
'13175' = '20140'
'13177' = '10500'
'13179' = '25980'
'13183' = '25980'
'13185' = '46660'
'13189' = '12260'
'13191' = '15260'
'13195' = '12020'
'13197' = '17980'
'13199' = '12060'
'13207' = '31420'
'13209' = '47080'
'13213' = '19140'
'13215' = '17980'
'13217' = '12060'
'13219' = '12020'
'13221' = '12020'
'13223' = '12060'
'13225' = '22980'
'13227' = '12060'
'13229' = '48180'
'13231' = '12060'
'13233' = '16340'
'13239' = '21640'
'13245' = '12260'
'13247' = '12060'
'13249' = '11140'
'13255' = '12060'
'13257' = '45740'
'13261' = '11140'
'13273' = '10500'
'13275' = '45620'
'13277' = '45700'
'13279' = '47080'
'13285' = '29300'
'13289' = '31420'
'13293' = '45580'
'13295' = '16860'
'13297' = '12060'
'13299' = '48180'
'13305' = '27700'
'13313' = '19140'
'13321' = '10500'
'15001' = '25900'
'15003' = '26180'
'15007' = '28180'
'15009' = '27980'
'16001' = '14260'
'16005' = '38540'
'16011' = '13940'
'16015' = '14260'
'16019' = '26820'
'16027' = '14260'
'16031' = '15420'
'16039' = '34300'
'16041' = '30860'
'16043' = '39940'
'16045' = '14260'
'16051' = '26820'
'16053' = '46300'
'16055' = '17660'
'16057' = '34140'
'16065' = '39940'
'16067' = '15420'
'16069' = '30300'
'16073' = '14260'
'16075' = '36620'
'16077' = '38540'
'16081' = '27220'
'16083' = '46300'
'17001' = '39500'
'17003' = '16020'
'17005' = '41180'
'17007' = '40420'
'17011' = '36860'
'17013' = '41180'
'17019' = '16580'
'17021' = '45380'
'17027' = '41180'
'17029' = '16660'
'17031' = '16980'
'17035' = '16660'
'17037' = '16980'
'17043' = '16980'
'17049' = '20820'
'17053' = '16580'
'17057' = '15900'
'17063' = '16980'
'17065' = '34500'
'17071' = '15460'
'17073' = '19340'
'17077' = '16060'
'17081' = '34500'
'17083' = '41180'
'17089' = '16980'
'17091' = '28100'
'17093' = '16980'
'17095' = '23660'
'17097' = '16980'
'17099' = '36860'
'17103' = '19940'
'17105' = '38700'
'17107' = '30660'
'17109' = '31380'
'17111' = '16980'
'17113' = '14060'
'17115' = '19500'
'17117' = '41180'
'17119' = '41180'
'17121' = '16460'
'17123' = '37900'
'17127' = '37140'
'17129' = '44100'
'17131' = '19340'
'17133' = '41180'
'17137' = '27300'
'17141' = '40300'
'17143' = '37900'
'17147' = '16580'
'17155' = '36860'
'17161' = '19340'
'17163' = '41180'
'17165' = '25380'
'17167' = '44100'
'17171' = '27300'
'17175' = '37900'
'17177' = '23300'
'17179' = '37900'
'17183' = '19180'
'17187' = '23660'
'17195' = '44580'
'17197' = '16980'
'17199' = '32060'
'17201' = '40420'
'17203' = '37900'
'18001' = '19540'
'18003' = '23060'
'18005' = '18020'
'18007' = '29140'
'18011' = '26900'
'18013' = '26900'
'18015' = '29140'
'18017' = '30900'
'18019' = '31140'
'18021' = '45460'
'18023' = '23140'
'18027' = '47780'
'18029' = '17140'
'18031' = '24700'
'18033' = '12140'
'18035' = '34620'
'18037' = '27540'
'18039' = '21140'
'18041' = '18220'
'18043' = '31140'
'18047' = '17140'
'18051' = '21780'
'18053' = '31980'
'18055' = '14020'
'18057' = '26900'
'18059' = '26900'
'18061' = '31140'
'18063' = '26900'
'18065' = '35220'
'18067' = '29020'
'18069' = '26540'
'18071' = '42980'
'18073' = '16980'
'18077' = '31500'
'18079' = '35860'
'18081' = '26900'
'18083' = '47180'
'18085' = '47700'
'18089' = '16980'
'18091' = '33140'
'18093' = '13260'
'18095' = '11300'
'18097' = '26900'
'18099' = '38500'
'18103' = '37940'
'18105' = '14020'
'18107' = '18820'
'18109' = '26900'
'18111' = '16980'
'18113' = '28340'
'18115' = '17140'
'18119' = '14020'
'18125' = '27540'
'18127' = '16980'
'18129' = '21780'
'18133' = '26900'
'18141' = '43780'
'18143' = '42500'
'18145' = '26900'
'18151' = '11420'
'18153' = '45460'
'18157' = '29140'
'18159' = '29020'
'18163' = '21780'
'18165' = '45460'
'18167' = '45460'
'18169' = '47340'
'18173' = '21780'
'18175' = '31140'
'18177' = '39980'
'18179' = '23060'
'18183' = '23060'
'19011' = '16300'
'19013' = '47940'
'19015' = '14340'
'19017' = '47940'
'19021' = '44740'
'19033' = '32380'
'19041' = '43980'
'19045' = '17540'
'19049' = '19780'
'19057' = '15460'
'19059' = '44020'
'19061' = '20220'
'19075' = '47940'
'19077' = '19780'
'19085' = '36540'
'19099' = '35500'
'19103' = '26980'
'19105' = '16300'
'19111' = '28460'
'19113' = '16300'
'19115' = '34700'
'19121' = '19780'
'19123' = '36820'
'19125' = '37800'
'19127' = '32260'
'19129' = '36540'
'19139' = '34700'
'19153' = '19780'
'19155' = '36540'
'19163' = '19340'
'19169' = '11180'
'19179' = '36900'
'19181' = '19780'
'19183' = '26980'
'19187' = '22700'
'19193' = '43580'
'19195' = '32380'
'20005' = '11860'
'20009' = '24460'
'20015' = '48620'
'20017' = '21380'
'20035' = '49060'
'20037' = '38260'
'20043' = '41140'
'20045' = '29940'
'20051' = '25700'
'20055' = '23780'
'20057' = '19980'
'20059' = '28140'
'20061' = '31740'
'20079' = '48620'
'20085' = '45820'
'20087' = '45820'
'20091' = '28140'
'20099' = '37660'
'20103' = '28140'
'20107' = '28140'
'20111' = '21380'
'20113' = '32700'
'20121' = '28140'
'20125' = '17700'
'20139' = '45820'
'20143' = '41460'
'20149' = '31740'
'20155' = '26740'
'20161' = '31740'
'20169' = '41460'
'20173' = '48620'
'20175' = '30580'
'20177' = '45820'
'20191' = '48620'
'20197' = '45820'
'20209' = '28140'
'21005' = '23180'
'21007' = '37140'
'21009' = '23980'
'21011' = '34460'
'21013' = '33180'
'21015' = '17140'
'21017' = '30460'
'21019' = '26580'
'21021' = '19220'
'21023' = '17140'
'21029' = '31140'
'21035' = '34660'
'21037' = '17140'
'21047' = '17300'
'21049' = '30460'
'21059' = '36980'
'21061' = '14540'
'21067' = '30460'
'21073' = '23180'
'21075' = '46460'
'21077' = '17140'
'21081' = '17140'
'21083' = '32460'
'21089' = '26580'
'21091' = '36980'
'21093' = '21060'
'21101' = '21780'
'21103' = '31140'
'21107' = '31580'
'21111' = '31140'
'21113' = '30460'
'21117' = '17140'
'21123' = '21060'
'21125' = '30940'
'21135' = '32500'
'21137' = '19220'
'21139' = '37140'
'21145' = '37140'
'21149' = '36980'
'21151' = '40080'
'21161' = '32500'
'21163' = '31140'
'21165' = '34460'
'21169' = '23980'
'21173' = '34460'
'21177' = '16420'
'21179' = '31140'
'21185' = '31140'
'21191' = '17140'
'21199' = '43700'
'21203' = '40080'
'21209' = '30460'
'21211' = '31140'
'21215' = '31140'
'21217' = '15820'
'21221' = '17300'
'21223' = '31140'
'21227' = '14540'
'21233' = '21780'
'21235' = '18340'
'21239' = '30460'
'22001' = '18940'
'22005' = '12940'
'22007' = '38200'
'22011' = '19760'
'22015' = '43340'
'22017' = '43340'
'22019' = '29340'
'22023' = '29340'
'22029' = '35020'
'22031' = '43340'
'22033' = '12940'
'22037' = '12940'
'22043' = '10780'
'22045' = '35340'
'22047' = '12940'
'22049' = '40820'
'22051' = '35380'
'22053' = '27660'
'22055' = '29180'
'22057' = '26380'
'22061' = '40820'
'22063' = '12940'
'22065' = '45260'
'22067' = '12820'
'22069' = '35060'
'22071' = '35380'
'22073' = '33740'
'22075' = '35380'
'22077' = '12940'
'22079' = '10780'
'22087' = '35380'
'22089' = '35380'
'22091' = '12940'
'22095' = '35380'
'22097' = '36660'
'22099' = '29180'
'22101' = '34020'
'22103' = '35380'
'22105' = '25220'
'22109' = '26380'
'22111' = '33740'
'22113' = '10020'
'22115' = '22860'
'22117' = '14220'
'22119' = '33380'
'22121' = '12940'
'22125' = '12940'
'23001' = '30340'
'23005' = '38860'
'23011' = '12300'
'23013' = '40500'
'23019' = '12620'
'23023' = '38860'
'23031' = '38860'
'24001' = '19060'
'24003' = '12580'
'24005' = '12580'
'24009' = '47900'
'24013' = '12580'
'24015' = '37980'
'24017' = '47900'
'24019' = '15700'
'24021' = '47900'
'24025' = '12580'
'24027' = '12580'
'24031' = '47900'
'24033' = '47900'
'24035' = '12580'
'24037' = '30500'
'24039' = '41540'
'24041' = '20660'
'24043' = '25180'
'24045' = '41540'
'24047' = '36180'
'24510' = '12580'
'25001' = '12700'
'25003' = '38340'
'25005' = '39300'
'25009' = '14460'
'25011' = '44140'
'25013' = '44140'
'25015' = '44140'
'25017' = '14460'
'25021' = '14460'
'25023' = '14460'
'25025' = '14460'
'25027' = '49340'
'26005' = '10880'
'26007' = '10980'
'26015' = '24340'
'26017' = '13020'
'26019' = '45900'
'26021' = '35660'
'26023' = '17740'
'26025' = '12980'
'26027' = '43780'
'26033' = '42300'
'26037' = '29620'
'26041' = '21540'
'26043' = '27020'
'26045' = '29620'
'26049' = '22420'
'26055' = '45900'
'26057' = '10940'
'26061' = '26340'
'26065' = '29620'
'26067' = '24340'
'26073' = '34380'
'26075' = '27100'
'26077' = '28020'
'26079' = '45900'
'26081' = '24340'
'26083' = '26340'
'26087' = '19820'
'26089' = '45900'
'26091' = '10300'
'26093' = '19820'
'26099' = '19820'
'26103' = '32100'
'26107' = '13660'
'26109' = '31940'
'26111' = '33220'
'26113' = '15620'
'26115' = '33780'
'26121' = '34740'
'26123' = '24340'
'26125' = '19820'
'26139' = '26100'
'26145' = '40980'
'26147' = '19820'
'26149' = '44780'
'26155' = '37020'
'26159' = '28020'
'26161' = '11460'
'26163' = '19820'
'26165' = '15620'
'27003' = '33460'
'27007' = '13420'
'27009' = '41060'
'27013' = '31860'
'27015' = '35580'
'27017' = '20260'
'27019' = '33460'
'27021' = '14660'
'27025' = '33460'
'27027' = '22020'
'27035' = '14660'
'27037' = '33460'
'27039' = '40340'
'27041' = '10820'
'27047' = '10660'
'27049' = '39860'
'27053' = '33460'
'27055' = '29100'
'27059' = '33460'
'27067' = '48820'
'27083' = '32140'
'27085' = '26780'
'27091' = '21860'
'27099' = '12380'
'27103' = '31860'
'27105' = '49380'
'27109' = '40340'
'27111' = '22260'
'27119' = '24220'
'27123' = '33460'
'27131' = '22060'
'27137' = '20260'
'27139' = '33460'
'27141' = '33460'
'27145' = '41060'
'27147' = '36940'
'27157' = '40340'
'27163' = '33460'
'27167' = '47420'
'27169' = '49100'
'27171' = '33460'
'28001' = '35020'
'28003' = '18420'
'28005' = '32620'
'28011' = '17380'
'28015' = '24900'
'28023' = '32940'
'28025' = '48500'
'28027' = '17260'
'28029' = '27140'
'28033' = '32820'
'28035' = '25620'
'28039' = '37700'
'28043' = '24980'
'28045' = '25060'
'28047' = '25060'
'28049' = '27140'
'28057' = '46180'
'28059' = '37700'
'28061' = '29860'
'28067' = '29860'
'28069' = '32940'
'28071' = '37060'
'28073' = '25620'
'28075' = '32940'
'28081' = '46180'
'28083' = '24900'
'28085' = '15020'
'28087' = '18060'
'28089' = '27140'
'28093' = '32820'
'28105' = '44260'
'28109' = '38100'
'28111' = '25620'
'28113' = '32620'
'28115' = '46180'
'28121' = '27140'
'28127' = '27140'
'28131' = '25060'
'28133' = '26940'
'28137' = '32820'
'28143' = '32820'
'28149' = '46980'
'28151' = '24740'
'28163' = '49540'
'29001' = '28860'
'29003' = '41140'
'29007' = '33020'
'29013' = '28140'
'29017' = '16020'
'29019' = '17860'
'29021' = '41140'
'29023' = '38740'
'29025' = '28140'
'29027' = '27620'
'29031' = '16020'
'29037' = '28140'
'29043' = '44180'
'29045' = '28460'
'29047' = '28140'
'29049' = '28140'
'29051' = '27620'
'29059' = '44180'
'29063' = '41140'
'29069' = '28380'
'29071' = '41180'
'29077' = '44180'
'29089' = '17860'
'29091' = '48460'
'29095' = '28140'
'29097' = '27900'
'29099' = '41180'
'29101' = '47660'
'29105' = '30060'
'29107' = '28140'
'29111' = '39500'
'29113' = '41180'
'29119' = '22220'
'29127' = '25300'
'29135' = '27620'
'29145' = '27900'
'29147' = '32340'
'29151' = '27620'
'29159' = '42740'
'29161' = '40620'
'29165' = '28140'
'29167' = '44180'
'29169' = '22780'
'29173' = '25300'
'29175' = '33620'
'29177' = '28140'
'29183' = '41180'
'29187' = '22100'
'29189' = '41180'
'29195' = '32180'
'29197' = '28860'
'29201' = '43460'
'29209' = '14700'
'29213' = '14700'
'29219' = '41180'
'29221' = '41180'
'29225' = '44180'
'29510' = '41180'
'30009' = '13740'
'30013' = '24500'
'30029' = '28060'
'30031' = '14580'
'30041' = '25660'
'30043' = '25740'
'30049' = '25740'
'30063' = '33540'
'30093' = '15580'
'30111' = '13740'
'31001' = '25580'
'31007' = '42420'
'31019' = '28260'
'31025' = '36540'
'31035' = '25580'
'31043' = '43580'
'31047' = '30420'
'31051' = '43580'
'31053' = '23340'
'31055' = '36540'
'31067' = '13100'
'31073' = '30420'
'31079' = '24260'
'31093' = '24260'
'31099' = '28260'
'31109' = '30700'
'31111' = '35820'
'31113' = '35820'
'31117' = '35820'
'31119' = '35740'
'31121' = '24260'
'31139' = '35740'
'31141' = '18100'
'31153' = '36540'
'31155' = '36540'
'31157' = '42420'
'31159' = '30700'
'31167' = '35740'
'31177' = '36540'
'32001' = '21980'
'32003' = '29820'
'32005' = '23820'
'32007' = '21220'
'32011' = '21220'
'32023' = '37220'
'32029' = '39900'
'32031' = '39900'
'32510' = '16180'
'33001' = '29060'
'33005' = '28300'
'33007' = '13620'
'33009' = '30100'
'33011' = '31700'
'33013' = '18180'
'33015' = '14460'
'33017' = '14460'
'33019' = '17200'
'34001' = '12100'
'34003' = '35620'
'34005' = '37980'
'34007' = '37980'
'34009' = '36140'
'34011' = '47220'
'34013' = '35620'
'34015' = '37980'
'34017' = '35620'
'34019' = '35620'
'34021' = '45940'
'34023' = '35620'
'34025' = '35620'
'34027' = '35620'
'34029' = '35620'
'34031' = '35620'
'34033' = '37980'
'34035' = '35620'
'34037' = '35620'
'34039' = '35620'
'34041' = '10900'
'35001' = '10740'
'35005' = '40740'
'35006' = '24380'
'35009' = '17580'
'35013' = '29740'
'35015' = '16100'
'35017' = '43500'
'35025' = '26020'
'35028' = '31060'
'35029' = '19700'
'35031' = '23700'
'35035' = '10460'
'35039' = '21580'
'35041' = '38780'
'35043' = '10740'
'35045' = '22140'
'35047' = '29780'
'35049' = '42140'
'35055' = '45340'
'35057' = '10740'
'35061' = '10740'
'36001' = '10580'
'36005' = '35620'
'36007' = '13780'
'36009' = '36460'
'36011' = '12180'
'36013' = '27460'
'36015' = '21300'
'36019' = '38460'
'36021' = '26460'
'36023' = '18660'
'36027' = '39100'
'36029' = '15380'
'36033' = '31660'
'36035' = '24100'
'36037' = '12860'
'36043' = '46540'
'36045' = '48060'
'36047' = '35620'
'36051' = '40380'
'36053' = '45060'
'36055' = '40380'
'36057' = '11220'
'36059' = '35620'
'36061' = '35620'
'36063' = '15380'
'36065' = '46540'
'36067' = '45060'
'36069' = '40380'
'36071' = '39100'
'36073' = '40380'
'36075' = '45060'
'36077' = '36580'
'36079' = '35620'
'36081' = '35620'
'36083' = '10580'
'36085' = '35620'
'36087' = '35620'
'36089' = '36300'
'36091' = '10580'
'36093' = '10580'
'36095' = '10580'
'36099' = '42900'
'36101' = '18500'
'36103' = '35620'
'36107' = '13780'
'36109' = '27060'
'36111' = '28740'
'36113' = '24020'
'36115' = '24020'
'36117' = '40380'
'36119' = '35620'
'37001' = '15500'
'37003' = '25860'
'37007' = '16740'
'37013' = '47820'
'37019' = '48900'
'37021' = '11700'
'37023' = '25860'
'37025' = '16740'
'37027' = '25860'
'37029' = '21020'
'37031' = '33980'
'37035' = '25860'
'37037' = '20500'
'37045' = '43140'
'37049' = '35100'
'37051' = '22180'
'37053' = '47260'
'37055' = '28620'
'37057' = '45640'
'37059' = '49180'
'37063' = '20500'
'37065' = '40580'
'37067' = '49180'
'37069' = '39580'
'37071' = '16740'
'37079' = '24780'
'37081' = '24660'
'37083' = '40260'
'37085' = '20380'
'37087' = '11700'
'37089' = '11700'
'37093' = '22180'
'37097' = '44380'
'37101' = '39580'
'37103' = '35100'
'37105' = '41820'
'37107' = '28820'
'37109' = '30740'
'37115' = '11700'
'37119' = '16740'
'37125' = '43860'
'37127' = '40580'
'37129' = '48900'
'37131' = '40260'
'37133' = '27340'
'37135' = '20500'
'37137' = '35100'
'37139' = '21020'
'37141' = '48900'
'37143' = '21020'
'37145' = '20500'
'37147' = '24780'
'37151' = '24660'
'37153' = '40460'
'37155' = '31300'
'37157' = '24660'
'37159' = '41580'
'37161' = '22580'
'37165' = '29900'
'37167' = '10620'
'37169' = '49180'
'37171' = '34340'
'37175' = '14820'
'37179' = '16740'
'37181' = '25780'
'37183' = '39580'
'37189' = '14380'
'37191' = '24140'
'37193' = '35900'
'37195' = '48980'
'37197' = '49180'
'38007' = '19860'
'38015' = '13900'
'38017' = '22020'
'38035' = '24220'
'38049' = '33500'
'38059' = '13900'
'38075' = '33500'
'38077' = '47420'
'38089' = '19860'
'38093' = '27420'
'38101' = '33500'
'38105' = '48780'
'39003' = '30620'
'39005' = '11740'
'39007' = '11780'
'39009' = '11900'
'39011' = '47540'
'39013' = '48540'
'39015' = '17140'
'39017' = '17140'
'39019' = '15940'
'39021' = '46500'
'39023' = '44220'
'39025' = '17140'
'39027' = '48940'
'39029' = '20620'
'39031' = '18740'
'39033' = '15340'
'39035' = '17460'
'39037' = '24820'
'39039' = '19580'
'39041' = '18140'
'39043' = '41780'
'39045' = '18140'
'39047' = '47860'
'39049' = '18140'
'39051' = '45780'
'39053' = '38580'
'39055' = '17460'
'39057' = '19380'
'39059' = '15740'
'39061' = '17140'
'39063' = '22300'
'39077' = '35940'
'39081' = '48260'
'39083' = '34540'
'39085' = '17460'
'39087' = '26580'
'39089' = '18140'
'39091' = '13340'
'39093' = '17460'
'39095' = '45780'
'39097' = '18140'
'39099' = '49660'
'39101' = '32020'
'39103' = '17460'
'39107' = '16380'
'39109' = '19380'
'39113' = '19380'
'39117' = '18140'
'39119' = '49780'
'39123' = '45780'
'39129' = '18140'
'39133' = '10420'
'39135' = '19380'
'39139' = '31900'
'39141' = '17060'
'39143' = '23380'
'39145' = '39020'
'39147' = '45660'
'39149' = '43380'
'39151' = '15940'
'39153' = '10420'
'39155' = '49660'
'39157' = '35420'
'39159' = '18140'
'39161' = '46780'
'39165' = '17140'
'39167' = '37620'
'39169' = '49300'
'39173' = '45780'
'40009' = '21120'
'40013' = '20460'
'40017' = '36420'
'40019' = '11620'
'40021' = '45140'
'40027' = '36420'
'40031' = '30020'
'40037' = '46140'
'40047' = '21420'
'40051' = '36420'
'40065' = '11060'
'40071' = '38620'
'40079' = '22900'
'40081' = '36420'
'40083' = '36420'
'40085' = '11620'
'40087' = '36420'
'40101' = '34780'
'40109' = '36420'
'40111' = '46140'
'40113' = '46140'
'40115' = '33060'
'40117' = '46140'
'40119' = '44660'
'40121' = '32540'
'40123' = '10220'
'40125' = '43060'
'40131' = '46140'
'40135' = '22900'
'40137' = '20340'
'40139' = '25100'
'40143' = '46140'
'40145' = '46140'
'40147' = '12780'
'40153' = '49260'
'41003' = '18700'
'41005' = '38900'
'41007' = '11820'
'41009' = '38900'
'41011' = '18300'
'41013' = '39260'
'41015' = '15060'
'41017' = '13460'
'41019' = '40700'
'41027' = '26220'
'41029' = '32780'
'41033' = '24420'
'41035' = '28900'
'41039' = '21660'
'41043' = '10540'
'41045' = '36620'
'41047' = '41420'
'41049' = '37820'
'41051' = '38900'
'41053' = '41420'
'41059' = '37820'
'41061' = '29260'
'41065' = '17180'
'41067' = '38900'
'41071' = '38900'
'42001' = '23900'
'42003' = '38300'
'42005' = '38300'
'42007' = '38300'
'42011' = '39740'
'42013' = '11020'
'42015' = '42380'
'42017' = '37980'
'42019' = '38300'
'42021' = '27780'
'42025' = '10900'
'42027' = '44300'
'42029' = '37980'
'42033' = '20180'
'42035' = '30820'
'42037' = '14100'
'42039' = '32740'
'42041' = '25420'
'42043' = '25420'
'42045' = '37980'
'42047' = '41260'
'42049' = '21500'
'42051' = '38300'
'42055' = '16540'
'42061' = '26500'
'42063' = '26860'
'42069' = '42540'
'42071' = '29540'
'42073' = '35260'
'42075' = '30140'
'42077' = '10900'
'42079' = '42540'
'42081' = '48700'
'42083' = '14620'
'42085' = '49660'
'42087' = '30380'
'42089' = '20700'
'42091' = '37980'
'42093' = '14100'
'42095' = '10900'
'42097' = '44980'
'42099' = '25420'
'42101' = '37980'
'42103' = '35620'
'42107' = '39060'
'42109' = '42780'
'42111' = '43740'
'42119' = '30260'
'42121' = '36340'
'42123' = '47620'
'42125' = '38300'
'42129' = '38300'
'42131' = '42540'
'42133' = '49620'
'44001' = '39300'
'44003' = '39300'
'44005' = '39300'
'44007' = '39300'
'44009' = '39300'
'45003' = '12260'
'45007' = '11340'
'45013' = '25940'
'45015' = '16700'
'45017' = '17900'
'45019' = '16700'
'45021' = '23500'
'45023' = '16900'
'45029' = '47500'
'45031' = '22500'
'45033' = '19900'
'45035' = '16700'
'45037' = '12260'
'45039' = '17900'
'45041' = '22500'
'45043' = '23860'
'45045' = '24860'
'45047' = '24940'
'45051' = '34820'
'45053' = '25940'
'45055' = '17900'
'45057' = '29580'
'45059' = '24860'
'45063' = '17900'
'45069' = '13500'
'45071' = '35140'
'45073' = '42860'
'45075' = '36700'
'45077' = '24860'
'45079' = '17900'
'45081' = '17900'
'45083' = '43900'
'45085' = '44940'
'45087' = '46420'
'45091' = '16740'
'46005' = '26700'
'46011' = '15100'
'46013' = '10100'
'46027' = '46820'
'46029' = '47980'
'46035' = '33580'
'46045' = '10100'
'46057' = '47980'
'46061' = '33580'
'46065' = '38180'
'46081' = '43940'
'46083' = '43620'
'46087' = '43620'
'46093' = '39660'
'46099' = '43620'
'46103' = '39660'
'46117' = '38180'
'46125' = '43620'
'46127' = '43580'
'46135' = '49460'
'47001' = '28940'
'47003' = '43180'
'47009' = '28940'
'47011' = '17420'
'47013' = '29220'
'47015' = '34980'
'47019' = '27740'
'47021' = '34980'
'47023' = '27180'
'47029' = '35460'
'47031' = '46100'
'47035' = '18900'
'47037' = '34980'
'47043' = '34980'
'47045' = '20540'
'47047' = '32820'
'47051' = '46100'
'47053' = '26480'
'47057' = '34100'
'47059' = '24620'
'47063' = '34100'
'47065' = '16860'
'47073' = '28700'
'47075' = '15140'
'47079' = '37540'
'47081' = '34980'
'47087' = '18260'
'47089' = '34100'
'47093' = '28940'
'47099' = '29980'
'47105' = '28940'
'47107' = '11940'
'47111' = '34980'
'47113' = '27180'
'47115' = '16860'
'47117' = '30280'
'47119' = '17940'
'47125' = '17300'
'47127' = '46100'
'47131' = '46460'
'47133' = '18260'
'47139' = '17420'
'47141' = '18260'
'47145' = '25340'
'47147' = '34980'
'47149' = '34980'
'47153' = '16860'
'47155' = '42940'
'47157' = '32820'
'47159' = '34980'
'47161' = '17300'
'47163' = '28700'
'47165' = '34980'
'47167' = '32820'
'47169' = '34980'
'47171' = '27740'
'47173' = '28940'
'47177' = '32660'
'47179' = '27740'
'47183' = '32280'
'47187' = '34980'
'47189' = '34980'
'48001' = '37300'
'48003' = '11380'
'48005' = '31260'
'48007' = '18580'
'48009' = '48660'
'48011' = '11100'
'48013' = '41700'
'48015' = '26420'
'48019' = '41700'
'48021' = '12420'
'48025' = '13300'
'48027' = '28660'
'48029' = '41700'
'48037' = '45500'
'48039' = '26420'
'48041' = '17780'
'48049' = '15220'
'48051' = '17780'
'48055' = '12420'
'48057' = '47020'
'48059' = '10180'
'48061' = '15180'
'48065' = '11100'
'48071' = '26420'
'48073' = '27380'
'48077' = '48660'
'48085' = '19100'
'48091' = '41700'
'48097' = '23620'
'48099' = '28660'
'48107' = '31180'
'48113' = '19100'
'48115' = '29500'
'48117' = '25820'
'48119' = '19100'
'48121' = '19100'
'48135' = '36220'
'48139' = '19100'
'48141' = '21340'
'48143' = '44500'
'48147' = '14300'
'48157' = '26420'
'48167' = '26420'
'48175' = '47020'
'48179' = '37420'
'48181' = '43300'
'48183' = '30980'
'48187' = '41700'
'48189' = '38380'
'48199' = '13140'
'48201' = '26420'
'48203' = '32220'
'48209' = '12420'
'48213' = '11980'
'48215' = '32580'
'48219' = '30220'
'48221' = '24180'
'48223' = '44860'
'48227' = '13700'
'48231' = '19100'
'48233' = '14420'
'48235' = '41660'
'48245' = '13140'
'48249' = '10860'
'48251' = '19100'
'48253' = '10180'
'48257' = '19100'
'48259' = '41700'
'48261' = '28780'
'48265' = '28500'
'48273' = '28780'
'48277' = '37580'
'48281' = '28660'
'48291' = '26420'
'48303' = '31180'
'48309' = '47380'
'48321' = '13060'
'48323' = '20580'
'48325' = '41700'
'48329' = '33260'
'48339' = '26420'
'48341' = '20300'
'48347' = '34860'
'48349' = '18620'
'48353' = '45020'
'48355' = '18580'
'48361' = '13140'
'48363' = '33420'
'48367' = '19100'
'48375' = '11100'
'48381' = '11100'
'48389' = '37780'
'48393' = '37420'
'48395' = '17780'
'48397' = '19100'
'48401' = '30980'
'48407' = '26420'
'48409' = '18580'
'48415' = '43660'
'48423' = '46340'
'48425' = '24180'
'48427' = '40100'
'48439' = '19100'
'48441' = '10180'
'48449' = '34420'
'48451' = '41660'
'48453' = '12420'
'48459' = '30980'
'48463' = '46620'
'48465' = '19620'
'48469' = '47020'
'48471' = '26660'
'48473' = '26420'
'48477' = '14780'
'48479' = '29700'
'48481' = '20900'
'48485' = '48660'
'48487' = '46900'
'48489' = '39700'
'48491' = '12420'
'48493' = '41700'
'48497' = '19100'
'49003' = '14940'
'49005' = '30860'
'49007' = '39220'
'49011' = '36260'
'49021' = '16260'
'49023' = '39340'
'49029' = '36260'
'49035' = '41620'
'49043' = '41620'
'49045' = '41620'
'49047' = '46860'
'49049' = '39340'
'49051' = '25720'
'49053' = '41100'
'49057' = '36260'
'50003' = '13540'
'50007' = '15540'
'50009' = '13620'
'50011' = '15540'
'50013' = '15540'
'50017' = '30100'
'50021' = '40860'
'50023' = '12740'
'50027' = '30100'
'51003' = '16820'
'51007' = '40060'
'51009' = '31340'
'51011' = '31340'
'51013' = '47900'
'51015' = '44420'
'51019' = '31340'
'51023' = '40220'
'51031' = '31340'
'51033' = '40060'
'51036' = '40060'
'51041' = '40060'
'51043' = '47900'
'51045' = '40220'
'51047' = '19020'
'51049' = '40060'
'51053' = '40060'
'51059' = '47900'
'51061' = '47900'
'51065' = '16820'
'51067' = '40220'
'51069' = '49020'
'51071' = '13980'
'51073' = '47260'
'51075' = '40060'
'51079' = '16820'
'51085' = '40060'
'51087' = '40060'
'51089' = '32300'
'51093' = '47260'
'51095' = '47260'
'51097' = '40060'
'51101' = '40060'
'51107' = '47900'
'51109' = '40060'
'51115' = '47260'
'51121' = '13980'
'51125' = '16820'
'51127' = '40060'
'51143' = '19260'
'51145' = '40060'
'51149' = '40060'
'51153' = '47900'
'51155' = '13980'
'51161' = '40220'
'51165' = '25500'
'51169' = '28700'
'51177' = '47900'
'51179' = '47900'
'51181' = '47260'
'51183' = '40060'
'51185' = '14140'
'51187' = '47900'
'51191' = '28700'
'51199' = '47260'
'51510' = '47900'
'51515' = '31340'
'51520' = '28700'
'51540' = '16820'
'51550' = '47260'
'51570' = '40060'
'51590' = '19260'
'51600' = '47900'
'51610' = '47900'
'51630' = '47900'
'51650' = '47260'
'51660' = '25500'
'51670' = '40060'
'51680' = '31340'
'51683' = '47900'
'51685' = '47900'
'51690' = '32300'
'51700' = '47260'
'51710' = '47260'
'51730' = '40060'
'51735' = '47260'
'51740' = '47260'
'51750' = '13980'
'51760' = '40060'
'51770' = '40220'
'51775' = '40220'
'51790' = '44420'
'51800' = '47260'
'51810' = '47260'
'51820' = '44420'
'51830' = '47260'
'51840' = '49020'
'53003' = '30300'
'53005' = '28420'
'53007' = '48300'
'53009' = '38820'
'53011' = '38900'
'53015' = '31020'
'53017' = '48300'
'53021' = '28420'
'53025' = '34180'
'53027' = '10140'
'53029' = '36020'
'53033' = '42660'
'53035' = '14740'
'53037' = '21260'
'53041' = '16500'
'53045' = '43220'
'53053' = '42660'
'53057' = '34580'
'53059' = '38900'
'53061' = '42660'
'53063' = '44060'
'53067' = '36500'
'53071' = '47460'
'53073' = '13380'
'53075' = '39420'
'53077' = '49420'
'54003' = '25180'
'54005' = '16620'
'54009' = '48260'
'54011' = '26580'
'54015' = '16620'
'54017' = '17220'
'54019' = '36060'
'54027' = '49020'
'54029' = '48260'
'54033' = '17220'
'54037' = '47900'
'54039' = '16620'
'54043' = '16620'
'54049' = '21900'
'54051' = '48540'
'54053' = '38580'
'54055' = '14140'
'54057' = '19060'
'54061' = '34060'
'54065' = '25180'
'54069' = '48540'
'54073' = '37620'
'54077' = '34060'
'54079' = '16620'
'54081' = '13220'
'54091' = '17220'
'54099' = '26580'
'54105' = '37620'
'54107' = '37620'
'55009' = '24580'
'55015' = '11540'
'55017' = '20740'
'55021' = '31540'
'55025' = '31540'
'55027' = '13180'
'55031' = '20260'
'55033' = '32860'
'55035' = '20740'
'55037' = '27020'
'55039' = '22540'
'55043' = '38420'
'55045' = '33820'
'55049' = '31540'
'55055' = '48020'
'55059' = '16980'
'55061' = '24580'
'55063' = '29100'
'55069' = '32980'
'55071' = '31820'
'55073' = '48140'
'55075' = '31940'
'55079' = '33340'
'55083' = '24580'
'55087' = '11540'
'55089' = '33340'
'55093' = '33460'
'55097' = '44620'
'55101' = '39540'
'55105' = '27500'
'55109' = '33460'
'55111' = '12660'
'55117' = '43100'
'55127' = '48580'
'55131' = '33340'
'55133' = '33340'
'55139' = '36780'
'55141' = '49220'
'56001' = '29660'
'56005' = '23940'
'56013' = '40180'
'56021' = '16940'
'56025' = '16220'
'56033' = '43260'
'56037' = '40540'
'56039' = '27220'
'56041' = '21740'
;

/*============================================================================;
*  Title:
*          Format Library for Inpatient Quality Indicators
*
*  Description:
*          COVARIATE FORMAT LIB FOR AHRQ INPATIENT QUALITY INDICATORS;
*
*                 >>>  VERSION 2.1  <<<
*
*============================================================================;*/

 /* -------------------------------------------------------------- */
 /* ---   FORMAT FOR AGE STRATIFIERS                           --- */
 /* ---   MODULE 3. ASSIGNS ARRAY INDEX FOR AGE CATEGORIES     --- */
 /* -------------------------------------------------------------- */

VALUE AGEFMT
low - 4 = 1
 5 -  9 = 2
10 - 14 = 3
15 - 17 = 4
18 - 24 = 5
25 - 29 = 6
30 - 34 = 7
35 - 39 = 8
40 - 44 = 9
45 - 49 = 10
50 - 54 = 11
55 - 59 = 12
60 - 64 = 13
65 - 69 = 14
70 - 74 = 15
75 - 79 = 16
80 - 84 = 17
85 - high = 18;

 /* -------------------------------------------------------------- */
 /* ---   FORMATS FOR SEX STRATIFIERS                          --- */
 /* ---   ONE FORMAT PER QI.  NUMBER REFERS TO N VARIABLE IN   --- */
 /* ---   MODULE 3. ASSIGNS ARRAY INDEX FOR SEX CATEGORIES     --- */
 /* -------------------------------------------------------------- */

Value S8IQFMT
1 = 0
2 = 0
other = 0 
; 

Value S9IQFMT
1 = 0
2 = 1
other = 0 
; 

Value S11IQFMT
1 = 0
2 = 1
other = 0 
; 

Value S12IQFMT
1 = 0
2 = 1
other = 0 
; 

Value S13IQFMT
1 = 0
2 = 0
other = 0 
; 

Value S14IQFMT
1 = 0
2 = 1
other = 0 
; 

Value S15IQFMT
1 = 0
2 = 0
other = 0 
; 

Value S16IQFMT
1 = 0
2 = 1
other = 0 
; 

Value S17IQFMT
1 = 0
2 = 1
other = 0 
; 

Value S18IQFMT
1 = 0
2 = 0
other = 0 
; 

Value S19IQFMT
1 = 0
2 = 1
other = 0 
; 

Value S20IQFMT
1 = 0
2 = 1
other = 0 
; 

Value S30IQFMT
1 = 0
2 = 1
other = 0 
; 

Value S31IQFMT
1 = 0
2 = 0
other = 0 
; 

Value S32IQFMT
1 = 0
2 = 0
other = 0 
; 

 /* -------------------------------------------------------------- */
 /* ---   FORMATS FOR AGE STRATIFIERS                          --- */
 /* ---   ONE FORMAT PER QI.  NUMBER REFERS TO N VARIABLE IN   --- */
 /* ---   MODULE 3. ASSIGNS ARRAY INDEX FOR AGE CATEGORIES     --- */
 /* -------------------------------------------------------------- */

Value A8IQFMT
1 = 0
2 = 0
3 = 0
4 = 0
5 = 0
6 = 0
7 = 0
8 = 0
9 = 0
10 = 0
11 = 0
12 = 0
13 = 0
14 = 1
15 = 1
16 = 2
17 = 2
18 = 2
other = 0 
;

Value A9IQFMT
1 = 0
2 = 0
3 = 0
4 = 0
5 = 0
6 = 0
7 = 0
8 = 0
9 = 0
10 = 0
11 = 0
12 = 0
13 = 0
14 = 2
15 = 2
16 = 3
17 = 3
18 = 3
other = 0 
;

Value A11IQFMT
1 = 0
2 = 0
3 = 0
4 = 0
5 = 0
6 = 0
7 = 0
8 = 0
9 = 0
10 = 0
11 = 0
12 = 0
13 = 0
14 = 2
15 = 2
16 = 3
17 = 4
18 = 5
other = 0 
;

Value A12IQFMT
1 = 0
2 = 0
3 = 0
4 = 0
5 = 0
6 = 0
7 = 0
8 = 0
9 = 2
10 = 2
11 = 3
12 = 4
13 = 0
14 = 5
15 = 5
16 = 5
17 = 5
18 = 6
other = 0 
;

Value A13IQFMT
1 = 0
2 = 0
3 = 0
4 = 0
5 = 1
6 = 2
7 = 2
8 = 2
9 = 2
10 = 2
11 = 2
12 = 2
13 = 0
14 = 3
15 = 3
16 = 3
17 = 3
18 = 3
other = 0 
;

Value A14IQFMT
1 = 0
2 = 0
3 = 0
4 = 0
5 = 2
6 = 2
7 = 2
8 = 2
9 = 2
10 = 2
11 = 2
12 = 2
13 = 0
14 = 3
15 = 3
16 = 3
17 = 3
18 = 3
other = 0 
;

Value A15IQFMT
1 = 0
2 = 0
3 = 0
4 = 0
5 = 1
6 = 1
7 = 1
8 = 1
9 = 2
10 = 3
11 = 4
12 = 5
13 = 0
14 = 6
15 = 6
16 = 6
17 = 7
18 = 8
other = 0 
;

Value A16IQFMT
1 = 0
2 = 0
3 = 0
4 = 0
5 = 2
6 = 2
7 = 2
8 = 2
9 = 2
10 = 2
11 = 3
12 = 4
13 = 0
14 = 5
15 = 5
16 = 5
17 = 5
18 = 6
other = 0 
;

Value A17IQFMT
1 = 0
2 = 0
3 = 0
4 = 0
5 = 2
6 = 2
7 = 2
8 = 2
9 = 2
10 = 2
11 = 2
12 = 2
13 = 0
14 = 3
15 = 3
16 = 3
17 = 3
18 = 4
other = 0 
;

Value A18IQFMT
1 = 0
2 = 0
3 = 0
4 = 0
5 = 1
6 = 1
7 = 1
8 = 1
9 = 1
10 = 1
11 = 1
12 = 1
13 = 0
14 = 2
15 = 2
16 = 2
17 = 2
18 = 2
other = 0 
;

Value A19IQFMT
1 = 0
2 = 0
3 = 0
4 = 0
5 = 0
6 = 0
7 = 0
8 = 0
9 = 0
10 = 0
11 = 0
12 = 0
13 = 0
14 = 0
15 = 2
16 = 2
17 = 2
18 = 3
other = 0 
;

Value A20IQFMT
1 = 0
2 = 0
3 = 0
4 = 0
5 = 2
6 = 3
7 = 4
8 = 5
9 = 6
10 = 7
11 = 8
12 = 9
13 = 0
14 = 10
15 = 10
16 = 10
17 = 10
18 = 11
other = 0 
;

Value A30IQFMT
1 = 0
2 = 0
3 = 0
4 = 0
5 = 0
6 = 0
7 = 0
8 = 0
9 = 2
10 = 2
11 = 2
12 = 2
13 = 0
14 = 3
15 = 3
16 = 4
17 = 5
18 = 6
other = 0 
;

Value A31IQFMT
1 = 0
2 = 0
3 = 0
4 = 0
5 = 1
6 = 1
7 = 1
8 = 1
9 = 1
10 = 1
11 = 1
12 = 1
13 = 0
14 = 2
15 = 2
16 = 2
17 = 2
18 = 2
other = 0 
;

Value A32IQFMT
1 = 0
2 = 0
3 = 0
4 = 0
5 = 1
6 = 1
7 = 1
8 = 1
9 = 2
10 = 3
11 = 4
12 = 5
13 = 0
14 = 6
15 = 6
16 = 6
17 = 6
18 = 7
other = 0 
;

 /* -------------------------------------------------------------- */
 /* --- FORMATS FOR APR-DRG STRATIFIERS     ---------------------- */
 /* ---   ONE FORMAT PER IQI.  NUMBER REFERS TO N VARIABLE IN  --- */
 /* ---   PROGRAM P3. ASSIGNS ARRAY INDEX FOR APR-DRG          --- */
 /* ---   CATEGORIES (PROVIDER ONLY).                          --- */
 /* -------------------------------------------------------------- */

Value $C8IQFM
'2201' = 0  
'2202' = 0  
'2203' = 3  
'2204' = 3  
other = -1;

Value $C9IQFM
'2601' = 0
'2602' = 0
'2603' = 4
'2604' = 4
other = -1;

Value $C11IQFM
'1691' = 6
'1692' = 6
'1693' = 7
'1694' = 7
'1731' = 0
'1732' = 0
'1733' = 8
'1734' = 8
other = -1;

Value $C12IQFM
'1611' = 7
'1612' = 7
'1613' = 8
'1614' = 9
'1621' = 10
'1622' = 10
'1623' = 11
'1624' = 12
'1631' = 13
'1632' = 13
'1633' = 14
'1634' = 15
'1651' = 0
'1652' = 16
'1653' = 17
'1654' = 18
'1661' = 19
'1662' = 19
'1663' = 20
'1664' = 21
other = -1;

Value $C13IQFM
'0211' = 0
'0212' = 4
'0213' = 5
'0214' = 6
'0221' = 7
'0222' = 7
'0223' = 8
'0224' = 9
'0231' = 10
'0232' = 10
'0233' = 11
'0234' = 11
'0241' = 12
'0242' = 12
'0243' = 13
'0244' = 14
other = -1;

Value $C14IQFM
'3011' = 0
'3012' = 0
'3013' = 4
'3014' = 4
other = -1;

Value $C15IQFM
'1611' = 9
'1612' = 9
'1613' = 10
'1614' = 10
'1621' = 11
'1622' = 11
'1623' = 12
'1624' = 13
'1651' = 14
'1652' = 14
'1653' = 15
'1654' = 16
'1731' = 17
'1732' = 17
'1733' = 17
'1734' = 17
'1741' = 0
'1742' = 18
'1743' = 19
'1744' = 20
'1901' = 21
'1902' = 22
'1903' = 23
'1904' = 24
other = -1;

Value $C16IQFM
'1611' = 7
'1612' = 8
'1613' = 9
'1614' = 10
'1621' = 11
'1622' = 11
'1623' = 12
'1624' = 13
'1751' = 14
'1752' = 14
'1753' = 14
'1754' = 15
'1801' = 16
'1802' = 17
'1803' = 18
'1804' = 19
'1911' = 20
'1912' = 20
'1913' = 21
'1914' = 22
'1941' = 0
'1942' = 23
'1943' = 24
'1944' = 25
other = -1;

Value $C17IQFM
'0211' = 5
'0212' = 6
'0213' = 7
'0214' = 8
'0221' = 9
'0222' = 10
'0223' = 11
'0224' = 11
'0231' = 12
'0232' = 12
'0233' = 13
'0234' = 14
'0241' = 15
'0242' = 16
'0243' = 17
'0244' = 18
'0261' = 19
'0262' = 19
'0263' = 19
'0264' = 20
'0441' = 21
'0442' = 22
'0443' = 23
'0444' = 24
'0451' = 0
'0452' = 25
'0453' = 26
'0454' = 27
other = -1;

Value $C18IQFM
'2201' = 3
'2202' = 4
'2203' = 5
'2204' = 6
'2211' = 7
'2212' = 8
'2213' = 9
'2214' = 10
'2411' = 11
'2412' = 11
'2413' = 11
'2414' = 12
'2421' = 13
'2422' = 13
'2423' = 13
'2424' = 14
'2441' = 15
'2442' = 15
'2443' = 16
'2444' = 17
'2531' = 0
'2532' = 18
'2533' = 19
'2534' = 20
'2541' = 21
'2542' = 21
'2543' = 21
'2544' = 22
other = -1;

Value $C19IQFM
'3011' = 4
'3012' = 4
'3013' = 5
'3014' = 6
'3081' = 0
'3082' = 7
'3083' = 8
'3084' = 9
'3401' = 10
'3402' = 11
'3403' = 12
'3404' = 13
other = -1;

Value $C20IQFM
'1211' = 12
'1212' = 13
'1213' = 14
'1214' = 15
'1301' = 16
'1302' = 17
'1303' = 18
'1304' = 18
'1371' = 19
'1372' = 20
'1373' = 21
'1374' = 22
'1391' = 0
'1392' = 23
'1393' = 24
'1394' = 25
other = -1;

Value $C30IQFM
'1651' = 0
'1652' = 0
'1653' = 7
'1654' = 7
'1741' = 8
'1742' = 9
'1743' = 10
'1744' = 11
'1751' = 0
'1752' = 12
'1753' = 13
'1754' = 14
other = -1;

Value $C31IQFM
'0241' = 0
'0242' = 3
'0243' = 3
'0244' = 3
other = -1;

Value $C32IQFM
'1611' = 8
'1612' = 8
'1613' = 8
'1614' = 8
'1621' = 9
'1622' = 9
'1623' = 10
'1624' = 11
'1651' = 12
'1652' = 12
'1653' = 13
'1654' = 14
'1731' = 15
'1732' = 15
'1733' = 15
'1734' = 15
'1741' = 0
'1742' = 16
'1743' = 17
'1744' = 18
'1901' = 19
'1902' = 20
'1903' = 21
'1904' = 22
other = -1;

 /* -------------------------------------------------------------- */
 /* --- FORMATS FOR MDC STRATIFIERS         ---------------------- */
 /* -------------------------------------------------------------- */

VALUE M8IQFMT
6 = 4
OTHER = 5
;

VALUE M9IQFMT
7 = 5
OTHER = 6
;

VALUE M11IQFMT
5 = 9
OTHER = 10
;

VALUE M12IQFMT
5 = 22
OTHER = 23
;

VALUE M13IQFMT
1 = 15
OTHER = 0
;

VALUE M14IQFMT
8 = 5
OTHER = 6
;

VALUE M15IQFMT
5 = 25
OTHER = 0
;

VALUE M16IQFMT
OTHER = 26
;

VALUE M17IQFMT
OTHER = 28
;

VALUE M18IQFMT
OTHER = 23
;

VALUE M19IQFMT
8 =  14
24 = 15
OTHER = 0
;

VALUE M20IQFMT
4 = 26
25 = 27
OTHER = 0
;

VALUE M30IQFMT
4 = 15
5 = 16
8 = 17
18 = 18
OTHER = 19
;

VALUE M31IQFMT
1 = 4
5 = 5
OTHER = 6
;

VALUE M32IQFMT
5 = 23
OTHER = 0
;

 /* -------------------------------------------------------------- */

RUN;

